#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2006, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/26 00:50:43
#
# @brief CalcLibBalance.pl - CartridgeGroup priority calculation
#
#-----------------------------------------------------------------------

#
# Windows lib not used yet. tool runs on Linux or AIX
#
#use lib "d:/opt/IBM/ermm/lib";

#
# Linux / AIX
#
use lib "/opt/IBM/ermm/lib";

unless (eval("require Locale::Maketext;")) { die "Required Perl module Locale::Maketext is missing!\n"; }

#
# use new libraries
#
use libbal::eRMMConfig;
use libbal::eRMMTrace;
use libbal::eRMMCom;
use libbal::eRMMReg;
use libbal::LIBBALVersion;

#
# private variables
#
my $LibBalanceVersion = $LIBBALVersion::LIBBALVERSION;

my $PercentNorm = 100;
my $PriorityNorm = 1000;

my @typesarr;
my @libsarr;

my $isConnected = 0;
my $triggercount = 1;
my $reinitcount = 1;
my $volume = "";

#
# read configuration
# if no argument is passed, use the default
#
my $configfile = $ARGV[0];
if (length($configfile) <= 0) {
    $configfile = "/opt/IBM/ermm/conf/LibBalConf.xml";
}
my $rcConfig = eRMMConfig::readConfiguration( { "ConfigFile" => $configfile } );
if ($rcConfig) {
    print "Configuration error, missing variables\n";
}

#
# let's start
#
eRMMConfig::L10N_init();

eRMMConfig::printtext("_COPYRIGHT");


#
# initialize tracing and trace config variables
#
eRMMTrace::initTrace( {
				"TracePath" => $eRMMConfig::mmtracepath,
				"TraceFile" => $eRMMConfig::mmtracefile,
				"TraceLevel" => $eRMMConfig::mmtracelevel,
				"Application" => "LibraryBalanceTool"
				} );
eRMMTrace::addTraceInfo("LB LibBalanceVersion:" . $LibBalanceVersion);
eRMMTrace::addTraceInfo("MM tracelevel:" . $eRMMConfig::mmtracelevel);
eRMMTrace::addTraceInfo("MM host:" . $eRMMConfig::mmhostname);
eRMMTrace::addTraceInfo("MM port:" . $eRMMConfig::mmportnumber);
eRMMTrace::addTraceInfo("MM application:" . $eRMMConfig::mmclientapplication);
eRMMTrace::addTraceInfo("MM instance:" . $eRMMConfig::mmclientappinstance);
eRMMTrace::addTraceInfo("MM authmethod:" . $eRMMConfig::mmclientauthmethod);
eRMMTrace::addTraceInfo("LB triggercount:" . $eRMMConfig::lbtriggercount);
eRMMTrace::addTraceInfo("LB reinitcount:" . $eRMMConfig::lbreinitcount);
eRMMTrace::addTraceInfo("LB availabledrivesweightfactor:" .
                        $eRMMConfig::lbavailabledrivesweightfactor);
eRMMTrace::addTraceInfo("LB usabledrivesweightfactor:" .
                        $eRMMConfig::lbusabledrivesweightfactor);
eRMMTrace::addTraceInfo("LB roundrobinvalueweightfactor:" .
                        $eRMMConfig::lbroundrobinvalueweightfactor);
eRMMTrace::addTraceInfo("LB debug:" . $eRMMConfig::lbdebug);

#
# check input configuration values
#
if ($rcConfig) {
    eRMMTrace::addTraceInfo("Configuration error, missing variables");
      exit 1;
}
if ( ( ($eRMMConfig::lbavailabledrivesweightfactor < 10000) ||
       ($eRMMConfig::lbavailabledrivesweightfactor > 100000) ) ||
     ($eRMMConfig::lbavailabledrivesweightfactor =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value lbavailabledrivesweightfactor:" .
                            $eRMMConfig::lbavailabledrivesweightfactor);
      exit 1;
}
if ( ( ($eRMMConfig::lbusabledrivesweightfactor < 100) ||
       ($eRMMConfig::lbusabledrivesweightfactor >
        $eRMMConfig::lbavailabledrivesweightfactor / 100) )  ||
     ($eRMMConfig::lbusabledrivesweightfactor =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value lbusabledrivesweightfactor:" .
                            $eRMMConfig::lbusabledrivesweightfactor);
      exit 1;
}
if ( ( ($eRMMConfig::lbroundrobinvalueweightfactor < 1) ||
     ($eRMMConfig::lbroundrobinvalueweightfactor > 1000) ) ||
     ($eRMMConfig::lbroundrobinvalueweightfactor =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value lbroundrobinvalueweightfactor:" .
                            $eRMMConfig::lbroundrobinvalueweightfactor);
      exit 1;
}
if ( ( ($eRMMConfig::mmtracelevel != 0) &&
       ($eRMMConfig::mmtracelevel != 1) &&
       ($eRMMConfig::mmtracelevel != 3) &&
       ($eRMMConfig::mmtracelevel != 5) ) ||
     ($eRMMConfig::mmtracelevel =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value mmtracelevel:" .
                            $eRMMConfig::mmtracelevel);
      exit 1;
}
if ( ( ($eRMMConfig::lbdebug < 0) ||
       ($eRMMConfig::lbdebug > 1) ) ||
     ($eRMMConfig::lbdebug =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value lbdebug:" .
                            $eRMMConfig::lbdebug);
      exit 1;
}
if ( ( ($eRMMConfig::lbtriggercount < 0) ||
     ($eRMMConfig::lbtriggercount > 10) ) ||
     ($eRMMConfig::lbtriggercount =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value lbtriggercount:" .
                            $eRMMConfig::lbtriggercount);
      exit 1;
}
if ( ( ($eRMMConfig::lbreinitcount < 0) ||
       ($eRMMConfig::lbreinitcount > 20) ) ||
     ($eRMMConfig::lbreinitcount =~ /\d*\D/) ) {
    eRMMTrace::addTraceInfo("Wrong config value lbreinitcount:" .
                            $eRMMConfig::lbreinitcount);
      exit 1;
}

eRMMTrace::addTraceInfo("Initialization completed, starting normal processing");

#
# store weight factors into local variables
#
my $AvailableDrivesWeightFactor = $eRMMConfig::lbavailabledrivesweightfactor;
my $UsableDrivesWeightFactor = $eRMMConfig::lbusabledrivesweightfactor;
my $RoundRobinValueWeightFactor = $eRMMConfig::lbroundrobinvalueweightfactor;

#
# create internal repository
#
createRepository();
debug("createRepository");
eRMMTrace::addTraceEntry("Internal repository created!");


#
# check library weight factor after creation of the internal repository
#
foreach my $lrec (@libsarr) {
    if ( ($lrec->{"LibraryWeightFactor"} < 1) ||
         ($lrec->{"LibraryWeightFactor"} > 2) ) {
        eRMMTrace::addTraceInfo("Wrong config value for Library:" .
                                $lrec->{"LibraryName"} .
                                " LibraryWeightFactor:" .
                                $lrec->{"LibraryWeightFactor"});
      exit 1;
    }
}

#
# connect to MM use two connections, one for registration and one for commands
#
eRMMCom::connect();
eRMMReg::connect();

#
# check whether the config parameter for libraries are ok
#
checkConfigLibraryArray();

#
# initalize values in repository
#
initializeRepository();
debug("initializeRepository");
eRMMTrace::addTraceEntry("Internal repository initialized!");

#
# register this process on allocate command
#
registerToMM();

#
# main loop triggered by MM notification
#
while (!$isConnected) {
    #
    # wait for notification, when disconnected/cancelled from MM then exit
    #
    my $notification = eRMMReg::getNotification();

    if ($notification =~ /\s*response\s+.*cancelled.*/) {
        eRMMTrace::addTraceInfo("Monitor task has been canceled.");
        $isConnected = 1;
        $volume = "";
    }
    else {
        if ($notification eq "error") {
            my $err = "Error receiving notificaton, trying next one";
            eRMMCom::sendError(eRMMConfig::gettext("ERR_NOTIFICATION"));
            eRMMTrace::addTraceInfo($err);
            next;
        }

	$notification =~ /.*newvolname\[\\"s*(\w+).*/;
        $volume = $1;
        my $str = "Notification received, allocated Volume=" . $volume;

            eRMMTrace::addTraceInfo($str);
        if ($eRMMConfig::mmdebug == 1) {
            print $str . "\n";
        }

        if ($eRMMConfig::mmtracelevel >= 3) {
            eRMMTrace::addTraceEntry($str);
        }

        if ($triggercount < $eRMMConfig::lbtriggercount) {
            $triggercount++;
            next;
        }
        $triggercount = 1;

        if ($reinitcount >= $eRMMConfig::lbreinitcount) {
            $reinitcount = 1;
            #
            # get all usable and free drives of system
            #
            getNowAllUsableAndAvailableDrives();
            debug("getNowAllUsableAndAvailableDrives");
            eRMMTrace::addTraceEntry("Get all usable and available drives succeeded!");
        }
        else {
            $reinitcount++;
            #
            # get all free drives of system
            #
            getNowAllAvailableDrives();
            debug("getNowAllAvailableDrives");
            eRMMTrace::addTraceEntry("Get all available drives succeeded!");
        }
        #
      	# calculate utilization
      	#
      	calculateUtilization();
        debug("calulateUtilization");
        eRMMTrace::addTraceEntry("Calculate utilization succeeded!");

        #
      	# calculate priority
      	#
        calculatePriority();
        debug("calulatePriority");
        eRMMTrace::addTraceEntry("Calculate priority succeeded!");

        #
      	# set the cartridge group priorities attribute
      	#
        setNewCartridgeGroupPriorities();
        debug("setNewCartridgeGroupPriorities");
        eRMMTrace::addTraceEntry("Setup new CartrideGroupPriorities succeeded!");

        traceResults();
    }

}
exit 0;


#
# routine to trace debug infos
# on screen
# tracefile
#
sub debug {
    my $str = "EntryPoint=" . $_[0];
    if ($eRMMConfig::lbdebug == 1) {
        print $str . "\n";
    }
    if ($eRMMConfig::mmtracelevel >= 5) {
        eRMMTrace::addTraceEntry($str);
    }
    foreach my $rec (@typesarr) {
        $str = "Type=" . $rec->{Type} . " UDS=" .
            $rec->{"AmountUsableDrivesSys"} .
            " ALIBC=" .$rec->{"AmountLibraries"} .
            " AADS=" .$rec->{"AmountAvailableDrivesSys"} .
            " CPVS=" .$rec->{"CalcPriorityValueSys"} .
            " USEL=" .$rec->{"UsedLibraryName"};
        if ($eRMMConfig::lbdebug == 1) {
            print $str . "\n";
        }
        if ($eRMMConfig::mmtracelevel >= 5) {
            eRMMTrace::addTraceEntry($str);
        }
    }
    foreach my $rec (@libsarr) {
        $str = "Lib=" . $rec->{"LibraryName"} .
            " LWF=" . $rec->{"LibraryWeightFactor"} .
            " Type=" . $rec->{"Type"} .
            " RRV=" . $rec->{"RoundRobinValue"} .
            " AUD=" . $rec->{"AmountUsableDrives"} .
            " AAD=" . $rec->{"AmountAvailableDrives"} .
            " LWF=" . $rec->{"LibraryWeightFactor"} .
            " NUSD=" . $rec->{"NormUsableDrivesSysValue"} .
            " NAD=" . $rec->{"NormAvailableDrivesValue"} .
            " LAST=" . $rec->{"LastUsedValue"} .
            " PRIO=" . $rec->{"Priority"} .
            " GRP=" . $rec->{"CartridgeGroupName"};
        if ($eRMMConfig::lbdebug == 1) {
            print $str . "\n";
        }
        if ($eRMMConfig::mmtracelevel >= 5) {
            eRMMTrace::addTraceEntry($str);
        }
    }
}


#
# routine to trace the result(s) off the current calculation cycle
# on screen
# tracefile
# message to TSLM
#
sub traceResults {
    my $strl = "";
    my $strt = "Results";
    foreach my $trec (@typesarr) {
        $strt = $strt . ";<-" . $trec->{"Type"} . " ";
        foreach my $lrec (@libsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {
                $strl = "Type=" . $lrec->{"Type"} . " Lib=" .
                    $lrec->{"LibraryName"} . " Prio=" . $lrec->{"Priority"};
                if ($eRMMConfig::lbdebug == 1) {
                    print $strl . "\n";
                }
                if ($eRMMConfig::mmtracelevel >= 3) {
                    eRMMTrace::addTraceEntry($strl);
                }
            }
        }
        $strt = $strt . "Lib=" . $trec->{"UsedLibraryName"} . " LN=" .
            $trec->{"UsedLibraryNumber"} . "->";
    }
    if ($eRMMConfig::lbdebug == 1) {
        print $strt . "\n";
    }
    eRMMTrace::addTraceInfo($strt);
    eRMMCom::sendInfo(eRMMConfig::gettext("I_NEXT_LIB", $strt));

    return;
}


#
# routine to create the internal repository
#
sub createRepository {
    my $librec = {};
    my $typerec = {};
    foreach my $trec (@eRMMConfig::conftypesarr) {
        my $cntlibs = 1;
        foreach my $lrec (@eRMMConfig::conflibsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {
                $librec = {};
                $librec->{"LibraryName"} = $lrec->{"LibraryName"};
                $librec->{"LibraryNumber"} = $cntlibs;
                $librec->{"LibraryWeightFactor"} = $lrec->{"LibraryWeightFactor"};
                $librec->{"Type"} = $lrec->{"Type"};
                $librec->{"CartridgeGroupName"} = $lrec->{"GroupName"};
                $librec->{"AmountUsableDrives"} = 0;
                $librec->{"AmountAvailableDrives"} = 0;
                $librec->{"NormUsableDrivesSysValue"} = 0;
                $librec->{"NormAvailableDrivesValue"} = 0;
                $librec->{"RoundRobinValue"} = $cntlibs;
                $librec->{"LastUsedValue"} = 0;
                $librec->{"Priority"} = 0;
                $librec->{"CalcPriorityValue"} = 0;
                push @libsarr, $librec;

                $cntlibs++;
            }
        }
        $typerec = {};
        $typerec->{"Type"} = $trec->{"Type"};
        $typerec->{"AmountLibraries"} = $cntlibs - 1;
        $typerec->{"AmountUsableDrivesSys"} = 0;
        $typerec->{"AmountAvailableDrivesSys"} = 0;
        $typerec->{"CalcPriorityValueSys"} = 0;
        $typerec->{"UsedLibraryName"} = "";
        $typerec->{"UsedLibraryNumber"} = 0;

        push @typesarr, $typerec;
    }
    return;
}


#
# routine to initialize the internal repository
#
sub initializeRepository {
    foreach my $trec (@typesarr) {
        $trec->{"AmountUsableDrivesSys"} = 0;
        $trec->{"AmountAvailableDrivesSys"} = 0;
        $trec->{"CalcPriorityValueSys"} = 0;
        $trec->{"UsedLibraryName"} = "";
        $trec->{"UsedLibraryNumber"} = 0;
        foreach my $lrec (@libsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {
                $lrec->{"AmountUsableDrives"} =
                    getUsableDrives($lrec->{"LibraryName"},
                                    $lrec->{"Type"});
                $lrec->{"AmountAvailableDrives"} =
                    getAvailableDrives($lrec->{"LibraryName"},
                                       $lrec->{"Type"});

                $trec->{"AmountUsableDrivesSys"} += $lrec->{"AmountUsableDrives"};
                $trec->{"AmountAvailableDrivesSys"} += $lrec->{"AmountAvailableDrives"};
            }
        }
    }
    return;
}


#
# routine to calculate the drive utilization
#
sub calculateUtilization {
    foreach my $trec (@typesarr) {
        $trec->{"CalcPriorityValueSys"} = 0;
        $trec->{"AmountAvailableDrivesSys"} = 0;
        foreach my $lrec (@libsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {
                if ($trec->{"AmountUsableDrivesSys"} <= 0){ 	#divide by zero
                    $lrec->{"NormUsableDrivesSysValue"} = 0;
                }
                else {
                    $lrec->{"NormUsableDrivesSysValue"} =
                        ($lrec->{"AmountUsableDrives"} /
                         $trec->{"AmountUsableDrivesSys"} *
                         $PercentNorm);
                }
                if ($lrec->{"AmountUsableDrives"} <= 0){ 	#divide by zero
                    $lrec->{"NormAvailableDrivesValue"} = 0;
                }
                else {
                    $lrec->{"NormAvailableDrivesValue"} =
                        ($lrec->{"AmountAvailableDrives"} /
                         $lrec->{"AmountUsableDrives"} *
                         $PercentNorm);
                }

                $lrec->{"CalcPriorityValue"} = ( ($lrec->{"NormAvailableDrivesValue"} *
                                                  $AvailableDrivesWeightFactor *
                                                  $lrec->{"LibraryWeightFactor"}) +

                                                 ($lrec->{"NormUsableDrivesSysValue"} *
                                                  $UsableDrivesWeightFactor) +

                                                 $lrec->{"LastUsedValue"} +

                                                 ($lrec->{"RoundRobinValue"} *
                                                  $RoundRobinValueWeightFactor)

                                                 );
                $trec->{"CalcPriorityValueSys"} += $lrec->{"CalcPriorityValue"};
                $trec->{"AmountAvailableDrivesSys"} += $lrec->{"AmountAvailableDrives"};
            }
        }
    }
    return;
}


#
# routine to calculate the priority
#
sub calculatePriority {
    foreach my $trec (@typesarr) {
        my $uselib = "";
        my $uselibnumber = 0;
      	my $lastprio = 1000;
        my $calcprio = 0;
        my $prio = 0;
        my $rem = 0;
        if ($trec->{"AmountAvailableDrivesSys"} > 0) {
            foreach my $lrec (@libsarr) {
                if ($trec->{"Type"} eq $lrec->{"Type"}) {
                    $calcprio = $PriorityNorm -
                        ($lrec->{"CalcPriorityValue"} / $trec->{"CalcPriorityValueSys"} *
                         $PriorityNorm);
                    #$calcprio =~ /(\d+).*/;
                    $lrec->{"Priority"} = $calcprio; #$1
                    if ($lrec->{"Priority"} < $lastprio) {
                        $uselib = $lrec->{"LibraryName"};
                        $uselibnumber = $lrec->{"LibraryNumber"};
                        $lastprio = $lrec->{"Priority"};
                    }

                    if ($lrec->{"RoundRobinValue"} >= $trec->{"AmountLibraries"}) {
                        $lrec->{"RoundRobinValue"} = 1;
                    }
                    else {
                        $lrec->{"RoundRobinValue"}++;
                    }
                }
            }
        }
        else {
            foreach my $lrec (@libsarr) {
                if ($trec->{"Type"} eq $lrec->{"Type"}) {
                    if ($lrec->{"RoundRobinValue"} >= $trec->{"AmountLibraries"}) {
                        $lrec->{"RoundRobinValue"} = 1;
                    }
                    else {
                        $lrec->{"RoundRobinValue"}++;
                    }
                    $lrec->{"Priority"} = $lrec->{"RoundRobinValue"} + 100;
                    if ($lrec->{"Priority"} < $lastprio) {
                        $uselib = $lrec->{"LibraryName"};
                        $uselibnumber = $lrec->{"LibraryNumber"};
                        $lastprio = $lrec->{"Priority"};
                    }
                }
            }
        }

        $trec->{"UsedLibraryName"} = $uselib;
        $trec->{"UsedLibraryNumber"} = $uselibnumber;

        #
        # setup new LastUsedValue
        #
        foreach my $lrec (@libsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {
                if ($lrec->{"LibraryName"} eq $uselib) {
                    $lrec->{"LastUsedValue"} = 0;
                    if ($lrec->{"Priority"} > 2) {
                        $lrec->{"Priority"} -= 1;
                    }
                }
                else {
                    if ($RoundRobinValueWeightFactor == 0) {
                        $lrec->{"LastUsedValue"} = ($trec->{"AmountLibraries"} + 1);
                    }
                    else {
                        $lrec->{"LastUsedValue"} = $RoundRobinValueWeightFactor *
                            ($trec->{"AmountLibraries"} + 1);
                    }
                }
            }
        }
    }
    return;
}


#
# routine to get the amount of usable drives in the system
# all drives which are enabled, not brocken, not in NoAccess,
# for the given library and type
#
sub getUsableDrives {
    my ($lib, $type) = @_;
    my $sendstr = "show task [\"" . eRMMConfig::getTaskId() . "\"] " .
        "report [DRIVE.\"DriveName\"] reportmode [value] " .
        "match [and( streq(DMCAPABILITYTOKEN.\"DMCAPABILITYTOKEN\" \"" . $type . "\") " .
        "streq(DRIVE.\"LibraryName\" \"" . $lib . "\")" .
        "streq(DRIVE.\"DriveDisabled\" \"false\") " .
        "streq(DRIVE.\"DriveBroken\" \"false\") " .
        "strne(DRIVE.\"DriveGroupName\" \"NoAccess\") " .
        "streq(DMCAPABILITYTOKEN.\"DriveName\" DRIVE.\"DriveName\") ) ];";

    eRMMCom::send($sendstr);
    my $resp = eRMMCom::getResponse();
    if ($resp eq "error") {
        my $err = "Error getting usable Drives for Type:"
            . $type . " of Library:" . $lib;
        eRMMCom::sendError(eRMMConfig::gettext("ERR_GET_UDRIVES", $type, $lib));
        eRMMTrace::addTraceInfo($err);
        return 0;
    }
    if ($resp =~ /.*text.*/) {
        # must use array count instead of number clause because
        # a drive is counted for each type.
        # as text in the response the drive is reported only once
        my @arr = eRMMCom::getKeyValueResults($resp);
        my $count = $#arr + 1;

        #print "size=" . $count . "\n";
        #foreach my $rec (@arr) {
        #		print "Val=" . @$rec[0] . "\n";
        #	}

        return $count;
    }
    else {
        my $err = "No usable Drives for Type:"
            . $type . " of Library:" . $lib . " currently found";
        eRMMCom::sendInfo(eRMMConfig::gettext("I_NO_UDRIVES", $type, $lib));
        eRMMTrace::addTraceInfo($err);
        return 0;
    }
}


#
# routine to get the amount of curently available drives in the system
# all drives which are enabled, not brocken, not in NoAccess, unloaded, ready,
# for the given
# library and type
#
sub getAvailableDrives {
    my ($lib, $type) = @_;
    my $sendstr = "show task [\"" . eRMMConfig::getTaskId() . "\"] " .
        "report [DRIVE.\"DriveName\"] reportmode [value] " .
        "match [and( streq(DMCAPABILITYTOKEN.\"DMCAPABILITYTOKEN\" \"" . $type . "\") " .
        "streq(DRIVE.\"LibraryName\" \"" . $lib . "\")" .
        "streq(DRIVE.\"DriveDisabled\" \"false\") " .
        "streq(DRIVE.\"DriveBroken\" \"false\") " .
        "streq(DRIVE.\"DriveStateHard\" \"unloaded\") " .
        "streq(DRIVE.\"DriveStateSoft\" \"ready\") " .
        "strne(DRIVE.\"DriveGroupName\" \"NoAccess\") " .
        "streq(DMCAPABILITYTOKEN.\"DriveName\" DRIVE.\"DriveName\") ) ];";

    eRMMCom::send($sendstr);
    my $resp = eRMMCom::getResponse();
    if ($resp eq "error") {
        my $err = "Error getting available Drives for Type:"
            . $type . " of Library:" . $lib;
        eRMMCom::sendError(eRMMConfig::gettext("ERR_GET_ADRIVES", $type, $lib));
        eRMMTrace::addTraceInfo($err);
        return 0;
    }
    if ($resp =~ /.*text.*/) {
        # must use array count instead of number clause because
        # a drive is counted for each type.
        # as text in the response the drive is reported only once
        my @arr = eRMMCom::getKeyValueResults($resp);
        my $count = $#arr + 1;

        #print "size=" . $count . "\n";
        #foreach my $rec (@arr) {
        #		print "Val=" . @$rec[0] . "\n";
        #	}

        return $count;
    }
    else {
        my $err = "No available Drives for Type:"
            . $type . " of Library:" . $lib . " currently found";
        eRMMCom::sendInfo(eRMMConfig::gettext("I_NO_ADRIVES", $type, $lib));
        eRMMTrace::addTraceInfo($err);
        return 0;
    }
}


#
# routine to setup the new CartridgeGroupPriority in TSLM
#
sub setNewCartridgeGroupPriorities {
    foreach my $lrec (@libsarr) {
        $lrec->{"Priority"} =~ /(\d+).*/;
        my $prio = $1;

        my $sendstr = "attribute task [\"" . eRMMConfig::getTaskId() . "\"] " .
            "match [and ( streq(CARTRIDGEGROUP.\"CartridgeGroupName\" " .
            "\"" . $lrec->{"CartridgeGroupName"} . "\") )] " .
            "set [CARTRIDGEGROUP.\"CartridgeGroupPriority\" " .
            "\"" . $prio . "\"];";

        eRMMCom::send($sendstr);
        my $resp = eRMMCom::getResponse();
        if ($resp eq "error") {
            my $err = "Error setting new CartridgeGroupPriority for Group:"
                .  $lrec->{"CartridgeGroupName"};
            eRMMCom::sendError(eRMMConfig::gettext("ERR_SET_NEWCGP",  $lrec->{"CartridgeGroupName"}));
            eRMMTrace::addTraceInfo($err);
        }
    }
    return;
}


#
# routine to register this application on any allocate requests
#
sub registerToMM {
    my $sendstr = "register task [\"" . eRMMConfig::getTaskId() . "\"] " .
        "type [\"event\" \"command:allocate\" \"always\"] ;" ;

    eRMMReg::send($sendstr);
    $resp = eRMMReg::getResponse();
    if ($resp eq "error") {
        my $err = "Error registering application";
        eRMMCom::sendError(eRMMConfig::gettext("ERR_REG_APP"));
        eRMMTrace::addTraceInfo($err);
        exit 1;
    }
}


#
# routine to get the new amount of available drives after the trigger from TSLM
#
sub getNowAllAvailableDrives {
    foreach my $trec (@typesarr) {
        $trec->{"AmountAvailableDrivesSys"} = 0;
        foreach my $lrec (@libsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {
                $lrec->{"AmountAvailableDrives"} =
                    getAvailableDrives($lrec->{"LibraryName"},
                                       $lrec->{"Type"});

                $trec->{"AmountAvailableDrivesSys"} += $lrec->{"AmountAvailableDrives"};
            }
        }
    }
    return;
}


#
# routine to get the new amount of usable and available drives after the trigger from TSLM
#
sub getNowAllUsableAndAvailableDrives {
    foreach my $trec (@typesarr) {
        $trec->{"AmountUsableDrivesSys"} = 0;
        $trec->{"AmountAvailableDrivesSys"} = 0;
        foreach my $lrec (@libsarr) {
            if ($trec->{"Type"} eq $lrec->{"Type"}) {

                $lrec->{"AmountUsableDrives"} =
                    getUsableDrives($lrec->{"LibraryName"},
                                    $lrec->{"Type"});

                $lrec->{"AmountAvailableDrives"} =
                    getAvailableDrives($lrec->{"LibraryName"},
                                       $lrec->{"Type"});

                $trec->{"AmountUsableDrivesSys"} += $lrec->{"AmountUsableDrives"};
                $trec->{"AmountAvailableDrivesSys"} += $lrec->{"AmountAvailableDrives"};
            }
        }
    }
    return;
}

sub checkConfigLibraryArray {
    #
    # check that all libraries always exists within TSLM
    #
    my $sendstr = "show task [\"" . eRMMConfig::getTaskId() . "\"] " .
        "report [LIBRARY.\"LibraryName\"] ;";

    eRMMCom::send($sendstr);
    my $resp = eRMMCom::getResponse();
    if ($resp eq "error") {
        my $err = "Error getting Libraries from TSLM";
        eRMMCom::sendError(eRMMConfig::gettext("ERR_GET_LIB"));
        eRMMTrace::addTraceInfo($err);
        exit 1;
    }

    my @data =  eRMMCom::getKeyValueResults($resp);
    foreach my $lrec (@eRMMConfig::conflibsarr) {
        my $str = $lrec->{"LibraryName"};
        my $found = 0;
        foreach my $lib (@data) {
            if (@$lib[0] eq $str) {
                $found = 1;
                last;
            }
            else {
                next;
            }
        }
        if ($found == 0) {
            my $err = "Library:" . $str . " does not exist within TSLM";
            eRMMCom::sendError(eRMMConfig::gettext("ERR_NO_LIB", $str));
            eRMMTrace::addTraceInfo($err);
            exit 1;
        }
    }

    #
    # check that all ScratchPools always exists within TSLM
    #

    $sendstr = "show task [\"" . eRMMConfig::getTaskId() . "\"] " .
        "report [CARTRIDGEGROUP.\"CartridgeGroupName\"] " .
        "match [and( streq(CARTRIDGEGROUP.\"IsScratchPool\" \"true\") ) ];";

    eRMMCom::send($sendstr);
    my $resp = eRMMCom::getResponse();
    if ($resp eq "error") {
        my $err = "Error getting CartridgeGroups from TSLM";
        eRMMCom::sendError(eRMMConfig::gettext("ERR_GET_CG"));
        eRMMTrace::addTraceInfo($err);
        exit 1;
    }

    my @data =  eRMMCom::getKeyValueResults($resp);
    foreach my $lrec (@eRMMConfig::conflibsarr) {
        my $str = $lrec->{"GroupName"};
        my $found = 0;
        foreach my $grp (@data) {
            if (@$grp[0] eq $str) {
                $found = 1;
                last;
            }
            else {
                next;
            }
        }
        if ($found == 0) {
            my $err = "CartridgeGroup:" . $str . " does not exist within TSLM";
            eRMMCom::sendError(eRMMConfig::gettext("ERR_NO_CG", $str));
            eRMMTrace::addTraceInfo($err);
            exit 1;
        }
    }
}
