#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager 
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
#
# @version 1.1 - 12/09/02 18:47:17
#
#
# @brief audit3494  - script that monitors import/export activity and
#                     emulates 3494 behaviour
#
#-----------------------------------------------------------------------
# configuration variables
# $DEBUG - debug	>0: display debug messages
# $targetLibsMode ["ALL"|"PART"]  - scope of libraries
# $sleepTime - seconds to sleep for monitor interval
# $aiName - "Audit3494" - name of application instance

my $targetLibsMode="ALL";
my $targetLibs = "3584-1";
my $sleepTime=120;      # seconds to sleep for monitor interval
my $aiName="Audit3494";

# Turn on some print statements for debugging only..
my $DEBUG=0;

#============ don't change anything below this line ====================
#=========== unless you really know what you're doing ==================
my $cmd = "/opt/IBM/ermm/bin/ermmtool";
my @libNames;
my @carts;

#
# get target libraries
#
getLibNames();
#
# ensure Audit3494 AI exist and has admin permissions
#
my $res = `$cmd addai $aiName ERMMSystem`;
$res = `$cmd chai -adm -app ERMMSystem $aiName`;

#
# ensure Audit3494 AI is being used for all command
# so that we can trace its behaviour in the log
#
$cmd .= " -i $aiName";

my $rv;
my $cart;
my @intSlots;
my $intCount = 0;

while (1) {
	auditLibraries();
	# get all newly detected cartridges (= in NoAccess group) into @carts
	# and make them available in the inject category
	#
	getCartridges("NoAccess",@libNames);
	print "Import will start shortly\n" if $DEBUG>0;
	
	foreach $cart (@carts) {
	    my $vol = substr($cart, 0, 6);

	    print "Detected $cart in NoAccess category\n" if $DEBUG>0 ;

	    # move cartridge into inject category (CartridgeGroup 0xff00)
	    $rv = `$cmd chcart $cart -group 0xff00 `;
	    if ($rv =~ /\w{3}\d{4}\w:/) {
			$rv = `$cmd addlog -e \"$aiName: error while moving cartridge $cart to cartridgegroup 0xff00\"`;
			print "- Fail to moved $cart into cartridgegroup 0xff00 slot\n" if $DEBUG>0 ;
			# put back this cart into NoAccess group
			$rv = `$cmd chcart $cart -group NoAccess `;
	    } else {
			print "- Moved $cart into cartridgegroup 0xff00 slot\n" if $DEBUG>0 ;
			# allocate volume on cartridge
			$rv = `$cmd -c 3494LM -i 3494LM-1 lsvol $vol`;
			# If not allocated, above command fails, and it will try to allocate for 3494LM, if not pass down into ELSE...
			if ($rv =~ /\w{3}\d{4}\w:/) { $rv = `$cmd -c 3494LM -i 3494LM-1 alloc -pcl $cart $vol`; }
			if ($rv =~ /\w{3}\d{4}\w:/) {
		    	$rv = `$cmd addlog -e \"$aiName: error while allocating volume on cartridge $cart\"`;
		    	print "- Could not allocate volume $vol to 3494 Emualtor\n" if $DEBUG>0 ;
		    	# deallocate this volume if it is allocated for some reason
		    	$rv=`$cmd dealloc -app 3494LM $vol`;
		    	# put back this cart into NoAccess group
		    	$rv = `$cmd chcart $cart -group NoAccess `;
			} else {
		    	print "- Allocated volume $vol to 3494 Emualtor\n" if $DEBUG>0 ;
		    	# move volume into a storage slot
	            $rv = moveCartridgeToStorageSlot($cart);
		    	if ($rv == 0) {
					print "- Moved $cart into internal slot\n" if $DEBUG>0 ;
					$rv = `$cmd addlog -e \"$aiName: cartridge $cart imported successfully\"`;
		    	} else {
					print "- Failed to move $cart into internal slot\n" if $DEBUG>0 ;
					# move cart back into I/O is not necessary 
					# deallocate this volume if it is allocated for some reason
					$rv=`$cmd dealloc -app 3494LM $vol`;
					# put back this cart into NoAccess group
					$rv = `$cmd chcart $cart -group NoAccess `;
		    	}
			}
	    }
	}
	
	#
	# move  all cartridges in eject category into an I/O slot
	#
	getCartridges("0xff10",@libNames);
	print "There are ",scalar @carts," cartridges in 0xff10 category in the logical library $libName\n" if $DEBUG>0;

	print "Export will start shortly\n" if $DEBUG>0;
	
	foreach $cart (@carts) {
	    $rv = moveCartridgeToIOSlot($cart);
	    if ($rv == 0) {
			$rv = `$cmd addlog -e \"$aiName: cartridge $cart exported successfully\"`;
			print "- Move $cart into I/O slot\n" if $DEBUG>0 ;
	    } else {
			print "- Failed to move $cart into I/O slot\n" if $DEBUG>0 ;
	    }
	}

	#
	# get all cartridges physically removed from the library and remove them from repository
	# when cartridges are removed from the library, they will be automatically taken out of TSLM/ermmm DB..
	#
	getEjectedCartridges();
	print "There are ",scalar @carts," cartridges ejected according to the DB2 entries\n" if $DEBUG>0;
	
	foreach (@carts) {
	    my $vol;
	    s/\s//g;
	    $cart = $_;
	    $vol = substr($cart, 0, 6);

	    # deallocate volume
	    $rv = `$cmd dealloc -app 3494LM $vol`;
	    if ($rv =~ /\w{3}\d{4}\w:/) {
			$rv = `$cmd addlog -e \"$aiName: error while deallocating cartridge $cart\"`;
			print "- Failed to deallocate $vol from 3494 Emulator\n" if $DEBUG>0 ;
	    } else {
			print "- Deallocated $vol from 3494 Emulator\n" if $DEBUG>0 ;
		# remove volume from database
			$rv = `$cmd rmcart $cart`;
			if ($rv =~ /\w{3}\d{4}\w:/) {
		    	$rv = `$cmd addlog -e \"$aiName: error while removing cartridge $cart\"`;
		    	print "- Failed to remove $cart from TSLM/ermm database\n" if $DEBUG>0 ;
			} else {
		    	$rv = `$cmd addlog -e \"$aiName: cartridge $cart removed from repository\"`;
		    	print "- Remove $cart from TSLM/ermm database\n" if $DEBUG>0 ;
			}
	    }
	}

    print "Sleeping for $sleepTime seconds before auditing again. \n" if $DEBUG>0;
    # sleep before starting all over again
    sleep($sleepTime);
}

#
# get cartridges from a specific CartridgeGroup provided as parameter
# into @cart array
#    
sub getCartridges($@)
{
	my ($group, @_libNames)=@_;
    my $result, $rv;

    @carts = ();
    foreach my $libName ( @_libNames ){
    	$result = `$cmd lscart -lib $libName -s -group $group -hdr off`;
    	chomp($result);

	    # Check for error message number
    	if ($result =~ /^\w{3}\d{4}\w:/) {
			if (substr($result, 0, 8) eq "EMM7009I") {
	    		# no matching cartridges found (ignore this error)
	    		next;
			} else {
				$rv = `$cmd addlog -e \"error while executing lscart command with -lib=$libName -group=$group\"`;
	    		next;
			}
		} else {
		    my @_carts=split(/\n/,$result);
		    print "There are ",scalar @_carts," cartridges in NoAccess category in the logical library $libName\n" if $DEBUG>0; 
		    push( @carts ,@_carts );
		}
    }
    return 1;
}

#
# utilize DB2 command to get list of cartridges that have been 
# physically removed
#
sub getEjectedCartridges()
{
    my $count;

    @carts = ();
    $result = `db2 connect to ermm >/dev/null && db2 -x select cartridgepcl from m_cartridge where libraryid is null && db2 -x disconnect current >/dev/null`;

    @carts = split(/\n/,$result);

    return 0;
}

#
# move cartridge (pcl and library name provided as parameter) into 
# a storage slot inside the library if it currently
# resides in an I/O slot
#
sub moveCartridgeToStorageSlot()
{
    my $cart = shift;
    my $rv;
    my $inio = 0;

    # get slot the cartridge resides in
    $rv = `$cmd lsslot -match \"streq(Cartridge.\\\"CartridgePCL\\\" \\\"$cart\\\")\" -hdr=off`;

    # check if cartridges resides in I/O slot
    if ($rv =~ /.*\s+I\/O\s+.*/) {
		# Move to any internal slot and let the library decide on where to 
		$rv = `$cmd move -pcl $cart -tosg internal `;
		if ($rv =~ /\w{3}\d{4}\w:/) {
	    	print "-- Moving $cart into internal slot has failed.\n" if $DEBUG>0 ;
	    	$rv = `$cmd addlog -e \"$aiName: error while moving cartridge $cart to storage slot\"`;
	    	return 1;
		} else {
	    	chomp($rv);
	    	print "-- Moving $cart into internal slot is completed succesfully.\n" if $DEBUG>0 ;
	    	return 0;
		}
    } elsif ($rv =~ /.*\s+internal\s+.*/) {
		print "-- $cart is already in internal slot, skipping the move.\n" if $DEBUG>0;
		return 0;
    } else {
		return 1;
    }
}

#
# move cartridge (pcl and Library name provided as parameter) into 
# an I/O slot of the library if it currently
# resides inside the library in an ordinary storage slot
#
sub moveCartridgeToIOSlot()
{
    my $cart = shift;
    my $rv;
    my $inio = 0;

    # get slot the cartridge resides in
    $rv = `$cmd lsslot -match \"streq(Cartridge.\\\"CartridgePCL\\\" \\\"$cart\\\")\" -hdr=off`;

    # check if cartridge resides in an internal storage slot
    if ($rv =~ /.*\s+internal\s+.*/) {
		$rv = `$cmd move -pcl $cart -tosg \"I/O\" `;
		if ($rv =~ /\w{3}\d{4}\w:/) {
	    	print "-- Moving $cart into internal slot has failed.\n" if $DEBUG>0 ;
	    	$rv = `$cmd addlog -e \"$aiName: error while moving cartridge $cart to I/O slot\"`;
	    	return 1;
		} else { 
	    	print "-- Moving $cart into IO slot is completed succesfully.\n" if $DEBUG>0 ;
	    	return 0;
		}
    } elsif ($rv =~ /.*\s+I\/O\s+.*/) {
        print "-- $cart is already in I/O slot, skipping the move.\n" if $DEBUG>0;
        return 0;
    } else {
        return 1;
    }
}

#
# get target libraries
#
sub getLibNames()
{
    if ($targetLibsMode eq "ALL") {
	@libNames = `$cmd lslib --hdr off -s 2>/dev/null`;
	until ( @libNames ) {
	    print "Can not get the library names, sleeping for $sleepTime seconds before checking again\n" if $DEBUG>0;
	    sleep($sleepTime);
	    @libNames = `$cmd lslib --hdr off -s 2>/dev/null`;
	    print "Checking for available libraries\n" if $DEBUG>0;
	}
    }else{
	@libNames = split(/,/,$targetLibs);
    }
    # Remove newlines
    chomp(@libNames);


    print "Found these logical libraries:  @libNames\n" if $DEBUG>0;
}

#
# audit libraries
#
sub auditLibraries()
{
	foreach my $libName ( @libNames ) {
		print "Auditing the logical library $libName\n" if $DEBUG>0; 
		#
		# audit library
		#
		$rv = `$cmd audit $libName`;
		if ($rv =~ /\w{3}\d{4}\w:/) {
	    	$rv = `$cmd addlog -e \"$aiName: error while auditing library $libName\"`;
		}
	}
}
