#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:33:35
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::AddAi;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "addai [-v | -a | -help, -?] <ainame> <applicationname>";

#
# add application instance
#
sub addai {
    my ($result, $response, $admin);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "a"        => \$admin, # flag
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_ADDAI', $synopsis);
        exit 1;
    }

    if ($#ARGV < 2) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_ADDAI', $synopsis);
        exit 1;
    }
    elsif ($#ARGV > 2) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_ADDAI', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "create task[\"$Ermm::CLI::Conf::taskId\"] type[AI] ";

    $sendString .= "set[\"AIName\" \"$ARGV[1]\"] ";
    if ($admin) {
        $sendString .= "set[\"Privilege\" \"ADMINISTRATOR\"] ";
    }
    $sendString .= "set[\"ApplicationName\" \"$ARGV[2]\"];\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();
}

1;
