#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:33:40
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::AddCg;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "addcg [-v | -scratch | -prio | -help, -?] <cartridgegroupname>";

#
# add cartridgegroup
#
sub addcg {
    my ($result, $response, $prio);
    my $help = 0;
    my $isScratch = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "prio=i"   => \$prio, # integer
                          "scratch"  => \$isScratch,   # flag
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_ADDCG', $synopsis);
        exit 1;
    }

    if ($#ARGV == 0) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_ADDCG', $synopsis);
        exit 1;
    }
    elsif ($#ARGV > 1) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_ADDCG', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "create task[\"$Ermm::CLI::Conf::taskId\"] type[cartridgegroup]";

    if ($isScratch) {
        $sendString .= " set[\"IsScratchPool\" \"true\"]";
    }
    if ($prio) {
        if ($prio > 1000 || $prio < 0) {
            Ermm::CLI::Main::printtext('EMM7122E', $prio);
            Ermm::CLI::Main::printtext('_USAGE_ADDCG', $synopsis);
            exit 1;
        }
        $sendString .= " set[\"CartridgeGroupPriority\" \"$prio\"]";
    }
    elsif ($isScratch) {
        $sendString .= " set[\"CartridgeGroupPriority\" \"100\"]";
    }
    $sendString .= " set[\"CartridgegroupName\" \"$ARGV[1]\"];\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
