#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:33:54
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Alloc;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "alloc [-pcl <name> | -type <name> | -v | -help, -?] <volumename>";

#
# allocate a volume
#
sub alloc {
    my ($i, $result, $volname, $pcl);
    my ($response, $match, $order, $number);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "pcl=s"    => \$pcl, # string
                          "type=s"   => \$type, # string
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_ALLOC', $synopsis);
        exit 1;
    }

    if ($#ARGV < 1) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_ALLOC', $synopsis);
        exit 1;
    }
    elsif ($#ARGV > 1) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_ALLOC', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "allocate task[\"$Ermm::CLI::Conf::taskId\"]";

    $sendString .= " volname[\"$ARGV[1]\"]";

    if ($pcl) {
        $sendString .= " cartridge[\"$pcl\"]";
    }
    if ($type) {
        if (length($matchString) > 0) {
            $matchString = "and($matchString streq(Cartridge.\"CartridgeTypeName\" \"$type\"))";
        }
        else {
            $matchString = "streq(Cartridge.\"CartridgeTypeName\" \"$type\")";
        }
    }
    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
