#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.4 - 12/02/27 19:59:14
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#     - 2012-02-28: (67222) changed synopsis
#-----------------------------------------------------------------------
package Ermm::CLI::Audit;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "audit [-v | -help, -?] [ -d | -delta (-from <name> -to <name>) | -pcl <cartridgePCL>] <libname>";

#
# audit a library
#
sub audit {
    my ($i, $result);
    my ($response, $match, $order, $number);
    my ($fromSlot, $toSlot, $scanDrives, $deltaAudit);
    my ($scanSingleDrive, $slotGroup, $cartPCL, $libStatus);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "from=s"   => \$fromSlot, # string
                          "to=s"     => \$toSlot, # string
			  "d"        => \$scanDrives, # flag
			  "delta"    => \$deltaAudit, # flag
			  "pcl=s"    => \$cartPCL, # string
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_AUDIT', $synopsis);
        exit 1;
    }

    if ($#ARGV < 1) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_AUDIT', $synopsis);
        exit 1;
    }
    elsif ($#ARGV > 1) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_AUDIT', $synopsis);
        exit 1;
    }

    if ($fromSlot) {
        if (!defined $toSlot) {
            Ermm::CLI::Main::printtext('EMM7010E');
            Ermm::CLI::Main::printtext('_USAGE_AUDIT', $synopsis);
            exit 1;
        }
    }
    if ($toSlot) {
        if (!defined $fromSlot) {
            Ermm::CLI::Main::printtext('EMM7010E');
            Ermm::CLI::Main::printtext('_USAGE_AUDIT', $synopsis);
            exit 1;
        }
    }

    #
    # build send string
    #
    $sendString = "cpscan task[\"$Ermm::CLI::Conf::taskId\"]";

    $matchString = "streq(Library.\"LibraryName\" \"$ARGV[1]\")";

    if ($scanDrives) {
	$sendString .= " drive";
    }
    elsif ($scanSingleDrive) {
	$sendString .= " drive[\"$scanSingleDrive\"]";
    }
    elsif ($slotGroup) {
	$sendString .= " slotgroup[\"$slotGroup\"]";
    }
    elsif ($cartPCL) {
	$sendString .= " cartridge[\"$cartPCL\"]";
    }
    elsif ($deltaAudit) {
        $sendString .= " delta";
    }
    elsif ((defined $fromSlot) && (defined $toSlot)) {
        $sendString .= " fromSlot[\"$fromSlot\"] toSlot[\"$toSlot\"]";
    }
    elsif (!$libStatus) {
        $sendString .= " all";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

    if ($libStatus && ($response =~ m/success/i) ) {
      Ermm::CLI::Main::printtext('EMM7142I', $ARGV[1]);
    }

}
1;
