#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:38:49
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Cancel;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "cancel [-v | -help, -?] <taskId>";

#
# cancel task
#
sub cancel {
    my ($i, $result);
    my ($response);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "prio=i"   => \$prio, # integer
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CANCEL', $synopsis);
        exit 1;
    }

    if ($#ARGV < 1) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CANCEL', $synopsis);
        exit 1;
    }
    elsif ($#ARGV > 1) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_CANCEL', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "cancel task[\"$Ermm::CLI::Conf::taskId\"]";

    $sendString .= " whichtask[\"$ARGV[1]\"];\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
