#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:38:54
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChApp;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chapp [-disable | -enable | -rm | -norm | -desc <desc> | -help, -? | -match <c> | -v ] [<appname>]";

#
# change application
#
sub chapp {
    my ($i, $result, $method, $data, $remoteMount, $disable, $enable);
    my ($response, $match);
    my $help         = 0;
    my $sendString   = "";
    my $matchString  = "";
    my $descString;

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "disable"  => \$disable,                  # flag
                          "enable"   => \$enable,                   # flag
                          "rm!"      => \$remoteMount,              # flag
                          "desc=s"   => \$descString,               # string
                          "help|?"   => \$help,                     # flag
                          "match=s"  => \$match);                   # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHAPP', $synopsis);
        exit 1;
    }

    #
    # check if there are any arguments
    #
    unless ($disable || $enable || defined $remoteMount || defined $descString){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHAPP', $synopsis);
        exit 1;
    }

    #
    # add application names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Application.\"applicationname\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHAPP', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($enable) {
        $sendString .= " set[Application.\"ApplicationDisabled\" \"false\"]";
    }
    elsif ($disable) {
        $sendString .= " set[Application.\"ApplicationDisabled\" \"true\"]";
    }
    if (defined $remoteMount && $remoteMount == 1) {
        $sendString .= " set[Application.\"AllowRemoteMount\" \"true\"]";
    }
    elsif (defined $remoteMount && $remoteMount == 0) {
        $sendString .= " set[Application.\"AllowRemoteMount\" \"false\"]";
    }

    if(defined $descString) {
        $sendString .= " set[Application.\"ApplicationDescription\" \"$descString\"]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
