#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:38:56
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChCart;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chcart [-group <name> | -type <name> | -app <name> | -dealloc <name> | -regex <exp> | -help, -? | -match <c> | -order <c> | -number <c> | -v] [<pcl>]";

#
# change cartridge
#
sub chcart {
    my ($i, $result, $group, $type, $regex, $app);
    my (@dealloc, $response, $match, $order, $number);
    my $help         = 0;
    my $sendString   = "";
    my $matchString  = "";
    my $orderString  = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"          => \$Ermm::CLI::Conf::verbose, # flag
                          "regex=s"    => \$regex,   # string
                          "group=s"    => \$group,   # string
                          "app=s"      => \$app,     # string
                          "dealloc=s@" => \@dealloc, # string
                          "type=s"     => \$type,    # string
                          "help|?"     => \$help,    # flag
                          "match=s"    => \$match,   # string
                          "number=s"   => \$number,  # string
                          "order=s"    => \$order);  # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHCART', $synopsis);
        exit 1;
    }

    #
    # ckeck if there are any arguments
    #
    unless ($group || $app || @dealloc || $type){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHCART', $synopsis);
        exit 1;
    }

    #
    # add cartridgepcl to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Cartridge.\"CartridgePCL\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add regex restriction if specified
    #
    if (defined $regex) {
        $matchString = "and($matchString regex(\"$regex\" ".
            "Cartridge.\"CartridgePCL\"))";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHCART', $synopsis);
        exit 1;
    }

    if ($order) {
        $orderString = "order[$order]";
    }

    if ($number) {
        $numberString = "number[$number]";
    }

    #
    # build send string
    #
    $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($group) {
        $sendString .= " set[Cartridge.\"CartridgeGroupName\" \"$group\"]";
    }
    if ($app) {
        $sendString .= " set[Cartridge.\"ApplicationName\" \"$app\"]";
    }
    if (@dealloc) {
        my $dealloc = pop @dealloc;
        if ($dealloc ne "") {
            $sendString .= " set[Cartridge.\"DeallocGroup\" \"$dealloc\"]";
        }
        else {
            $sendString .= " unset[Cartridge.\"DeallocGroup\"]";
        }
    }
    if ($type) {
        $sendString .= " set[Cartridge.\"CartridgeTypeName\" \"$type\"]";
    }

    $sendString .= " $matchString $orderString $numberString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
