#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:39:01
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChCga;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chcga [-prio <num> | -help, -? | -match <c> | -v] [<cgaid>]";

#
# change cartridge group application
#
sub chcga {
    my ($i, $result, $prio);
    my ($response, $match);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "prio=i"   => \$prio,   # int
                          "help|?"   => \$help,   # flag
                          "match=s"  => \$match); # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHCGA', $synopsis);
        exit 1;
    }

    #
    # ckeck if there are any arguments
    #
    unless ($prio){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHCGA', $synopsis);
        exit 1;
    }

    #
    # add cg names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(CartridgeGroupApplication.\"CartridgeGroupApplicationID\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHCGA', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($prio) {
        if ($prio > 1000 || $prio < 0) {
            Ermm::CLI::Main::printtext('EMM7122E', $prio);
            Ermm::CLI::Main::printtext('_USAGE_CHCGA', $synopsis);
            exit 1;
        }
        $sendString .= " set[CartridgeGroupApplication.\"CartridgeGroupApplicationPriority\" \"$prio\"]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
