#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:39:05
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChDm;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chdm [-drive <name> | -host <h> | -mlevel <l> | -reset | -restart | rescan | -disable | -help, -? | -match <c> | -v] [<dmname>]";

#
# change drive manager
#
sub chdm {
    my ($i, $result, $method, $data, $drive, $messageLevel, $host, $reset);
    my ($response, $match, $doExit, $disable, $rescan);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "restart"  => \$doExit,       # flag
                          "reset"    => \$reset,        # flag
                          "rescan"   => \$rescan,       # flag
                          "disable"  => \$disable,      # flag
                          "drive=s"  => \$drive,        # string
                          "mlevel=s" => \$messageLevel, # string
                          "help|?"   => \$help,         # flag
                          "match=s"  => \$match,        # string
                          "host=s"   => \$host);        # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHDM', $synopsis);
        exit 1;
    }

    #
    # ckeck if there are any arguments
    #
    unless ($method || $data || $doExit || $reset ||
            $rescan || $disable || $messageLevel){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHDM', $synopsis);
        exit 1;
    }

    #
    # add dm names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(DM.\"DMName\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add drive restriction if specified
    #
    if ($drive) {
        $matchString = "and($matchString streq(DM.\"DriveName\" ".
            "\"$drive\"))";
    }

    if ($host) {
        $matchString = "and($matchString streq(DM.\"DMHost\" ".
            "\"$host\"))";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHDM', $synopsis);
        exit 1;
    }

    if ($messageLevel) {
        if (!(lc($messageLevel) =~ m/^(emergency|alert|critical|error|warning|notice|information|debug|developer)$/)) {
            Ermm::CLI::Main::printtext('EMM7124E', $messageLevel);
            Ermm::CLI::Main::printtext('_USAGE_CHDM', $synopsis);
            exit 1;
        }
    }
    if ($doExit) {
        #
        # build send string
        #
        $sendString = "cpexit task[\"$Ermm::CLI::Conf::taskId\"] cptype[dm]";
    }
    elsif ($rescan) {
        #
        # build send string
        #
        $sendString = "cpreset task[\"$Ermm::CLI::Conf::taskId\"] cptype[dm]";
    }
    else {
        #
        # build send string
        #
        $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

        if ($messageLevel) {
            $sendString .= " set[DM.\"DMMessageLevel\" \"$messageLevel\"]";
        }
        if ($method) {
            if (!(lc($method) =~ m/^(none|password)$/)) {
                Ermm::CLI::Main::printtext('EMM7124E', $method);
                Ermm::CLI::Main::printtext('_USAGE_CHDM', $synopsis);
                exit 1;
            }
            $sendString .= " set[DM.\"AuthenticationMethod\" \"$method\"]";
        }
        if ($data) {
            $sendString .= " set[DM.\"AuthenticationData\" \"$data\"]";
        }

        if ($reset) {
            $sendString .= " set[DM.\"DMStateHard\" \"ready\"]";
        }

        if ($disable) {
            $sendString .= " set[DM.\"DMStateHard\" \"broken\"]";
        }
    }
    $sendString .= " $matchString;\n";
    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

    if ($reset) {
        #
        # send command to server
        #
        Ermm::CLI::Main::send("reschedule ".
                              "task[\"$Ermm::CLI::Conf::taskId\"];\n");
      }
}

1;
