#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:39:08
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChDrive;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chdrive [-disable | -enable | -online | -offline | -broken | -fixed | -group <name> | -dm [<name>] | -prio <num> | -regex <exp> | -sn <num> | -help, -? | -match <c> | -v] [<drivename>]";

#
# change drive attribute
#
sub chdrive {
    my ($i, $result, $enable, $disable, $online, $offline, $dmname, $regex, $sn);
    my ($response, $match, $prio, $group, $broken, $fixed);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "disable"  => \$disable,  # flag
                          "enable"   => \$enable,   # flag
                          "online"   => \$online,   # flag
                          "offline"  => \$offline,  # flag
                          "broken"   => \$broken,   # flag
                          "fixed"    => \$fixed,    # flag
                          "prio=i"   => \$prio,     # integer
                          "regex=s"  => \$regex,    # string
                          "sn=s"     => \$sn,       # string
                          "dm:s"     => \$dmname,   # string
                          "help|?"   => \$help,     # flag
                          "group=s"  => \$group,    # string
                          "match=s"  => \$match);   # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHDRIVE', $synopsis);
        exit 1;
    }

    #
    # ckeck if there are any arguments
    #
    unless ($disable || $enable || $online || $offline || $broken || $fixed || $prio || $group || defined $sn || defined $dmname){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHDRIVE', $synopsis);
        exit 1;
    }

    #
    # add drive names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Drive.\"DriveName\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add regex restriction if specified
    #
    if (defined $regex) {
        $matchString = "and($matchString regex(\"$regex\" ".
            "Drive.\"DriveName\"))";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHDRIVE', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($enable) {
        $sendString .= " set[Drive.\"DriveDisabled\" \"false\"]";
    }
    elsif ($disable) {
        $sendString .= " set[Drive.\"DriveDisabled\" \"true\"]";
    }
    if ($offline) {
        $sendString .= " set[Drive.\"DriveOnline\" \"false\"]";
    }
    elsif ($online) {
        $sendString .= " set[Drive.\"DriveOnline\" \"true\"]";
    }
    if ($broken) {
        $sendString .= " set[Drive.\"DriveBroken\" \"true\"]";
    }
    elsif ($fixed) {
        $sendString .= " set[Drive.\"DriveBroken\" \"false\"]";
    }
    if (defined $dmname) {
        $sendString .= " set[Drive.\"DMName\" \"$dmname\"]";
    }
    if ($prio) {
        if ($prio > 1000 || $prio < 0) {
            Ermm::CLI::Main::printtext('EMM7122E', $prio);
            Ermm::CLI::Main::printtext('_USAGE_CHDRIVE', $synopsis);
            exit 1;
        }
        $sendString .= " set[Drive.\"DrivePriority\" \"$prio\"]";
    }
    if ($group) {
        $sendString .= " set[Drive.\"DriveGroupName\" \"$group\"]";
    }

    if (defined $sn) {
        $sendString .= " set[Drive.\"SerialNumber\" \"$sn\"]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
