#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:39:10
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChLib;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chlib [-disable | -enable | -on | -off | -lm [<name>] | -help, -? | -match <c> | -v] [<libname>]";

#
# change library
#
sub chlib {
    my ($i, $result, $enable, $disable, $online, $offline, $lmname);
    my ($response, $match);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "disable"  => \$disable,                  # flag
                          "enable"   => \$enable,                   # flag
                          "online"   => \$online,                   # flag
                          "offline"  => \$offline,                  # flag
                          "lm:s"     => \$lmname,                   # string
                          "help|?"   => \$help,                     # flag
                          "match=s"  => \$match);                   # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHLIB', $synopsis);
        exit 1;
    }

    #
    # check if there are any arguments
    #
    unless ($disable || $enable || $online || $offline || defined $lmname){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHLIB', $synopsis);
        exit 1;
    }

    #
    # add library names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Library.\"libraryname\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHLIB', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($enable) {
        $sendString .= " set[Library.\"LibraryDisabled\" \"false\"]";
    }
    elsif ($disable) {
        $sendString .= " set[Library.\"LibraryDisabled\" \"true\"]";
    }
    if ($offline) {
        $sendString .= " set[Library.\"LibraryOnline\" \"false\"]";
    }
    elsif ($online) {
        $sendString .= " set[Library.\"LibraryOnline\" \"true\"]";
    }
    if (defined $lmname) {
        $sendString .= " set[Library.\"LMName\" \"$lmname\"]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
