#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:39:15
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::ChSys;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "chsys [-llevel <l> | -dcalimit <num> | -messlimit <num> | -reqlimit <num> | -ton | -toff | -tfile <filename> | -tsize <num>[M|m|K|k] | -tnum <num> | -tlevel <level> | -von | -voff | -rlevel <level> | -help, -? | -v]";

#
# change system attribute
#
sub chsys {
    my ($i, $result);
    my ($response, $match, $prio);
    my ($ton, $off, $tfile, $tsize, $tnum, $tlevel, $von, $voff, $rlevel);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"           => \$Ermm::CLI::Conf::verbose, # flag
                          "llevel=s"    => \$messageLevel,  # string
                          "dcalimit=i"  => \$dcalimit,      # integer
                          "messlimit=i" => \$messlimit,     # integer
                          "reqlimit=i"  => \$reqlimit,      # integer
                          "ton"         => \$ton,           # flag
                          "toff"        => \$toff,          # flag
                          "tfile=s"     => \$tfile,         # string
                          "tsize=s"     => \$tsize,         # string
                          "tnum=i"      => \$tnum,          # integer
                          "tlevel=s"    => \$tlevel,        # integer
                          "von"         => \$von,           # flag
                          "voff"        => \$voff,          # flag
			  "rlevel=s"    => \$rlevel,        # integer
                          "help|?"      => \$help);         # flag


    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_CHSYS', $synopsis);
        exit 1;
    }

    #
    # ckeck if there are any arguments
    #
    unless (defined $messageLevel || defined $dcalimit || defined $messlimit ||
            defined $reqlimit || defined $ton || defined $toff || defined $tfile ||  defined $rlevel ||
            defined $tsize || defined $tnum || defined $tlevel || defined $von ||
            defined $voff){
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_CHSYS', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "attribute task[\"$Ermm::CLI::Conf::taskId\"]";

    if (defined $dcalimit) {
        if ($dcalimit < 0 || $dcalimit > 2000000) {
            Ermm::CLI::Main::printtext('EMM7124E', $dcalimit);
            Ermm::CLI::Main::printtext('_USAGE_CHSYS', $synopsis);
            exit 1;
        }
        $sendString .= " set[System.\"SystemDCALimit\" \"$dcalimit\"]";
    }
    if (defined $messlimit) {
        if ($messlimit < 0 || $messlimit > 2000000) {
            Ermm::CLI::Main::printtext('EMM7124E', $messlimit);
            Ermm::CLI::Main::printtext('_USAGE_CHSYS', $synopsis);
            exit 1;
        }
        $sendString .= " set[System.\"SystemMessageLimit\" \"$messlimit\"]";
    }
    if (defined $reqlimit) {
        if ($reqlimit < 0 || $reqlimit > 2000000) {
            Ermm::CLI::Main::printtext('EMM7124E', $reqlimit);
            Ermm::CLI::Main::printtext('_USAGE_CHSYS', $synopsis);
            exit 1;
        }
        $sendString .= " set[System.\"SystemRequestLimit\" \"$reqlimit\"]";
    }
    if (defined $messageLevel) {
        if (!(lc($messageLevel) =~ m/^(emergency|alert|critical|error|warning|notice|information|debug|developer)$/)) {
            Ermm::CLI::Main::printtext('EMM7124E', $messageLevel);
            Ermm::CLI::Main::printtext('_USAGE_CHSYS', $synopsis);
            exit 1;
        }
        $sendString .= " set[System.\"SystemLogLevel\" \"$messageLevel\"]";
    }

    #
    # version checking releated options
    #
    if (defined $von) {
        $sendString .= " set[System.\"VersionChecking\" \"enabled\"]";
    }
    if (defined $voff) {
        $sendString .= " set[System.\"VersionChecking\" \"disabled\"]";
    }

    #
    # reporting level
    #
    if (defined $rlevel) {
        $sendString .= " set[System.\"SystemReportingLevel\" \"$rlevel\"]";
    }
    
    #
    # trace releated options
    #
    if (defined $ton) {
        $sendString .= " set[System.\"Tracing\" \"enabled\"]";
    }
    if (defined $toff) {
        $sendString .= " set[System.\"Tracing\" \"disabled\"]";
    }
    if (defined $tfile) {
        $sendString .= " set[System.\"TraceFile\" \"$tfile\"]";
    }
    if (defined $tsize) {
        $sendString .= " set[System.\"TraceFileSize\" \"$tsize\"]";
    }
    if (defined $tnum) {
        $sendString .= " set[System.\"NumTraceFiles\" \"$tnum\"]";
    }
    if (defined $tlevel) {
        $sendString .= " set[System.\"TraceLevel\" \"$tlevel\"]";
    }

    $sendString .= " match[regex(\".*\" System.\"SystemId\")];\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
