#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:39:23
#
# @brief
#
#   Module with TSLM CLI specific configuration options
#
#-----------------------------------------------------------------------

package Ermm::CLI::Conf;

#
# set configuration file name.
#
$configname = "ermmcli.conf";

#
# set default values for options
#
$host = 'localhost';
$port   = 6740;
$client = 'ERMMSystem';
$instance = 'ERMMAdmin';
$authMethod = 'none';
$password = "";
$taskId = 'cli1';
$verbose = 0;
$debug = 0;
$language = 'en';
$country = 'us';

#
# default output format is delimited by ' '
#
$format = "delim";
$delimiter = " ";
$console = 0;

#
# no header is printed by default
#
$header = 0;

#
# max. number of objects printed when no number clause is given
#
$objlimit = 32;

#
# Default time in seconds to wait for checking network connectivity
# (ping) of media manager host (timeout=0 disables the check).
#
$timeout = 0;

#
# default one shot mode.
#
$mode = 0;

#
# Enable/disable IPv6 support (default disabled)
#
$ipv6support = 0;


#---------------------------------------------------------------------
#
# Setup configuration variables.
#
#---------------------------------------------------------------------
sub readConfFile
{
  my @conffiles = ();

#
# Configuration file on Windows platform
#
  if ($^O =~ /.*win32.*/i)  {
	push (@conffiles, $ENV{IBMCLICONFIGFILE}."\\".$Ermm::CLI::Conf::configname);
  }
  else {  
#
# Configuration file in /etc is used first.
#
    if ( -e "/etc/".$Ermm::CLI::Conf::configname) {
      push(@conffiles, "/etc/".$Ermm::CLI::Conf::configname);
    }
#
# Configuration file in home directory is used second.
#
    if ( -e $ENV{HOME}."/".".".$Ermm::CLI::Conf::configname) {
      push(@conffiles, $ENV{HOME}."/".".".$Ermm::CLI::Conf::configname);
    }
  }
#
# Setup variables from each config file.
#
  foreach $conffile (@conffiles) {

    open(CONFFILE, "$conffile");
    while(<CONFFILE>) {

      my $var = "";
      my $val = "";

      chomp();
#
# Check if the string in the config file is of the format VARIABLE=VALUE or VARIABLE="VALUE".
#
      if(m/^\s*(\w+)\s*=\s*((?:\".*?\")|(?:[^\"]*?))\s*$/g) {

        $var = $1;
        $val = $2;
        $val =~ s/^\"(.*)\"$/$1/;                                     # remove double ticks
      }

#
# Setup HOST variable.
#
      if($var =~ m/^\s*HOST\s*$/i) {
        $Ermm::CLI::Conf::host = $val;
      }
#
# Setup PORT variable.
#
      elsif($var =~ m/^\s*PORT\s*$/i) {
        $Ermm::CLI::Conf::port = $val;
      }
#
# Setup CLIENT variable.
#
      elsif($var =~ m/^\s*CLIENT\s*$/i) {
        $Ermm::CLI::Conf::client = $val;
      }
#
# Setup INSTANCE variable.
#
      elsif($var =~ m/^\s*INSTANCE\s*$/i) {
        $Ermm::CLI::Conf::instance = $val;
      }
#
# Setup PASSWORD variable.
#
      elsif($var =~ m/^\s*PASSWORD\s*$/i) {
        $Ermm::CLI::Conf::password = $val;
      }
#
# Setup AUTHMETHOD variable.
#
      elsif($var =~ m/^\s*AUTHMETHOD\s*$/i) {
        $Ermm::CLI::Conf::authMethod = $val;
      }
#
# Setup TASKID variable.
#
      elsif($var =~ m/^\s*TASKID\s*$/i) {
        $Ermm::CLI::Conf::taskId = $val;
      }
#
# Setup VERBOSE variable.
#
      elsif($var =~ m/^\s*VERBOSE\s*$/i) {
        $Ermm::CLI::Conf::verbose = $val;
      }
#
# Setup DEBUG variable.
#
      elsif($var =~ m/^\s*DEBUG\s*$/i) {
        $Ermm::CLI::Conf::debug = $val;
      }
#
# Setup LOCALE variables.
#
      elsif($var =~ m/^\s*COUNTRY\s*$/i) {
        $Ermm::CLI::Conf::country = $val;
      }
      elsif($var =~ m/^\s*LANGUAGE\s*$/i) {
        $Ermm::CLI::Conf::language = $val;
      }
#
# Setup FORMAT variable.
#
      elsif($var =~ m/^\s*FORMAT\s*$/i) {
        $Ermm::CLI::Conf::format = $val;
      }
#
# Setup DELIMITER variable.
#
      elsif($var =~ m/^\s*DELIMITER\s*$/i) {
        $Ermm::CLI::Conf::delimiter = $val;
      }
#
# Setup HEADER variable.
#
      elsif($var =~ m/^\s*HEADER\s*$/i) {
        $Ermm::CLI::Conf::header = $val;
      }
#
# Setup OBJLIMIT variable.
#
      elsif($var =~ m/^\s*OBJLIMIT\s*$/i) {
        $Ermm::CLI::Conf::objlimit = $val;
      }
#
# Setup TIMEOUT variable.
#
      elsif($var =~ m/^\s*TIMEOUT\s*$/i) {
        $Ermm::CLI::Conf::timeout = $val;
      }
#
# Setup IPv6 support variable.
#
      elsif($var =~ m/^\s*IPV6SUPPORT\s*$/i) {
        $Ermm::CLI::Conf::ipv6support = $val;
      }
#
# Setup APPLICATIONSERVER variable.
#
      elsif($var =~ m/^\s*APPLICATIONSERVER\s*$/i) {
        $Ermm::CLI::Conf::applicationServer = $val;
      }
#
# Setup APPLICATIONUSERID variable.
#
      elsif($var =~ m/^\s*APPLICATIONUSERID\s*$/i) {
         $Ermm::CLI::Conf::applicationUserid = $val;
      }
#
# Setup APPLICATIONPASSWORD variable.
#
      elsif($var =~ m/^\s*APPLICATIONPASSWORD\s*$/i) {
        $Ermm::CLI::Conf::applicationPassword = $val;
      }
#
# Setup DFSMSRMMSERVERIP variable.
#
      elsif($var =~ m/^\s*DFSMSRMMSERVERIP\s*$/i) {
        $Ermm::CLI::Conf::dfsmsRmmServerIp = $val;
      }
#
# Setup DFSMSRMMSERVERPORT variable.
#
      elsif($var =~ m/^\s*DFSMSRMMSERVERPORT\s*$/i) {
        $Ermm::CLI::Conf::dfsmsRmmServerPort = $val;
      }
#
# Setup DFSMSRMMOWNER variable.
#
      elsif($var =~ m/^\s*DFSMSRMMOWNER\s*$/i) {
        $Ermm::CLI::Conf::dfsmsRmmOwner = $val;
      }
#
# Setup DFSMSRMMDEFAULTLOCATION variable.
#
      elsif($var =~ m/^\s*DFSMSRMMDEFAULTLOCATION\s*$/i) {
        $Ermm::CLI::Conf::dfsmsRmmDefaultLocation = $val;
      }
#
# Setup DFSMSRMMMAXRETPD variable.
#
      elsif($var =~ m/^\s*DFSMSRMMMAXRETPD\s*$/i) {
        $Ermm::CLI::Conf::dfsmsRmmMaxRetpd = uc($val);
      }
    }
    close(CONFFILE);
  }
}

1;
