#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:41:20
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Dealloc;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "dealloc <volumename> -app <name> [-help, -? | -v] [volumename]";

#
# deallocate a volume
#
sub dealloc {
    my ($i, $result, $volname, $application);
    my ($response, $match, $order, $number);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "app=s"    => \$application, # string
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_DEALLOC', $synopsis);
        exit 1;
    }
    if ( ($#ARGV < 1) || (!$application) ) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_DEALLOC', $synopsis);
        exit 1;
    }
    #
    # build send string
    #
    $sendString = "deallocate task[\"$Ermm::CLI::Conf::taskId\"] ";

    #
    # add volume names to deallocate
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(VOLUME.\"VolumeName\" \"$ARGV[$i]\")";
    }
    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add application restriction if specified
    #
    if ($application) {
        $matchString = "and($matchString streq(VOLUME.\"ApplicationName\" ".
            "\"$application\"))";
    }

    $sendString .= "match[$matchString];\n";
    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
