#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:58:19
#
# @brief
#
# Change activities:
#     - 2005-05-09: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Eject;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "eject [-sg slotgroup | -lib library | -st slottype | -v | -help, -? ] cartridges";

sub eject {
    #
    # process command line options
    #
    my ($slotgroup, $library, $help);
    my $slottype='3480';
    my $result = GetOptions ("sg=s"     => \$slotgroup,
                             "lib=s"    => \$library,
                             "st=s"     => \$slottype,
                             "v"        => \$Ermm::CLI::Conf::verbose, # flag
                             "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_EJECT', $synopsis);
        exit 1;
    }

    if ($#ARGV < 1) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_EJECT', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    my $sendString = "eject task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($slotgroup) {
        $sendString .= " slotgroup [\"$slotgroup\"]";
    }

    foreach (1 .. $#ARGV) {
        $sendString .= " cart [\"$ARGV[$_]\" \"$slottype\"]";
    }

    my $matchString='';
    if ($library) {
        if (length($matchString) > 0) {
            $matchString = "and($matchString streq(Library.\"LibraryName\" \"$library\"))";
        }
        else {
            $matchString = "streq(Library.\"LibraryName\" \"$library\")";
        }
    }
    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }

    $sendString .= " $matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
