#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:48:42
#
# @brief
#
# Change activities:
#     - 2011-02-09: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::LsLibCon;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "lslibcon [-v | -help, -? | -fmt [xml|stanza|delim=c]] [-library <libname>] ";

#
# list library
#
sub lslibcon {
    my ($i, $longOutput, $shortOutput, $ermmOutput, $result);
    my ($response, $match, $order, $number);
    my $help = 0;
    my $matchString = "";
    my $reportmode = "";
    my $reportString = "";
    my $flag = "";

    #
    # get defaults from configuration
    #
    my $format = $Ermm::CLI::Conf::format;
    my $delimiter = $Ermm::CLI::Conf::delimiter;
    my $header = $Ermm::CLI::Conf::header;

    #
    # the classname for xml output
    #
    my $className = "Library";

    #
    # attributes listed by default
    #
    my $defaultReport =
        " Library.\"LibraryName\" ".
        " Library.\"ConnectedLibraryList\" ";

    #
    # attribute names on headline
    #
    my @propNames = ("Name", "ConnectedLibraryList");

    #
    # attribute types
    #
    my @typeNames = ("string", "string");

    #
    # process command line options
    #
    $result = GetOptions ("l"        => \$longOutput, # flag
                          "v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "fmt=s"    => \$format, # string
                          "help|?"   => \$help,   # flag
                          "library=s" => \$libname); # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_LSLIBCON', $synopsis);
        exit 1;
    }

    #
    # check header option
    #
    if ($header eq "on" || $header eq "yes") {
        $header = 1;
    }

    #
    # get delimiter from -fmt option
    #
    if ($format =~ /^delim=(.*)/) {
        $format = "delim";
        $delimiter = $1;
    }

    #
    # add application names to match clause
    #
    if ($libname){
       $matchString .= "streq(Library.\"LibraryName\" \"$libname\")";
    }
    #
    # build report string
    #
    if ($ermmOutput) {
        $reportString .= "$className";
        $reportmode = "namevalue";
    }
    else {
        $reportString .= $defaultReport;
    }

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # if number is not specified, print total number of objects.
    #
    if (!$flag) {
      my $sendString = Ermm::CLI::Main::composeMMPShow($Ermm::CLI::Conf::taskId,
                                                       "$matchString",
                                                       "",
                                                       "",
                                                       $reportString,
                                                       "number");

      Ermm::CLI::Main::send($sendString);
      $response = Ermm::CLI::Main::getResponse();

      #
      # get total number of objects.
      #
      @values = Ermm::CLI::Main::getKeyValueResults($response);

      if ( ($#values < 0) || ($values[0][0] < 1) ) {
          Ermm::CLI::Main::printtext('EMM7009I');
          exit;
      }
    }
    my $records = $values[0][0];
    my $recread = 0;

    #
    # send command to server
    #
    Ermm::CLI::Main::sendMMPShow($Ermm::CLI::Conf::taskId,
                                 "$matchString",
                                 "",
                                 "",
                                 $reportString,
                                 $reportmode);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

    #
    # Begin loop
    #
    do {
        if ($ermmOutput) {
          #
          # -x option specified; print raw TSLM output
          #
          print $response,"\n";
        }
        else {
          #
          # start normal output processing
          #
          @values = Ermm::CLI::Main::getKeyValueResults($response);

          if ($#values < 0) {
              exit;
          }
          Ermm::CLI::Main::printResults($format, $delimiter, $header, $className,
                                      \@propNames, \@typeNames, \@values);
        }
        $recread += $Ermm::CLI::Conf::objlimit;
        if ($recread >= $records) {
            $flag = "q";
        }

        #
        # Get next part of response
        #
        if (!$flag) {
          Ermm::CLI::Main::nextMMPShowPart();
          #
          # receive response from server
          #
          $response = Ermm::CLI::Main::getResponse();

          #
          # Check if response has values
          #
            if ($response =~ m/text\s*\[.+\]/) {
              if ($Ermm::CLI::Conf::mode) {
                $flag = " ";
              }
              else {
                $flag = "";
              }
            }
            else {
              $flag = "q";
            }

          #
          # Prompt continue or quit
          #
            while ($flag ne "" && $flag ne "q") {
              Ermm::CLI::Main::printtext('CLIMSG_PROMT');
              $flag = <STDIN>;
              chomp $flag;
            }
        }

    }  while (!$flag)
}

1;
