#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.5 - 12/01/24 02:06:14
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Mount;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "mount [-b | -where <ipadr> | -ro | -drive <drivename> -help, -? | -v] <volumename> | -pcl <cartridge>";

#
# mount a volume
#
sub mount {
    my ($i, $result);
    my ($response, $match, $order, $number, $drive, $pcl);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "b"        => \$block, # flag
                          "where=s"  => \$where, # string
                          "ro"       => \$readonly, # flag
                          "drive=s"  => \$drive, # string
                          "pcl=s"    => \$pcl,   # string
                          "access=s" => \$access, #string
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_MOUNT', $synopsis);
        exit 1;
    }

    if ($#ARGV < 1 && !defined $pcl) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_MOUNT', $synopsis);
        exit 1;
    }
    elsif ($#ARGV > 1) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_MOUNT', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "mount task[\"$Ermm::CLI::Conf::taskId\"]";

	if ($readonly) {
		$sendString .= " accessmode[\"readonly\"]";
	}
    if (!defined $pcl) {
	$sendString .= " volname[\"$ARGV[1]\"]";
    }
    else {
	$sendString .= " type[PARTITION]";
	$sendString .= " match[streq(Cartridge.\"CartridgePCL\" \"$pcl\")]";
    }

    if ($where) {
        $sendString .= " where[\"$where\"]";
    }
    if ($block) {
        $sendString .= " when[blocking]";
    }
    if ($drive) {
        $sendString .= " drive[\"$drive\"]";
    }
    $sendString .= ";\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();
}

1;
