#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.5 - 12/04/03 02:53:19
#
# @brief ermmtool - TSLM command line interface
# 
# 67548 2012/04/03 mkamiya - changed synopsis
#--------------------------------------------------------------------

package Ermm::CLI::Move;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "move -pcl <pcl> [[[-lib <libraryname>] -toslot <slot>] | [-tosg <slot_group>]] [ -help, -? | -v]";

sub move {

    #
    # process command line options
    #
    my ($pcl, $lib, $toslot, $help);
    my $slottype="3480";

    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "pcl=s"    => \$pcl,                      # string
			  "lib=s"    => \$lib,                      # string
                          "toslot=s" => \$toslot,                   # string
                          "tosg=s"   => \$toslotgroup,              # string
                          "help|?"   => \$help);                    # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_MOVE', $synopsis);
        exit 1;
    }

    unless ( (defined $pcl) && (defined $toslot || (defined $toslotgroup && !defined $lib)) ) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_MOVE', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    my $sendString = "move task[\"$Ermm::CLI::Conf::taskId\"]";

    if($pcl) {
        $sendString .= " cart [\"$pcl\" \"$slottype\" \"Side 1\"]";
    }

    if($lib) {
	$sendString .= " libslot [\"$lib\" \"$toslot\"]"; 
    }elsif($toslot) {
        $sendString .= " toslot [\"$toslot\"]";
    }

    if($toslotgroup) {
        $sendString .= " toslotgroup[\"$toslotgroup\"]";
    }

    $sendString .= " ;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();
}

1;
