#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 02:08:07
#
# @brief
#
# Change activities:
#     - 2005-02-08: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::NotifyMsg;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;
use Getopt::Long;

$synopsis = "addlog [-v | -help, -?] <message> <level option>";

#
# notify Message to MM
#
sub notifyMsg {
    my $type = shift;
    my $msg = "";
    my $informational;
    my $notice;
    my $warning;
    my $error;
    my $result = "";
    my $msgId = "";
    my $sev ="";
    my $args = "";
    my $response = "";
    my $sendString = "";

    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "i"        => \$informational, # flag
                          "n"        => \$notice, # flag
                          "w"        => \$warning, # flag
                          "e"        => \$error, # flag
                          "help|?"   => \$help);   # flag

    if ($type eq "connect") {
        $msgId = "EMM1831I";
        $sev = "information";
        $args= "arguments[\"Key\" \"$Ermm::CLI::Conf::client\"";
        $args .= " \"Key\" \"$Ermm::CLI::Conf::instance\"]";
    }
    elsif ($type eq "disconnect") {
        $msgId = "EMM1832I";
        $sev = "information";
        $args= "arguments[\"Key\" \"$Ermm::CLI::Conf::client\"";
        $args .= " \"Key\" \"$Ermm::CLI::Conf::instance\"]";
    }
    else {
        #
        # check if we should print usage infos
        #
        if ($result != 1 || $help == 1) {
            Ermm::CLI::Main::printtext('_USAGE_NOTIFYMSG', $synopsis);
            exit 1;
        }

        if ($#ARGV < 1) {
            Ermm::CLI::Main::printtext('EMM7010E');
            Ermm::CLI::Main::printtext('_USAGE_NOTIFYMSG', $synopsis);
            exit 1;
        }
        elsif ($#ARGV > 1) {
            Ermm::CLI::Main::printtext('EMM7011E');
            Ermm::CLI::Main::printtext('_USAGE_NOTIFYMSG', $synopsis);
            exit 1;
        }
        $msg = $ARGV[1];
        if ($informational) {
            $msgId = "EMM7001I";
            $sev = "information";
        }
        elsif ($notice) {
            $msgId = "EMM7001I";
            $sev = "notice";
        }
        elsif ($warning) {
            $msgId = "EMM7001W";
            $sev = "warning";
        }
        elsif ($error) {
            $msgId = "EMM7001E";
            $sev = "error";
        }
        else {
            Ermm::CLI::Main::printtext('EMM7012E');
        }
        $args= "arguments[\"Key\" \"$msg\"]";
    }


    #
    # build send string
    #
    $sendString = "message task[\"$Ermm::CLI::Conf::taskId\"]";
    $sendString .= " severity [\"$sev\"]";
    $sendString .= " message [ id[\"IBM\" \"TSLM\" \"$msgId\"]";
    $sendString .= " $args ];\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
