#!usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:54:38
#
# @brief
#
# Change activities:
#     - 2004-10-26: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Register;

use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

if ($^O =~ /.*win32.*/i) {
  require Win32::Process;
}

#
# register message console
#
sub register {

    # Do not buffer stdout to allow reading the output e.g. via a pipe
    $|=1;

    #
    # build send string
    #
    my $pid;
    if ($^O =~ /.*win32.*/i) {
      $pid = Win32::Process::GetCurrentProcessID();
    } else {
      $pid = getppid();
    }
    my $sendString = "register task[\"console:$pid\"] ".
        "type[\"event\" \"command:message\" \"always\"];\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    Ermm::CLI::Main::getResponse();

    my $cancelled = 0;
    while(!$cancelled) {
        my $notif = Ermm::CLI::Main::getNotification();
        my ($sec, $min, $hour, $mday, $mon, $year) = localtime();
        my $t = sprintf("%04d-%02d-%02dT%02d:%02d:%02d", $year+1900, $mon+1,
                        $mday, $hour, $min, $sec);

        if ($notif =~ /.*severity\s*\[\s*\\\"error\\\".*loctext\s*\[\s*\\\"([^\\]+).*/) {
            print "$t $1\n";
        }
        elsif ($notif =~ /.*severity\s*\[\s*\\\"warning\\\".*loctext\s*\[\s*\\\"([^\\]+).*/) {
	    print "$t $1\n";
	}
        elsif ($notif =~ /.*severity\s*\[\s*\\\"information\\\".*loctext\s*\[\s*\\\"([^\\]+).*/) {
	    print "$t $1\n";
	}
        elsif ($notif =~ /.*severity\s*\[\s*\\\"notice\\\".*loctext\s*\[\s*\\\"([^\\]+).*/) {
	    print "$t $1\n";
	}
        elsif ($notif =~ /\s*response\s+.*cancelled.*/) {
            Ermm::CLI::Main::printtext('CLICONSMSG1001I', $t);
            $cancelled = 1;
        }
    }
}

1;
