#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:54:40
#
# @brief
#
# Change activities:
#     - 2005-05-09: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Release;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "release [-match <c> | -v | -help, -? | <request-ids>]";

sub release {

    #
    # process command line options
    #
    my ($match, $type, $help);
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "match=s"  => \$match, # string
                          "type=s"   => \$type, # string
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_RELEASE', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    my $sendString = "release task[\"$Ermm::CLI::Conf::taskId\"]";

    if($#ARGV>0) {
        my $reqids;
        foreach (1 .. $#ARGV) {
            $reqids .= " \"$ARGV[$_]\"";
        }
        $sendString .= " reqid [$reqids ]";
    }

    if ($match) {
        $sendString .= " match [$match]";
    }

    $sendString .= ';';

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
