#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:54:44
#
# @brief
#
# Change activities:
#     - 2007-02-16: Initial version RW
#
#-----------------------------------------------------------------------

package Ermm::CLI::Resched;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

my $nextTasksLower = 1;
my $nextTasksUpper = 1000;

$synopsis = "reschedule [-lib <name> | -app <name> [ -ai <name> ] [-nextTasks <$nextTasksLower..$nextTasksUpper>] | -task <taskId>] [-v | -help, -?]";

#
# reschedule blocked tasks
#
sub reschedule {
    my ($result, $lib, $app, $ai, $taskID, $nextTasks, $response);
    my $help = 0;
    my $sendString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"           => \$Ermm::CLI::Conf::verbose, # flag
                          "lib=s"       => \$lib, # string
                          "app=s"       => \$app, # string
                          "ai=s"        => \$ai, # string
                          "task=s"      => \$taskID, # string
                          "nextTasks=i" => \$nextTasks, # numeric
                          "help|?"      => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_RESCHED', $synopsis, $nextTasksLower, $nextTasksUpper);
        exit 1;
    }

    #
    # some additional paramter checking
    #
    if (!$lib && !$app && !$taskID) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_RESCHED', $synopsis, $nextTasksLower, $nextTasksUpper);
        exit 1;
    }
    if (($lib && ($app || $taskID)) || ($app && $taskID)) {
        Ermm::CLI::Main::printtext('EMM7130E');
        Ermm::CLI::Main::printtext('_USAGE_RESCHED', $synopsism, $nextTasksLower, $nextTasksUpper);
        exit 1;
    }
    if ($ai && !$app) {
        Ermm::CLI::Main::printtext('EMM7131E', $i);
        Ermm::CLI::Main::printtext('_USAGE_RESCHED', $synopsis, $nextTasksLower, $nextTasksUpper);
        exit 1;
    }
    if ($nextTasks && !($lib || $app || ($app && $ai))) {
        Ermm::CLI::Main::printtext('EMM7132E');
        Ermm::CLI::Main::printtext('_USAGE_RESCHED', $synopsis, $nextTasksLower, $nextTasksUpper);
        exit 1;
    }
    if ((defined $nextTasks) &&
        (($nextTasks < $nextTasksLower) || ($nextTasks > $nextTasksUpper)) ) {
        Ermm::CLI::Main::printtext('EMM7133E', $nextTasksLower, $nextTasksUpper);
        Ermm::CLI::Main::printtext('_USAGE_RESCHED', $synopsis, $nextTasksLower, $nextTasksUpper);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "reschedule task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($lib) {
        $sendString .= " library[\"$lib\"]";
    }
    if ($app && !$ai) {
        $sendString .= " application[\"$app\"]";
    }
    if ($ai && $app) {
        $sendString .= " application[\"$app\"] ai[\"$ai\"]";
    }
    if ($nextTasks) {
        $sendString .= " whichtasks[\"$nextTasks\"]";
    }
    if ($taskID) {
        $sendString .= " whichtaskid[\"$taskID\"]";
    }

    $sendString .= ";\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
