#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:54:49
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::RmAi;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "rmai <ainame> -app <name> [-v | -help, -? | -regex <x> | -match <c>]";

#
# remove application instance
#
sub rmai {
    my ($i, $regex, $result);
    my ($response, $match, $application);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "regex=s"  => \$regex,       # string
                          "app=s"    => \$application, # string
                          "help|?"   => \$help,        # flag
                          "match=s"  => \$match);      # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_RMAI', $synopsis);
        exit 1;
    }
    if (!(($#ARGV && $application) || $match)) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_RMAI', $synopsis);
        exit 1;
    }

    #
    # add ai names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "regex(\"^$ARGV[$i](\:[0-9].*)?\$\" AI.\"AIName\" )";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add application restriction if specified
    #
    if ($application) {
        $matchString = "and($matchString streq(AI.\"ApplicationName\" ".
            "\"$application\"))";
    }

    #
    # add regex name restriction if specified
    #
    if (defined $regex) {
        $matchString = "and($matchString ".
            "regex(\"$regex\" AI.\"AIName\"))";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_RMAI', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "delete task[\"$Ermm::CLI::Conf::taskId\"] type[AI] ";

    $sendString .= "$matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
