#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:55:18
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::RmSlot;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "rmslot -lib <name> [<slotname>] [-v | -regex <x> | -help, -? | -match <c>]";

#
# remove library slot
#
sub rmslot {
    my ($i, $regex, $result);
    my ($response, $match, $library);
    my $help        = 0;
    my $sendString  = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "help|?"   => \$help,     # flag
                          "regex=s"  => \$regex,    # string
                          "lib=s"    => \$library,  # string
                          "match=s"  => \$match);   # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_RMSLOT', $synopsis);
        exit 1;
    }
    if (!($library || $match)) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_RMSLOT', $synopsis);
        exit 1;
    }

    #
    # add slot names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Slot.\"SlotName\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add library restriction if specified
    #
    if ($library) {
        $matchString = "and($matchString streq(Slot.\"LibraryName\" ".
            "\"$library\"))";
    }

    #
    # add regex name restriction if specified
    #
    if (defined $regex) {
        $matchString = "and($matchString ".
            "regex(\"$regex\" Slot.\"SlotName\"))";
    }

    if (length($matchString) > 0) {
        $matchString = "match[$matchString]";
    }
    else {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_RMSLOT', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "delete task[\"$Ermm::CLI::Conf::taskId\"] type[Slot] ";

    $sendString .= "$matchString;\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
