#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 02:10:03
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Shutdown;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "shutdown [-help, -? | -nnm | -v]";

#
# shutdown
#
sub shutdown {
    my ($i, $result, $noNewMount);
    my ($response);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "nnm"      => \$noNewMount, # flag
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_SHUTDOWN', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "shutdown task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($noNewMount) {
        $sendString .= " type[\"nonewmounts\"]";
    }
    else {
        $sendString .= " type[\"force\"]";
    }
    $sendString .= ";\n";

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}

1;
