#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 02:10:05
#
# @brief
#
# Change activities:
#     - 2005-06-22: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::TecAdapt;
use Getopt::Long;
use Term::ReadLine;
use Sys::Hostname;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

if ($^O =~ /.*win32.*/i) {
  require Win32::Process;
}

$synopsis = "tecadapt [ -v | -help | -? ]";

sub tecadapt {
    my ($help);
    my $result = GetOptions ("v"          => \$Ermm::CLI::Conf::verbose,
                             "help|?"     => \$help);

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_TECADAPT', $synopsis);
        exit 1;
    }

    my $tecconf="/opt/IBM/ermm/conf/tecadapt.conf";
    my $pid;
    if ($^O =~ /.*win32.*/i) {
      $pid = Win32::Process::GetCurrentProcessID();
    } else {
      $pid = getppid();
    }

    my $hostname = hostname();
    my $sendString = "register task [\"console:$pid\"] " .
      'type ["command:message" "always"] ' .
      'number [FIRST] order [ strhilo(Message."MessageTimeCreated") ] ' .
      'report [ Message."MessageSenderType" Message."MessageSenderName" ' .
      ' Message."MessageSenderInstance" Message."MessageText" ' .
      ' Message."MessageTimeCreated" Message."MessageLevel" ' .
      ' Message."MessageId" ] ;' . "\n";

    my %sevmap = ( 'emergency' => 'FATAL', 'alert' => 'CRITICAL',
                   'critical' => 'CRITICAL', 'error' => 'MINOR',
                   'warning' => 'WARNING', 'notice' => 'HARMLESS',
                   'information' => 'HARMLESS', 'debug' => 'HARMLESS',
                   'developer' => 'HARMLESS' );

    Ermm::CLI::Main::connect();
    Ermm::CLI::Main::send($sendString);
    Ermm::CLI::Main::getResponse();

    unless(stat($tecconf)) {
	Ermm::CLI::Main::printtext('EMM7134E', $tecconf);
        exit 1;
    }

    my $cancelled = 0;
    while(!$cancelled) {
        my $notif = Ermm::CLI::Main::getNotification();
        if($notif =~ /^notification/) {
            my($type, $name, $instance, $text, $time, $level, $id)
              = $notif=~/text\s*\[\s*"([^"]*)"\s*"([^"]*)"\s*"([^"]*)"\s*"([^"]*)"\s*"([^"]*)"\s*"([^"]*)"\s*"([^"]*)"\s*\]/;

            # Reformat timestamp to yyyy-mm-dd hh:mm:ss.mmm
            my($year, $month, $day, $hour, $minute, $second, $millisecond)
              = $time=~/(\d+)\s(\d+)\s(\d+)\s(\d+)\s(\d+)\s(\d+)\s(\d+)/;
            $time = sprintf("%04d-%02d-%02d %02d:%02d:%02d.%03d",
                            $year, $month, $day, $hour, $minute, $second, $millisecond);

            # Due to HDM drive names are usually incorrect, so omit them here.
            $name = '' if $type eq 'dm';

            $severity=$sevmap{$level};

            if($Ermm::CLI::Conf::verbose) {
		Ermm::CLI::Main::printtext('CLIVMSG1009I', $type, $name, $instance, $text, $level, $severity, $id, $hostame, $time);
            }

            @args = ("postzmsg", "-f", $tecconf,
                     "sub_source=$type", "origin=$name", "sub_origin=$instance",
                     "severity=$severity", "msg=$text", "date=$time",
                     "adapter_host=$hostname", "IEEE1244_severity=$level",
                     "IEEE1244_uuid=$id",
                     "TSLM", "TSLM");
            system(@args);

            if ($? == -1) {
                Ermm::CLI::Main::printtext('EMM7135E', $!);
                exit 2;
            } elsif ($? & 127) {
		Ermm::CLI::Main::printtext('CLIVMSG1011I', ($? & 127), ($? & 128));                 
            } else {
                if($Ermm::CLI::Conf::verbose) {
	            Ermm::CLI::Main::printtext('CLIVMSG1012I',$? >> 8);                    
                }
            }
        }
    }
}

1;
