#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 02:10:07
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::Unmount;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "unmount [-help, -? | -v] [<volumename> | -d <drivename> | -t <clienttask>]";

#
# unmount a volume
#
sub unmount {
    my ($i, $result, $drive, $clienttask);
    my ($response, $match, $order, $number);
    my $help = 0;
    my $sendString = "";
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";

    #
    # process command line options
    #
    $result = GetOptions ("v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "d"        => \$drive, # flag
                          "t"        => \$clienttask, # flag
                          "help|?"   => \$help);   # flag

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_UNMOUNT', $synopsis);
        exit 1;
    }

    if ($#ARGV < 1) {
        Ermm::CLI::Main::printtext('EMM7010E');
        Ermm::CLI::Main::printtext('_USAGE_UNMOUNT', $synopsis);
        exit 1;
    }
    elsif (($#ARGV > 1) && ($drive == 1)) {
        Ermm::CLI::Main::printtext('EMM7011E');
        Ermm::CLI::Main::printtext('_USAGE_UNMOUNT', $synopsis);
        exit 1;
    }

    #
    # build send string
    #
    $sendString = "unmount task[\"$Ermm::CLI::Conf::taskId\"]";

    if ($drive == 1) {
        $sendString .= " type[DRIVE] ".
            "match[streq(Drive.\"DriveName\"\"$ARGV[1]\")];\n";
    }
    elsif ($clienttask == 1) {
        $sendString .= " type[CLIENTTASK] ".
            "match[streq(TASK.\"ClientTaskId\"\"$ARGV[1]\")];\n";
    }
    else {
        $sendString .= " volname[ ";
        for $i (1..$#ARGV) {
          $sendString .= "\"$ARGV[$i]\" "
        }
        $sendString .= "];\n";
    }

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # send command to server
    #
    Ermm::CLI::Main::send($sendString);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

}
1;
