#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2006, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/26 00:50:45
#
# @brief eRMMConfig.pm - TSLM Libray Balance Configuration Module
#
#-----------------------------------------------------------------------

package eRMMConfig;

use 5.005;

use XML::Parser;
use nls::lb_L10N;

#
# global config variables
#
$mmtracepath = "";
$mmtracefile = "";
$mmtracelevel = 0;
$mmhostname = "";
$mmportnumber = "";
$mmclientapplication = "";
$mmclientappinstance = "";
$mmclientpassword = "";
$mmclientauthmethod = "";
$mmtaskid = "";

$lbavailabledrivesweightfactor = 0;
$lbusabledrivesweightfactor = 0;
$lbroundrobinvalueweightfactor = 0;

$lbtriggercount = 1;
$lbreinitcount = 1;
$lbdebug = 0;

$language = 'en';
$country = 'us';

@conftypesarr;
@conflibsarr;

#
# only vars for checking input
#
$varcnt = 0;
$typcnt = 0;
$libcnt = 0;
# amount of vars to check
$varchk = 16;



#
# private variables
#
my $xmlfile = "";
my $ltype = "";
my $taskcount = 0;

#
# subroutine to create and get the next taskid to be used
#
sub getTaskId() {
    if ($taskcount > 10000) {
        $taskcount = 1;
    }
    else {
        $taskcount++;
    }
    return $mmtaskid . $taskcount;
}


#
# subroutine for reading ans parsing the input xml config file
#
sub readConfiguration($) {
    ($xmlfile) = @_[0]->{"ConfigFile"};
    #
    # check whether config file exists
    #
    open(HANDLE, $xmlfile) || die
        "Cannot open config file $xmlfile for parsing. RC: $!";

    #
    # initialize parser and pars input
    #
    my $parser = XML::Parser->new( Handlers => {Start=>\&handle_start});
    $parser->parsefile($xmlfile);


    #
    # check amount of vars
    # expected all vars, min 1 type, min 2 libs and min libs must type * 2
    #
    if ($varcnt < $varchk) {
        return 1;
    }
    if ( ($typcnt < 1)  || ($libcnt < 2) )  {
        return 1;
    }
    if ($libcnt < ($typcnt *  2))  {
        return 1;
    }

    return 0;
}

#
# subroutine = handler for XMP parser
#
sub handle_start {
    my( $expat, $element, %attrs ) = @_;
    #
    # set element name to uppercase for minimize errors
    #
    my $upperkey = uc($element);

    #
    # from here begins the setup of our config variables
    #
    if ($upperkey eq "MMTRACEPATH") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmtracepath = $value;
            }
        }
    }

    if ($upperkey eq "MMTRACEFILE") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmtracefile = $value;
            }
        }
    }

    if ($upperkey eq "MMTRACELEVEL") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmtracelevel = $value;
            }
        }
    }

    if ($upperkey eq "MMHOSTNAME") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmhostname = $value;
            }
        }
    }

    if ($upperkey eq "MMPORTNUMBER") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmportnumber = $value;
            }
        }
    }

    if ($upperkey eq "MMCLIENTAPPLICATION") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmclientapplication = $value;
            }
        }
    }

    if ($upperkey eq "MMCLIENTAPPINSTANCE") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmclientappinstance = $value;
            }
        }
    }

    if ($upperkey eq "MMCLIENTAUTHMETHOD") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmclientauthmethod = $value;
            }
        }
    }

    if ($upperkey eq "MMCLIENTPASSWORD") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmclientpassword = $value;
            }
        }
    }

    if ($upperkey eq "MMTASKID") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $mmtaskid = $value;
            }
        }
    }

    if ($upperkey eq "LBUSABLEDRIVESWEIGHTFACTOR") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $lbusabledrivesweightfactor = $value;
            }
        }
    }

    if ($upperkey eq "LBAVAILABLEDRIVESWEIGHTFACTOR") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $lbavailabledrivesweightfactor = $value;
            }
        }
    }

    if ($upperkey eq "LBROUNDROBINVALUEWEIGHTFACTOR") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $lbroundrobinvalueweightfactor = $value;
            }
        }
    }

    if ($upperkey eq "LBTRIGGERCOUNT") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $lbtriggercount = $value;
            }
        }
    }

    if ($upperkey eq "LBREINITCOUNT") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $lbreinitcount = $value;
            }
        }
    }

    if ($upperkey eq "LBDEBUG") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $lbdebug = $value;
            }
        }
    }

    if ($upperkey eq "LANGUAGE") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $language = $value;
            }
        }
    }

    if ($upperkey eq "COUNTRY") {
        $varcnt++;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $country = $value;
            }
        }
    }

    if ($upperkey eq "TYPE") {
        $typcnt++;
        my $typerec = {};
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                $typerec->{"Type"} = $value;
                $ltype = $value;
            }
            push @conftypesarr, $typerec;
        }
    }

    if ($upperkey eq "LIB") {
        $libcnt++;
        my $librec = {};
        $librec->{"Type"} = $ltype;
        if( %attrs ) {
            while( my( $key, $value ) = each( %attrs )) {
                if ($key eq "name") {
                    $librec->{"LibraryName"} = $value;
                }
                if ($key eq "weightfactor") {
                    $librec->{"LibraryWeightFactor"} = $value;
                }
                if ($key eq "group") {
                    $librec->{"GroupName"} = $value;
                }
            }
            push @conflibsarr, $librec;
        }
    }

}

sub L10N_init
  {
   $lh = nls::lb_L10N -> get_handle("lb\_$language\_$country") || die "Error loading customized NLS module lb\_$language\_$country!\n";
   $lh -> fail_with("lookup_failure_handler");
}

sub printtext (@) {
   print( $lh -> maketext(@_) );
}

sub gettext (@) {
   return ( $lh -> maketext(@_) );
}

1;
