#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2006, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/26 00:50:48
#
# @brief eRMMTrace.pm - TSLM Library Balance Trace Module
#
#-----------------------------------------------------------------------

package eRMMTrace;

use libbal::eRMMConfig;
#
# private variables
#
my $tracepath = "";
my $basetracefile = "";
my $application = "";
my $tracelevel = 0;

#
# subroutine to initialize the log module
# and add the starting entry
#
sub initTrace($) {
    ($tracepath) = @_[0]->{"TracePath"};
    ($basetracefile) = @_[0]->{"TraceFile"};
    ($tracelevel) = @_[0]->{"TraceLevel"};
    ($application) = @_[0]->{"Application"};

    addTraceInfo("Application <" . $application . "> has started!")
}

#
# subroutine to add a log entry, ignoring the tracelevel
#
sub addTraceInfo($) {
    my ($logentry) = @_;
    addTrace($logentry);
}

#
# subroutine to add a log entry, by checking the tracelevel
#
sub addTraceEntry($) {
    my ($logentry) = @_;
    if ($tracelevel <= 0) {
        return;
    }
    addTrace($logentry);
}

#
# subroutine to add a log entry
#
sub addTrace($) {
    my ($logentry) = @_;

    my $timestamp = scalar localtime;
    $logentry = $timestamp.":".$logentry."\n";
    my $prefix = (split(" ",scalar localtime))[0];
    #
    # Build the tracefile name
    #
    my $traceFileName = $tracepath . $prefix . $basetracefile;

    if(-e $traceFileName) {
        #
        # if tracefile already exists
        #
        $Lastmodified = (stat($traceFileName))[9];
        my($wday,$month,$mday) = (split(" ",scalar localtime($Lastmodified)));
        my($lwday,$lmonth,$lmday) = (split(" ",scalar localtime))[0,1,2];
        if($wday eq $lwday && $month eq $lmonth && $mday eq $lmday){
            #
            # append the logentry to tracefile if it has the current date
            #
            open(HANDLE,">> $traceFileName") or
                die eRMMConfig::printtext("LBTRACEERR2", $traceFileName, $!);
            print HANDLE $logentry;
            close(HANDLE);
        }
        else {
            #
            # create a new tracefile, when it is one week old
            #
            open(HANDLE,">",$traceFileName) or
                die eRMMConfig::printtext("LBTRACEERR1", $traceFileName, $!);
            print HANDLE $logentry;
            close(HANDLE);
        }
    }
    else {
        #
        # create a new tracefile, when it does not exist
        #
        open(HANDLE,">",$traceFileName) or
            die eRMMConfig::printtext("LBTRACEERR1", $traceFileName, $!);
        print HANDLE $logentry;
        close(HANDLE);
    }

}
1;
