#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/26 01:04:53
#
# @brief en_us - default resorce file for TSM sync tool NLS support
#
#
#-----------------------------------------------------------------------

package nls::ts_L10N::ts_en_us;
use base qw(nls::ts_L10N);
%Lexicon = (

'_COPYRIGHT' => <<'EOCOPYRIGHT',
IBM Tape System Library Manager
Licensed Materials - Property of IBM
(C) Copyright IBM Corp. 2004, 2012 All Rights Reserved

EOCOPYRIGHT

'_USGOVRESTRICTED' => <<'ENDUSGOVRESTRICTED',
US Government Users Restricted Rights - Use, duplication or
disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
ENDUSGOVRESTRICTED

'_ABOUT' => "ermmTsmSync - Query and synchronize TSM and TSLM databases.\n",

'_USAGE' => <<'ENDOFUSAGE',

Usage:

  ermmTsmSync -config <configfile>
              (-clearmounts | -audittsmvols | -reconcileermmvols)
              ~[-fix~] ~[-debug~]

  ermmTsmSync -help

ENDOFUSAGE

'_OPTIONS' => <<'ENDOFOPTIONS',
Options:

  -config <configfile> The config file to use.

    Parameters in config file with default values:

     dsmserver=TSM     Server name.
                       Has to be defined in .../tsm/client/ba/bin/dsm.sys
     dsmid=admin       TSM user id for connecting to TSM with dsmadmc.
     dsmpassword=admin Password for the TSM user id.
     dsmlibname=TSLM   Name of the TSLM library definition in TSM.
     ermmapp=TSM       TSLM application name for the TSM server.
     ermmai=TSM        TSLM application instance for the TSM server.
     ermmauth=none     Authentication method.
     ermmpassword=ncc1701d Password for the TSM server application instance.
     ermmserver=localhost TSLM server IP.
     ermmport=default  TSLM server port.

    See also the example config file in /opt/IBM/ermm/conf/ermmTsmSync.conf.smp

    These are usually not required, because the defaults are quite reliable:

     dsmadmc=/usr/tivoli/tsm/client/ba/bin/dsmadmc Full path to dsmadmc.
            Default for Linux systems: /opt/tivoli/tsm/client/ba/bin/dsmadmc
            Default for AIX systems: see above
     ermmtool=/opt/IBM/ermm/bin/ermmtool

  -debug              Optional flag that prints more detailed information from
                      this tool.

  -fix                Try to fix problems. If omitted only queries are issued
                      without affecting the TSM server and TSLM. With the
                      -fix flag the user is queried for each operation.

  -clearmounts        Compare the mounted volumes in TSM and the volumes
                      mounted for TSM application defined in TSLM.

                      With the 'fix' option, try to unmount volumes that are
                      mounted in TSLM but do not show up in the TSM
                      'query mount' command.

  -audittsmvols       Compare the volumes allocated in TSLM for the TSM
                      application with the output of TSM 'query volume'
                      and 'query drmedia' (for DB backups) commands.
                      Show cartridges not allocated in TSLM.

                      With the 'fix' option try to allocate volumes from
                      scratch cartridges that show up in the lists from
                      TSM but are not allocated according to TSLM.

  -reconcileermmvols  Compare the volumes allocated in TSLM for the TSM
                      application with the output of TSM 'query volume'
                      and 'query drmedia' (for DB backups) commands.
                      Show cartridges not allocated in TSM.

                      With the 'fix' option try to deallocate volumes
                      that are allocated in TSLM but don't show up in
                      the lists from TSM.

ENDOFOPTIONS

'ALLOC_FAILED' => "Allocation of volume [_1] failed on cartridge [_2].\n",

'ALLOC_SUCCEEDED' => "Volume [_1] allocated successfully on cartridge [_2].\n",

'CMD_COMPLETED' => "Command completed.\n",

'DEALLOC_FAILED' => "Deallocation of volume [_1] failed.\n",

'DEALLOC_SUCCEEDED' => "Volume [_1] deallocated successfully.\n",

'DONE' => "Done\n",

'DRMEDIA' => "drmedia: [_1]\n",

'FAILED' => "Failed\n",

'ERMM_MNT' => "TSLM Mount: [_1]\n",

'ERMM_VOL' => "TSLM volume: [_1]\n",

'RETR_DRMEDIA_TSM' =>  "Retrieving drmedia from TSM... ",

'RETR_MNTVOL' =>  "Retrieving mounted volumes from [_1]... ",

'RETR_SVOL_TSM' =>  "Retrieving snapshot volumes from TSM... ",

'RETR_VOL_ERMM' => "Retrieving allocated volumes from TSLM... ",

'RETR_VOL_TSM' =>  "Retrieving volumes from TSM... ",

'SVOL' =>  "snapshotvolume: [_1]\n",

'SYNCMSG1001' => "There are [_1] volumes in [_2] that are not in [_3].\n",

'SYNCMSG1002' => "TSM volume [_1] not allocated in TSLM for this TSM server.\n",

'SYNCMSG1003' =>  "TSLM volume [_1] not allocated in TSM server.\n",

'SYNCMSG1004' => "[_1] mount requests in TSLM vs. [_2] mount requests in TSM.\n",

'SYNCMSG1005' =>  "TSLM mount of volume [_1] in drive [_2] unknown to TSM.\n",

'SYNCMSG1006' =>  "Could not find cartridge for allocating volume [_1].\n",

'SYNCMSG1007' => "parse line: [_1]\n",

'SYNCMSG1008' => "Executing command: [_1]\n",

'SYNCMSG1009' =>  "failed to execute: [_1]\n",

'SYNCMSG1010' => sub{
                     my $var = [_2] ? 'with' : 'without';
                     return "child died with signal [_1], $var coredump.\n";
                    },

'SYNCMSG1011' => "\nIssuing command: [_1].\n",

'SYNCMSG1012' => "Could not run [_1].\n",

'SYNCMSG1013' => "Result: [_1].\n",

'SYNCMSG1014' => "Could not read data from TSM.\n",

'SYNCMSG1015' => "Found device class [_1].\n",

'SYNCMSG1016' => "Got device class [_1] for library [_2].\n",

'SYNCQUERY001' => "Allocate volume [_1] on scratch cartridge?",

'SYNCQUERY002' => "Dealloc volume [_1] in TSLM?",

'TSM_MNT' => "TSM Mount: [_1]\n",

'TSM_VOL' => "TSM Volume: [_1]\n",

'TSM_VOL_TYPE' => "TSM volume: [_1]. Type: [_2].\n",

'UNMNT_FAILED' => "Unmount of volume [_1] failed.\n",

'UNMNT_SUCCEEDED' => "Unmount of volume [_1] succeeded.\n",

'ERMMSTOPPED' => "\nIBM Tape System Library Manager is not running.\n"

);

sub lookup_failure_handler {
    my $phrase = shift;
    my $messageID = shift;

    my $MsgLookupError = "EMM8100E";
    print "$MsgLookupError: Message ID \'$messageID\' not found in catalog.\n";
}

1;
