#!/usr/bin/perl
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.1 - 12/04/30 19:31:05
#
# @brief import_to_tslm_stage1.pl - Import data using ermmtool stage1.
#
#-----------------------------------------------------------------------

use strict;
use warnings;

#output datafles
my $sysfile="data/sys.dat";
my $libfile = "data/lib.dat";
my $lmfile = "data/lm.dat";
my $appfile = "data/app.dat";
my $aifile = "data/ai.dat";
my $cgfile = "data/cg.dat";
my $cgafile = "data/cga.dat";
my $dgfile = "data/dg.dat";
my $dgafile = "data/dga.dat";
my $dbcartnotinlibwithvolfile="data/cartnotinlibwithvol.db2dat";
my $dbcartnotinlibwithoutvolfile="data/cartnotinlibwithoutvol.db2dat";
my $dbvolcartnotinlibfile="data/volcartnotinlib.db2dat";    

my $tracefile="data/import_to_tslm1.log";

my @export_files=($sysfile, $libfile, $lmfile, $appfile, $aifile, $cgfile, $cgafile, $dgfile, $dgafile, $dbcartnotinlibwithoutvolfile, $dbcartnotinlibwithvolfile, $dbvolcartnotinlibfile);

my $buf;
my $cmd; 
my $rc;

my $sec;
my $min;
my $hour;
my $mday;
my $mon;
my $year;
my $wday;
my $yday;
my $isdst;

sub show_copyright()
{
    print "IBM Tape System Library Manager\n";
    print "Licensed Materials - Property of IBM\n";
    print "(C) Copyright IBM Corp. 2004, 2012 All Rights Reserved\n";
    print "\n";
    sleep(1);
}

sub check_user()
{
    my $MYLOGIN = $ENV{'LOGNAME'}; 
    chomp($MYLOGIN); 
    #print $MYLOGIN . "\n";
    my $WHOAMI = `which whoami 2> /dev/null`;
    chomp($WHOAMI);
    #print $WHOAMI . "\n";
    if (-e $WHOAMI) {
        $MYLOGIN = `$WHOAMI 2> /dev/null`;
        chomp($MYLOGIN);
        #print $MYLOGIN . "xxxx\n";
    }
    if ($MYLOGIN ne "ermm") {
        print "This script must be run with user \"ermm\".\n";
        exit -1;
    }
}

sub create_data_directory
{
    mkdir ("data/");
    open(HANDLE,">>",$tracefile) or die "Can't open tracefile file $tracefile, RC=$! \n";
}

sub print_and_log()
{
    print "$_[0]\n"; print HANDLE "$_[0]\n";
}

sub quit_process()
{
    &print_and_log("");
    &print_and_log("Import to TSLM stage 1 did not complete successfully: RC=$_[0]");
    &print_and_log("");
    &print_and_log("-----");
    ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
    $year+=1900;
    &print_and_log("----- End of import to TSLM stage 1 on $year/$mon/$mday $hour:$min:$sec");
    &print_and_log("-----");
    &print_and_log("");

    close(HANDLE);

    exit $_[0];
}

sub check_export_files()
{
    &print_and_log("----- Checking exported files from eRMM exist in data directory...");
    foreach my $value (@export_files)
    {
        if (-f $value)
        {
            &print_and_log("$value found.");
        }
        else
        {
           &print_and_log("$value does not exist.");
           &print_and_log("Please make sure that all the exported files from eRMM are in data/ directory.");
           &quit_process(1);
        }
    }
}

sub check_ermmtool_connectivity {
    &print_and_log("----- Checking ermmtool is able to connect to Media Manager correctly...");
    $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin lssys >> $tracefile 2>&1";

    for (1..3)
    {
       $rc = system("$cmd");

       if ($rc eq 0) {
           &print_and_log("Done!");
           &print_and_log("");
           return;
       }
       else {
           &print_and_log("ermmtool lssys did not return expected outputs.");
           sleep(2);
       }
    }

    &print_and_log("");
    &print_and_log("Please make sure that TSLM CLI package is installed and Media Manager is running on this system.");

    &quit_process(2);
}

sub chsys() {
    open IN, $sysfile  or die "Can't open source file $sysfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        # skip header lines
        if ( ($buf =~ /.*Admin.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";

        my ($v1, $v2, $v3, $v4, $v5, $v6, $v7) = split(/ +/);
        # print "$v1 \n" . "$v2 \n"  . "$v3 \n" . "$v4 \n"  . "$v5 \n"  . "$v6 \n"  . "$v7 \n";
        # change system record
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chsys -llevel $v2 -dcalimit $v4 -messlimit $v3 -reqlimit $v5 ";
    
        if  ($v6 =~ /.*enabled.*/) {
            $cmd = $cmd . "-von ";
        }
        else {
            $cmd = $cmd . "-voff ";
        }

        if  ($v7 =~ /.*enabled.*/) {
            $cmd = $cmd . "-ton ";
        }
        else {
            $cmd = $cmd . "-toff ";
        }
    
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

sub addlib() {
    open IN, $libfile  or die "Can't open source file $libfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        # skip header lines
        if ( ($buf =~ /.*Name.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";

        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n"  . "$v3 \n" . "$v4 \n"  . "$v5 \n"  . "$v6 \n";
 
        # add libs
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addlib $v1";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);

        # check disable status
        if  ($v3 =~ /.*true.*/) {
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chlib $v1 -disable";
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        } 
    }
}

sub addlm() {
    open IN, $lmfile  or die "Can't open source file $lmfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        my (@v1) = split(/text\[/,$buf);
        foreach my $rec (@v1) {
            if ($rec =~ /.*response.*/) {
                next;
            }
            chomp($rec);
        
            my @da = createdataarr($rec);
        
            # print $#da+1 . "\n";  
            # print $da[0] . "\n";
            # print $da[1] . "\n";
            # print $da[2] . "\n";
            # print $da[3] . "\n";
            # print $da[4] . "\n";
        
            # add LMs
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addlm $da[0] $da[1]";
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
      
            # check auth method and set messagelimit
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chlm $da[0] -mlevel $da[2] ";
            if ( ($da[3] =~ /.*password.*/) || ($da[3] =~ /.*pwenc.*/) ) {
                $cmd = $cmd . "-am $da[3] -ad $da[4] ";
            }
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        }
    }
}

sub associateLMToLib() {
    open IN, $libfile  or die "Can't open source file $libfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        # skip header lines
        if ( ($buf =~ /.*Name.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n"  . "$v3 \n" . "$v4 \n"  . "$v5 \n"  . "$v6 \n";
    
        # associate LM with lib
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chlib $v1 -lm $v4 ";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

sub addapp() {
    open IN, $appfile  or die "Can't open source file $appfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*Name.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4) = split(/ +/);
        # print "$v1 \n" . "$v2 \n"  . "$v3 \n" . "$v4 \n";
    
        # add app
        if ($v1 ne "ERMMSystem")
        {
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addapp $v1";
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        }

        # check remote mount and disabe status
        if ( ($v2 =~ /.*true.*/) || ($v3 =~ /.*true.*/) ) { 
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chapp $v1 ";
            if ($v2 =~ /.*true.*/) {
                $cmd = $cmd . "-disable ";
            }
            if ($v3 =~ /.*true.*/) {
                $cmd = $cmd . "-rm ";
            }
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        }

        # add temp migration ai for each app
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addai MigrationAI $v1 -a";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

sub addai() {
    open IN, $aifile  or die "Can't open source file $aifile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        my (@v1) = split(/text\[/,$buf);
        foreach my $rec (@v1) {
            if ($rec =~ /.*response.*/) {
                next;
            }
            chomp($rec);
      
            my @da = createdataarr($rec);

            # print $#da+1 . "\n";  
            # print $da[0] . "\n";
            # print $da[1] . "\n";
            # print $da[2] . "\n";
            # print $da[3] . "\n";
            # print $da[4] . "\n";
            # print $da[5] . "\n";
            # print $da[6] . "\n";
            # print $da[7] . "\n";
        
            # add AIs

            if ($da[0] ne "ERMMAdmin")
            {
                $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addai $da[0] $da[1]";
                $rc = `$cmd`;
                printandlogrc($rc,$cmd);
            }

            # check all additional values and set them
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chai $da[0] -app $da[1] -prio $da[4] ";
            if ($da[5] =~ /.*true.*/) {
                $cmd = $cmd . "-disable ";
            }
            if ($da[3] =~ /.*true.*/) {
                $cmd = $cmd . "-pc ";
            }
            if  ($da[2] =~ /.*ADMINISTRATOR.*/) {
                $cmd = $cmd . "-admin ";
            }
            if ( ($da[6] =~ /.*password.*/) || ($da[6] =~ /.*pwenc.*/) ) {
                $cmd = $cmd . "-am $da[6] -ad $da[7] ";
            }
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        }
    }
}

sub addcg() {
    open IN, $cgfile  or die "Can't open source file $cgfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        my (@v1) = split(/text\[/,$buf);
        foreach my $rec (@v1) {
            if ($rec =~ /.*response.*/) {
                next;
            }
            chomp($rec);
        
            my @da = createdataarr($rec);
  
            # print $#da+1 . "\n";  
            # print $da[0] . "\n";
            # print $da[1] . "\n";
            # print $da[2] . "\n";
            # print $da[3] . "\n";
            # print $da[4] . "\n";

            # add CGs
            if (($da[0] ne "Default") && ($da[0] ne "NoAccess") && ($da[0] ne "ScratchPool"))
            {
                $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addcg $da[0] -prio $da[1] ";
                if ($da[2] =~ /.*true.*/) {
                    $cmd = $cmd . "-scratch ";
                }
                $rc = `$cmd`;
                printandlogrc($rc,$cmd);
            }
        
            # set mountlimir and deallocgrp
            if ( ($da[3] ne "") || ($da[4] ne "") ) {
                $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin chcg $da[0] ";
            if ($da[3] ne "") {
                $cmd = $cmd . "-mountlimit $da[3] ";
            }
            if ($da[4] ne "") {
                $cmd = $cmd . "-dealloc $da[4] ";
            }
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
            }
        }
    }
}

sub addcga() {
    open IN, $cgafile  or die "Can't open source file $cgafile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*ID.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n"  . "$v3 \n" . "$v4 \n";
    
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin addcga $v2 $v3 -prio $v4";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

sub adddg() {
    open IN, $dgfile  or die "Can't open source file $dgfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*Name.*/) || ($buf =~ /.*=====.*/) || ($buf =~ /.*Default.*/) || ($buf =~ /.*NoAccess.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n" . "$v3 \n";

        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin adddg $v1";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

sub adddga() {
    open IN, $dgafile  or die "Can't open source file $dgafile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*ID.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n"  . "$v3 \n" . "$v4 \n" . "$v5 \n" . "$v6 \n";
       
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin adddga $v2 $v3 -prio $v4";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

sub createdataarr() {
    my ($buf) = @_;
   
    my @str;
    @str = split(/ +/,$buf);
    my $i = 0;
    foreach my $x (@str) {
        $str[$i] =~ s/\"//;
        $str[$i] =~ s/\"//;
        $i++; 
    }
    $str[$i-1] =~ s/\]//;
    return @str
}

sub printandlogrc {
    my ($prc, $pcmd) = @_;
    my $success = "SUCCESS->";
    my $error =   "ERROR--->";
    my $ret =     "RC------>";
    my $buf;
    if ( ($prc eq "") || ($prc =~ /.*success.*/) ) {
        $buf = "$success ermmtool cmd:$pcmd --- successfully done.\n";
        &print_and_log($buf);
    }
    else {
        $buf = "$error ermmtool cmd:$pcmd --- execution error.";
        &print_and_log($buf);
        $buf = "$ret $prc ";
        &print_and_log($buf);
    }
}

sub addcartnotinlib() {
    open IN, $dbcartnotinlibwithoutvolfile  or die "Can't open source file $dbcartnotinlibwithoutvolfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*ID.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n" . "$v3 \n" ;

        # create carts which have no lib relation and no vol 
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin raw create task[\\\"migtaskid\\\"] type[cartridge] set[\\\"CartridgePCL\\\" \\\"$v1\\\"] set[\\\"CartridgeGroupName\\\" \\\"$v2\\\"] set[\\\"CartridgeTypeName\\\" \\\"$v3\\\"] set[\\\"CartridgeState\\\" \\\"allocatable\\\"] report[Cartridge.\\\"CartridgeId\\\"] ";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);

        if ($rc =~ /.*success.*/) {
            my ($s1, $s2, $s3, $s4) = split(/\"/,$rc);
            # print "$s1 \n" . "$s2 \n" . "$s3 \n" . "$s4 \n" ;

            # create partition for just created cart
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin raw create task[\\\"migtaskid\\\"] type[partition] set[\\\"CartridgeID\\\" \\\"$s4\\\"] set[\\\"PartitionName\\\" \\\"Partition 1\\\"] set[\\\"SideName\\\" \\\"Side 1\\\"] ";
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        }
    }

    open IN, $dbcartnotinlibwithvolfile  or die "Can't open source file $dbcartnotinlibwithvolfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*ID.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n" . "$v3 \n" ;

        # create carts which have no lib relation but have a vol 
        $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin raw create task[\\\"migtaskid\\\"] type[cartridge] set[\\\"CartridgePCL\\\" \\\"$v1\\\"] set[\\\"CartridgeGroupName\\\" \\\"$v2\\\"] set[\\\"CartridgeTypeName\\\" \\\"$v3\\\"] set[\\\"CartridgeState\\\" \\\"allocatable\\\"] report[Cartridge.\\\"CartridgeId\\\"] ";
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);

        if ($rc =~ /.*success.*/) {
            my ($s1, $s2, $s3, $s4) = split(/\"/,$rc);
            # print "$s1 \n" . "$s2 \n" . "$s3 \n" . "$s4 \n" ;

            # create partition for just created cart            
            $cmd = "ermmtool -c ERMMSystem -i ERMMAdmin raw create task[\\\"migtaskid\\\"] type[partition] set[\\\"CartridgeID\\\" \\\"$s4\\\"] set[\\\"PartitionName\\\" \\\"Partition 1\\\"] set[\\\"SideName\\\" \\\"Side 1\\\"] ";
            $rc = `$cmd`;
            printandlogrc($rc,$cmd);
        }
    }

    open IN, $dbvolcartnotinlibfile  or die "Can't open source file $dbvolcartnotinlibfile: $! \n"; 
    while (<IN>) {
        $buf = $_;
        if ( ($buf =~ /.*ID.*/) || ($buf =~ /.*=====.*/) ) {
            next;
        }
        # print "$buf";
        my ($v1, $v2, $v3, $v4, $v5, $v6) = split(/ +/);
        # print "$v1 \n" . "$v2 \n" . "$v3 \n" . "$v4 \n" . "$v5\n"  ;

        # allocate vols for carts not in lib with vol
        if ($v2 =~ /.*ERMMSystem.*/) {
            $cmd = "ermmtool -c $v2 -i ERMMAdmin alloc $v3 -pcl $v1";
        }
        else {
            $cmd = "ermmtool -c $v2 -i MigrationAI alloc $v3 -pcl $v1";
        }
        $rc = `$cmd`;
        printandlogrc($rc,$cmd);
    }
}

#main
&show_copyright();
&check_user();
&create_data_directory();

($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
$year+=1900;
&print_and_log("-----");
&print_and_log("----- Start of import to TSLM stage 1 on $year/$mon/$mday $hour:$min:$sec");
&print_and_log("-----");
&print_and_log("");

#export file check
&check_export_files();
# conectivity check
&check_ermmtool_connectivity();

&print_and_log("");
&print_and_log("----- Start importing data to TSLM...");
&print_and_log("");

&chsys();
&addlib();
&addlm();
&associateLMToLib();
&addapp();
&addai();
&addcg();
&addcga();
&adddg();
&adddga();
&addcartnotinlib();

&print_and_log("");
&print_and_log("Import to TSLM completed successfully.");
&print_and_log("");
($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
$year+=1900;
&print_and_log("-----");
&print_and_log("----- End of import to TSLM stage 1 on $year/$mon/$mday $hour:$min:$sec");
&print_and_log("-----");
&print_and_log("");

close(HANDLE);

exit(0);
