#! /usr/bin/ksh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.2 - 12/04/30 21:28:42
#
# @brief ha_db2_start.ksh - DB2 start script at concurrent rg startup.
#
#-----------------------------------------------------------------------

# Script direcotry
SCRIPT_DIR="/opt/IBM/ermm/ha"

mkdir -p $SCRIPT_DIR/log
exec >> $SCRIPT_DIR/log/`basename $0`.log
exec 2>&1

echo "----------------------------------------------------------------"
date
echo "----------------------------------------------------------------"

#set -x

# Set parameters
. $SCRIPT_DIR/env

# Remote shell command
RSH_CMD="/usr/bin/rsh $REMOTENODE"

# Cluster node command
CL_NODECMD="/usr/es/sbin/cluster/sbin/cl_nodecmd -cspoc "

export LANG=C

# Get PowerHA start sequence
/usr/es/sbin/cluster/utilities/clRGinfo -c $CONCURRENT_RG | awk -F: ' $3 == "'${REMOTENODE}'" {print $2}'| read REMOTENODE_STATE

if [[ "$REMOTENODE_STATE" = "ONLINE" ]];then
    START_MODE=LATE_START
else
    START_MODE=FIRST_START
fi

# Main

# db2start
echo "#DB2START"
${SU_CMD_DB2} "db2start"

# Get HADR Role and State on local node
${HADR_MONITOR} | read CFG_ROLE PD_STATE PD_ROLE

echo START_MODE ${START_MODE}
echo CFG_ROLE   ${CFG_ROLE}
echo PD_ROLE    ${PD_ROLE}
echo PD_STATE   ${PD_STATE}

case ${START_MODE} in
# In case PowerHA started on this node first
FIRST_START)
    echo "PowerHA started on this node first."
    case "${CFG_ROLE}" in
    # Local node is configured as Primary
    PRIMARY)
        case "${PD_ROLE}" in
        # HADR is not working now
        '')
            echo "No action is taken because local node is configured as Primary."
        ;;
        # HADR is working now
        *)
            echo "HADR is working already on local node. No action is taken because this situation is unexpedted."
        ;;
        esac
    ;;
    # Local node is configured as Standby
    STANDBY)
        case "${PD_ROLE}" in
        # HADR is not working now
        '')
            echo "Start HADR as Standby because local node is configured as Standby."
            ${SU_CMD_DB2} "db2 activate database ${DBNAME}"

            RC=$?
            if [[ $RC != 0 ]]; then
                echo "Failed to activate database."
                exit 1
            fi

        ;;
        # HADR is working now
        *)
            echo "HADR is working already on local node. No action is taken because this situation is unexpedted."
        ;;
        esac
    ;;
    # Local node is configured as neither Primary nor Standby
    *)
        echo "Local node is configured as neither Primary nor Standby. No action is taken because this situation is unexpedted."
    ;;
    esac
;;
# In case PowerHA started on this node later
LATE_START)
    echo "PowerHA started on this node later."

    # Get HADR Role and State on remote node
    # Try up to COUNT times
    COUNT=5
    while [[ $COUNT > 0 ]]
    do
        ${CL_NODECMD} "-n ${REMOTENODE}" ${HADR_MONITOR} | cut -f2,3,4 -d" " | read REMOTE_CFG_ROLE REMOTE_PD_STATE REMOTE_PD_ROLE

        if [[ $REMOTE_PD_ROLE != "" ]];then 
            break
        fi
        sleep 1
        COUNT=`expr $COUNT - 1`
    done

    echo REMOTE_CFG_ROLE ${REMOTE_CFG_ROLE}
    echo REMOTE_PD_ROLE  ${REMOTE_PD_ROLE}
    echo REMOTE_PD_STATE ${REMOTE_PD_STATE}

    case "${CFG_ROLE}" in
    # Local node is configured as Primary
    PRIMARY)
        echo "Local node is configured as Primary."
        case "${PD_ROLE}" in
        # HADR is not working now
        '')
            case "${REMOTE_PD_ROLE}" in
            # Remote node is current Primary
            Primary)
                echo "Start HADR as Standby on local node because remote node is current Primary."
                ${SU_CMD_DB2} "db2 start hadr on db ${DBNAME} as standby"

                RC=$?
                if [[ $RC != 0 ]]; then
                    echo "Failed to start HADR as Standby."
                    exit 2
                fi
            ;;
            # Remote node is current Standby
            Standby)
                echo "Start HADR as Primary on local node because remote node is current Standby."
                ${SU_CMD_DB2} "db2 activate database ${DBNAME}"

                RC=$?
                if [[ $RC != 0 ]]; then
                    echo "Failed to activate database."
                    exit 3
                fi
            ;;
            # Remote node is not Primary nor Standby
            *)
                echo "Remote node is not Primary nor Standby. No action is taken because this situation is unexpedted."
            ;;
           esac
        ;;
        # HADR is working now
        *)
            echo "HADR is working already on local node. No action is taken because this situation is unexpedted."
        ;;
        esac
    ;;
    # Local node is configured as Standby
    STANDBY)
        echo "Local node is configured as Standby."
        case "${PD_ROLE}" in
        # HADR is not working now
        '')
            echo "Start HADR as Standby on local node because it is configured as Standby."
            ${SU_CMD_DB2} "db2 activate database ${DBNAME}"

            RC=$?
            if [[ $RC != 0 ]]; then
                echo "Failed to activate database."
                exit 4
            fi

            case "${REMOTE_CFG_ROLE}" in
            # Remote node is configured as Primary
            PRIMARY)
                case "${REMOTE_PD_ROLE}" in
                # HADR is not working on remote node
                '')
                    echo "Start HADR as Primary on remote node because it is configured as Primary."
                    ${CL_NODECMD} "-n ${REMOTENODE}" ${SU_CMD_DB2} "db2 activate database ${DBNAME}"

                    RC=$?
                    if [[ $RC != 0 ]]; then
                        echo "Failed to activate database."
                        exit 5
                    fi
                ;;
                # Remote node is current Primary
                Primary)
                    echo "No action is taken on remote node because it is current Primary."
                ;;
                # HADR is working on remote node
                *)
                    echo "HADR is working already on remote node. No action is taken because this situation is unexpedted."
                ;;
                esac
            ;;
            # Remote node is not old Primary
            *)
                echo "Remote node is not old Primary. No action is taken because this situation is unexpedted."
            ;;
           esac
        ;;
        # HADR is workin on local node
        *)
            echo "HADR is working already on local node. No action is taken because this situation is unexpedted."
        ;;
        esac
    ;;
    # Local node is configured neither as Primary nor as Standby
    *)
        echo "Local node is not configured as Primary nor as Standby. No action is taken because this situation is unexpedted."
    ;;
    esac
;;
# Unknown PowerHA start sequence
*)
    echo "Unknown PowerHA start sequence detected. No action is taken because this situation is unexpedted."
;;
esac

exit 0
