#!/usr/bin/ksh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/05/26 00:52:20
#
# @brief ha_hadr_start.ksh - HADR start script at rotating rg startup.
#
#-----------------------------------------------------------------------

# Script direcotry
SCRIPT_DIR="/opt/IBM/ermm/ha"

mkdir -p $SCRIPT_DIR/log
exec >> $SCRIPT_DIR/log/`basename $0`.log
exec 2>&1

echo "----------------------------------------------------------------"
date
echo "----------------------------------------------------------------"

#set -x

# Set parameters
. $SCRIPT_DIR/env

# Get PowerHA start sequence
/usr/es/sbin/cluster/utilities/clRGinfo -c $CONCURRENT_RG | awk -F: ' $3 == "'${REMOTENODE}'" {print $2}'| read REMOTENODE_STATE

if [[ "$REMOTENODE_STATE" = "ONLINE" ]];then
    START_MODE="FALLOVER"
else
    START_MODE="NORMAL"
fi

# Get HADR Role and State on local node
${HADR_MONITOR} | read CFG_ROLE PD_STATE PD_ROLE

echo CFG_ROLE   ${CFG_ROLE}
echo PD_ROLE    ${PD_ROLE}
echo PD_STATE   ${PD_STATE}

if [[ "${PD_STATE}" != "" ]]; then
    START_MODE="FALLOVER"
fi

echo START_MODE ${START_MODE}

# Main
case ${START_MODE} in
NORMAL)
    echo "No action is taken because of normal startup."
;;
FALLOVER)
    echo "Take appropriate actions based on HADR Role and State because of startup with takeover."

    if [[ "${PD_ROLE}" = "Primary" ]]; then
        # already primary
        echo "No action is taken because this node is already Primary."

    elif [[ "${PD_ROLE}" = "Standby" && "${PD_STATE}" = "Peer" ]]; then
        # Standby and Peer case. Try takeover
        echo "Perform HADR takeover because this node is Standby and Peer."
        ${SU_CMD_DB2} "db2 takeover hadr on db ${DBNAME}"
        RC=$?
        if [[ $RC != 0 ]]; then
            # Normal takeover failed. Try takeover by force
            echo "Normal takeover failed. Try takeover by force..."
            ${SU_CMD_DB2} "db2 takeover hadr on db ${DBNAME} by force"
            RC_F=$?
            if [[ $RC_F != 0 ]]; then
                echo "Failed to takeover by force."
                exit 1
            fi
        fi

    elif [[ "${PD_ROLE}" = "Standby" && "${PD_STATE}" != "Peer" ]]; then
        # Standby but not Peer case. Try takeover by force
        echo "Perform HADR takeover by force because this instance is Standby but not Peer."
        ${SU_CMD_DB2} "db2 takeover hadr on db ${DBNAME} by force"
        RC_F=$?
        if [[ $RC_F != 0 ]]; then
            echo "Failed to takeover by force."
            exit 1
        fi

    else
        echo "No action is taken because this node is not Primary nor Standby. Check HADR status."

    fi
;;

esac

exit 0
