#!/usr/bin/ksh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.2 - 12/04/30 21:28:46
#
# @brief ha_hadr_stop.ksh - HADR stop script at rotating rg stop.
#
#-----------------------------------------------------------------------

# Script direcotry
SCRIPT_DIR="/opt/IBM/ermm/ha"

mkdir -p $SCRIPT_DIR/log
exec >> $SCRIPT_DIR/log/`basename $0`.log
exec 2>&1

echo "----------------------------------------------------------------"
date
echo "----------------------------------------------------------------"

#set -x

# Set parameters
. $SCRIPT_DIR/env

# Check stop mode
/usr/es/sbin/cluster/utilities/clRGinfo -a | grep $ROTATE_RG | awk -F\" '{print $2}' | awk -F\: '{print $2}' | read POSTNODE 

if [[ "$POSTNODE" = "" ]]; then
    STOP_MODE="NORMAL"
else
    STOP_MODE="FALLOVER"
fi

# Get HADR Role and State on local node
${HADR_MONITOR} | read CFG_ROLE PD_STATE PD_ROLE

# Main
case ${STOP_MODE} in
NORMAL)
    echo "No action is taken because of normal stop."
;;
FALLOVER)
    echo "Take appropriate actions based on HADR Role and State because of stop with takeover."

    if [[ "${PD_ROLE}" = "Primary" && "${PD_STATE}" = "Peer" ]]; then
        echo "Perform HADR takeover from remote node because this node is Primary and Peer."
        /usr/es/sbin/cluster/sbin/cl_nodecmd -cspoc "-n ${REMOTENODE}" ${SU_CMD_DB2} "db2 takeover hadr on db ${DBNAME}"
    else
        echo "No action is taken because this node is not Primary and Peer."
    fi
;;

esac

exit 0
