#! /usr/bin/ksh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.2 - 12/04/30 21:28:51
#
# @brief tslm_monitor.ksh - TSLM tiny monitoring script.
#
#-----------------------------------------------------------------------

# Script direcotry
SCRIPT_DIR="/opt/IBM/ermm/ha"

mkdir -p $SCRIPT_DIR/log
exec >> $SCRIPT_DIR/log/`basename $0`.log
exec 2>&1

#set -x

# Set parameters
. $SCRIPT_DIR/env

# This function runs lssys command.
# The output of this command should be the following:
#
# ID
# ====================================
#
# This command validates the following conditions:
# oa local user can connect to the Media Manager,
# o the Media Manager process is running,
# o the Media Manager process is not hanged-up,
# o the Media Manager can access the TSLM database,
# o the IBM DB2 for TSLM is up and running.
run_lssys()
{
    LSSYS_OUTPUT=`${SU_CMD_TSLM} "ermmtool lssys -s | head -2" 2>&1`
    echo $LSSYS_OUTPUT | read FST_LINE SND_LINE
}

# See if lssys returns expected outputs.
# Try up to COUNT times
COUNT=3
while [[ $COUNT > 0 ]]
do
    run_lssys
    if [[ "${FST_LINE}" != "ID" || "${SND_LINE}" != "====================================" ]]; then
        echo "----------------------------------------------------------------"
        date
        echo "----------------------------------------------------------------"
        echo "lssys output: ${LSSYS_OUTPUT}"
        sleep 5
        COUNT=`expr $COUNT - 1`
    else
        # lssys command is working as expected.
        exit 0
    fi
done

echo "lssys did not return expected outputs."
exit 1
