#!/usr/bin/ksh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.7 - 12/08/28 19:57:48
#
# @brief install_aix.sh - Install TSLM on aix platforms.
#
#-----------------------------------------------------------------------
export LC_ALL=C

# variable definition
PRODUCT_NAME="Tape System Library Manager"
PRODUCT_SHORT="TSLM"
PRODUCT_SHORT_OLD="eRMM"
PRODUCT_PKG_FILESET_TSLM="tslm"
PRODUCT_PKG_FILESET_IRMM="irmm"
SRCDIR=`dirname $0`
CURRENT_DIR=`pwd`
TSLM_INST_PKG_ROOT="$SRCDIR/../"
cd $TSLM_INST_PKG_ROOT
TSLM_INST_PKG_ROOT=`pwd`
cd $CURRENT_DIR
TSLM_INST_SCRIPT_DIR="$TSLM_INST_PKG_ROOT/scripts"
LOG_ROOT="/tmp/tslmlog"
TSLM_INST_LOG_FILE_NAME="$LOG_ROOT/tslm_inst.log"
TSLM_INST_STAT_FILE_NAME="$LOG_ROOT/tslm_inst_stat"
PACKAGE_FILES_DIR="$TSLM_INST_PKG_ROOT/aix64"
INSTALLP_OPTS="-acgNQqXYd"
INSTALLATION_SET=0
EMU3494_INSTALLATION=0
STATE_COMMITTED="COMMITTED"
TSLM_UNINST_ORG_SCRIPT="$TSLM_INST_SCRIPT_DIR/uninstall_aix.sh"
TSLM_UNINST_SCRIPT="uninstall.sh"

INSTALLATION_BASE_DIR="/opt/IBM/ermm"
INSTALLATION_INSTALL_DIR="$INSTALLATION_BASE_DIR/install"
INSTALLATION_CONFIG_DIR="$INSTALLATION_BASE_DIR/conf"
INSTALLATION_TSM_DIR="$INSTALLATION_BASE_DIR/client/tsm"
INSTALLATION_EMU3494_DIR="$INSTALLATION_BASE_DIR/client/3494"
INSTALLATION_LOG_DIR="$INSTALLATION_BASE_DIR/log"
PRE_INSTALL_DB_SCRIPT="preInstallDatabase"
INSTALL_DB_SCRIPT="installDatabase"
MM_CONFIG_FILE_SAMPLE="mm.xml.smp"
MM_CONFIG_FILE="mm.xml"
HDM_CONFIG_FILE_SAMPLE="genhdm.cfg.smp"
HDM_CONFIG_FILE="genhdm.cfg"
ELM_CONFIG_FILE_SAMPLE="elm.cfg.smp"
ELM_CONFIG_FILE="elm.cfg"
EMU3494_CONFIG_FILE_SAMPLE="ermm3494.cfg.smp"
EMU3494_CONFIG_FILE="ermm3494.cfg"
DB2_INSTALL_LOG="ermmdb2install.log"

TSLM_MM="Media Manager"
TSLM_HDM="Host Driver Manager"
TSLM_ELM="External Library Manager"
TSLM_EMU3494="3494 Emulation"

TSLM_USR_NAME="ermm"
TSLM_DB_NAME="ermm"
TSLM_SU_COMMAND=""

PACKAGE_CLI_KEY="cli"
PACKAGE_ELM_KEY="elm"
PACKAGE_HDM_KEY="hdm"
PACKAGE_LM_KEY="lm"
PACKAGE_MM_KEY="mm"
PACKAGE_PWGEN_KEY="pwgen"
PACKAGE_SYSTEM_KEY="system"
PACKAGE_3494_KEY="3494"

SUPPORT_OS_TYPE="AIX"
OS_REQ_VRMF="6.1.0.0"

TAPE_DRIVER_NAME="Atape"
TAPE_DRIVER_FILESET="Atape.driver"
TAPE_DRIVER_REQ_VRMF="12.5.2.0"

DB_NAME="DB2"
DB_ADM_NAME="db2inst1"
DB_ADM_GRP_NAME="db2grp1"

PERL_NAME="Perl"
PERL_FILESET="perl.rte"
PERL_REQ_VRMF="5.8.0.0"

SQLLIB_PATH="db2inst1/sqllib/bin"

PACKAGE_MANDATORY_LIST="$PACKAGE_SYSTEM_KEY $PACKAGE_CLI_KEY"
PACKAGE_SERVER_LIST="$PACKAGE_LM_KEY $PACKAGE_MM_KEY"
PACKAGE_CLIENT_LIST="$PACKAGE_ELM_KEY $PACKAGE_HDM_KEY"
PACKAGE_COMMON_LIST="$PACKAGE_PWGEN_KEY"

# function definition
print_and_log()
{
    echo $1 | tee -a $TSLM_INST_LOG_FILE_NAME
}

logonly()
{
    echo $1 >> $TSLM_INST_LOG_FILE_NAME
}

ask_yes_no_answer()
{
    while true;
    do
        print_and_log "$1 (y/n)"
        read YES_NO_ANS
        if [ $YES_NO_ANS == "y" ] || [ $YES_NO_ANS == "n" ]; then
            break
        fi
    done
    logonly $YES_NO_ANS
}

show_copyright()
{
    echo "IBM Tape System Library Manager"
    echo "Licensed Materials - Property of IBM"
    echo "(C) Copyright IBM Corp. 2004, 2012 All Rights Reserved"
    echo ""
    sleep 1
}

usage()
{
    echo "Install $PRODUCT_NAME and create database $TSLM_DB_NAME."
    echo "Usage: $(basename $0) [-c] [-s] [-b] [-e] [-h]"
    echo "Options:"
    echo "  -c    Install client packages of $PRODUCT_SHORT."
    echo "  -s    Install server packages of $PRODUCT_SHORT."
    echo "  -b    Install both, client and server packages of $PRODUCT_SHORT."
    echo "  -e    Install $TSLM_EMU3494 package. Must be specified with -c/-s/-b."
    echo "  -h    Display this help and exit."
}

quit_installation()
{
    print_and_log "Installation process of $PRODUCT_SHORT did not complete successfully: RC=$1"
    print_and_log ""
    print_and_log_with_banner "End of $PRODUCT_SHORT installation process on `date`"
    exit $1
}

banner()
{
    BANNER=""
    width=$(tput cols)
    if [ $width -le 80 ]; then
        i=0
        while [[ $i -lt $width ]]; do
            BANNER="$BANNER#"
            let i=$i+1
        done
    else
        BANNER="###############################################################################"
    fi
    print_and_log "$BANNER"
}

print_and_log_with_banner()
{
    banner
    print_and_log "$1"
    banner
}

check_user()
{
    if [ "$USER" != "root" ]; then
        echo "This script can not be run with non-root account."
        exit 1
    fi
}

create_log_file()
{
    if [ ! -d $LOG_ROOT ]; then
        echo "Create log directory \"$LOG_ROOT\"."
        mkdir -p $LOG_ROOT
        if [ $? != 0 ]; then
            echo "Failed to create log directory \"$LOG_ROOT\"."
            exit 2
        fi
    fi
    
    if [ -f $TSLM_INST_LOG_FILE_NAME ]; then
        mv $TSLM_INST_LOG_FILE_NAME "$TSLM_INST_LOG_FILE_NAME"'.previous'
    fi

    touch $TSLM_INST_LOG_FILE_NAME
}

check_options()
{
    while getopts "csbeh" options
    do
        case $options in
            c)  INSTALLATION_SET=1;;
            s)  INSTALLATION_SET=2;;
            b)  INSTALLATION_SET=3;;
            e)  EMU3494_INSTALLATION=1;;
            h)  usage; exit 0;;
            *) echo "Invalid option was specified."; exit 3;;
        esac
    done

    if [ $EMU3494_INSTALLATION == 1 ]; then
        if [ $INSTALLATION_SET != 1 ] && [ $INSTALLATION_SET != 2 ] && [ $INSTALLATION_SET != 3 ]; then
            echo "Option -e must be specified with -c/-s/-b."
            exit 3
        fi
    fi

    if [ $INSTALLATION_SET == 1 ]; then
        echo "Running client installation mode..."
    elif [ $INSTALLATION_SET == 2 ]; then
        echo "Running server installation mode..."
    elif [ $INSTALLATION_SET == 3 ]; then
        echo "Running client and server installation mode..."
    else
        usage
        exit 0
    fi
}

compare_vrmfs()
{
    VRMF_A=$1
    VRMF_B=$2
    logonly "VRMF_A=$VRMF_A, VRMF_B=$VRMF_B"
    
    CUR_A=`echo $VRMF_A | cut -f 1 -d .`
    CUR_B=`echo $VRMF_B | cut -f 1 -d .`
    logonly "CUR_A=$CUR_A, CUR_B=$CUR_B"
    
    REMAINS_A=`echo $VRMF_A | cut -f 2- -d . -s`
    REMAINS_B=`echo $VRMF_B | cut -f 2- -d . -s`
    logonly "REMAINS_A=$REMAINS_A, REMAINS_B=$REMAINS_B"
    
    if [ $CUR_A -lt $CUR_B ]; then
        return 2
    elif [ $CUR_A -gt $CUR_B ]; then
        return 1
    else
        [[ $REMAINS_A == "" ]] || [[ $REMAINS_B == "" ]] && return 0 
        compare_vrmfs $REMAINS_A $REMAINS_B
    fi
}

check_os_version()
{
    print_and_log_with_banner "Checking OS..."
    
    UNAME=`uname -a`
    logonly "UNAME=$UNAME"
    OS_TYPE=`echo $UNAME | awk '{print $1}'`
    
    if [ "$OS_TYPE" != "$SUPPORT_OS_TYPE" ]; then
        print_and_log "Detected OS is $OS_TYPE, not $SUPPORT_OS_TYPE."
        print_and_log "This installation script only works on $SUPPORT_OS_TYPE."
        quit_installation 4
    fi

    OS_VERSION=`echo $UNAME | awk '{print $4}'`
    OS_RELEASE=`echo $UNAME | awk '{print $3}'`
    OS_VRMF="$OS_VERSION.$OS_RELEASE.0.0"

    logonly "OS_TYPE=$OS_TYPE, OS_VERSION=$OS_VERSION, OS_RELEASE=$OS_RELEASE"

    print_and_log "Detected OS is $OS_TYPE $OS_VERSION.$OS_RELEASE"
    compare_vrmfs $OS_VRMF $OS_REQ_VRMF
   
    if [ $? -eq "2" ]; then
        print_and_log "$PRODUCT_NAME requires $SUPPORT_OS_TYPE `echo $OS_REQ_VRMF | cut -f -2 -d .` or higher."
        quit_installation 4
    else
        print_and_log "Done!"
    fi
    
    print_and_log ""
}

check_tslm_package()
{
    for PRODUCT_PKG in $1; do
        FOUND_PKG=`ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PRODUCT_PKG`
        logonly "Target package: $PRODUCT_PKG, Found package: $FOUND_PKG"
        if [ -z "$FOUND_PKG" ]; then
            print_and_log "\"$PRODUCT_PKG\" package is not found in \"$PACKAGE_FILES_DIR\" directory."
            print_and_log "This package is required to proceed installation."
            quit_installation 16
        fi
    done
}

check_tslm_packages_availability()
{
    print_and_log_with_banner "Checking all the neccessary $PRODUCT_SHORT packages are available..."
    check_tslm_package "$PACKAGE_MANDATORY_LIST"
    if [ $INSTALLATION_SET -eq 2 ] || [ $INSTALLATION_SET -eq 3 ]; then
        check_tslm_package "$PACKAGE_SERVER_LIST"
    fi
    if [ $INSTALLATION_SET -eq 1 ] || [ $INSTALLATION_SET -eq 3 ]; then
        check_tslm_package "$PACKAGE_CLIENT_LIST"
    fi
    if [ $EMU3494_INSTALLATION -eq 1 ]; then
        check_tslm_package "$PACKAGE_3494_KEY"
    fi
    check_tslm_package "$PACKAGE_COMMON_LIST"
    print_and_log "Done!"
    
    print_and_log ""
}

is_old_release_installed()
{
    print_and_log_with_banner "Checking $PRODUCT_SHORT_OLD/$PRODUCT_SHORT components already installed on this system..."

    PRODUCT_PKG_FILESET_LIST="$PRODUCT_PKG_FILESET_IRMM"
    if [ $INSTALLATION_SET -eq 2 ] || [ $INSTALLATION_SET -eq 3 ]; then
        for PRODUCT_PKG in ${PACKAGE_SERVER_LIST}; do
            PRODUCT_PKG_FILESET_LIST=" $PRODUCT_PKG_FILESET_LIST $PRODUCT_PKG_FILESET_TSLM.$PRODUCT_PKG"
        done
    fi
    if [ $INSTALLATION_SET -eq 1 ] || [ $INSTALLATION_SET -eq 3 ]; then
        for PRODUCT_PKG in ${PACKAGE_CLIENT_LIST}; do
            PRODUCT_PKG_FILESET_LIST=" $PRODUCT_PKG_FILESET_LIST $PRODUCT_PKG_FILESET_TSLM.$PRODUCT_PKG"
        done
    fi
    if [ $EMU3494_INSTALLATION -eq 1 ]; then
        PRODUCT_PKG_FILESET_LIST=" $PRODUCT_PKG_FILESET_LIST $PRODUCT_PKG_FILESET_TSLM.$PACKAGE_3494_KEY"
    fi

    INSTALLED_PACKAGE_LIST=""
    
    for PRODUCT_PKG in ${PRODUCT_PKG_FILESET_LIST}; do 
        LSLPP_PRODUCT_PKG_FILESET=`lslpp -L 2>&1 | grep $PRODUCT_PKG | awk '{print $1}'`
        logonly "LSLPP_PRODUCT_PKG_FILESET=$LSLPP_PRODUCT_PKG_FILESET"
        if [ -n "$LSLPP_PRODUCT_PKG_FILESET" ]; then
            INSTALLED_PACKAGE_LIST="$INSTALLED_PACKAGE_LIST $LSLPP_PRODUCT_PKG_FILESET "
        fi
    done
    
    if [ -n "$INSTALLED_PACKAGE_LIST" ]; then
        print_and_log "The following component(s) detected on this system:"
        for INSTALLED_PKG in ${INSTALLED_PACKAGE_LIST}; do 
            LSLPP_PRODUCT_PKG_VERSION=`lslpp -L 2>&1 | grep $INSTALLED_PKG | awk '{print $2}'`
            print_and_log "$INSTALLED_PKG $LSLPP_PRODUCT_PKG_VERSION"
        done
        print_and_log ""
        print_and_log "Please uninstall the existing one(s) before installing this release."
        quit_installation 5
    fi
    
    print_and_log "Done!"
    
    print_and_log ""
}

check_tape_driver()
{
    print_and_log_with_banner "Checking $TAPE_DRIVER_NAME driver..."
    
    LSLPP_TAPE_DRIVER_FILESET=`lslpp -l $TAPE_DRIVER_FILESET* 2>&1`
    logonly "LSLPP_TAPE_DRIVER_FILESET=$LSLPP_TAPE_DRIVER_FILESET"
    IS_TD_INVALID="1"
    TAPE_DRIVER_VRMF=`lslpp -l $TAPE_DRIVER_FILESET* 2>&1 | grep $STATE_COMMITTED | head -n 1 | awk '{print $2}'`
    if [ -z "$TAPE_DRIVER_VRMF" ]; then
        print_and_log "No $TAPE_DRIVER_NAME driver detected on this system."
    else
        print_and_log "$TAPE_DRIVER_NAME driver version $TAPE_DRIVER_VRMF detected on this system."
        compare_vrmfs $TAPE_DRIVER_VRMF $TAPE_DRIVER_REQ_VRMF
        if [ $? -ne "2" ]; then
            IS_TD_INVALID="0"
        fi
    fi

    if [ "$IS_TD_INVALID" -eq "1" ]; then
        print_and_log "$PRODUCT_NAME requires $TAPE_DRIVER_NAME driver version $TAPE_DRIVER_REQ_VRMF or higher."
        quit_installation 6
    else
        print_and_log "Done!"
    fi
    
    print_and_log ""
}

check_database_admin()
{
    print_and_log_with_banner "Checking $DB_NAME Administrator..."

    grep "^$DB_ADM_NAME:" /etc/passwd > /dev/null
    GREP_DB_ADM_RES=$?
    if [ $GREP_DB_ADM_RES != 0 ]; then
        print_and_log "User \"$DB_ADM_NAME\" not found on this system."
        print_and_log "User \"$DB_ADM_NAME\" is required to create database for $PRODUCT_SHORT."
        quit_installation 8
    fi

    grep "^$DB_ADM_GRP_NAME:" /etc/group > /dev/null
    GREP_DB_GRP_RES=$?
    if [ $GREP_DB_GRP_RES != 0 ]; then
        print_and_log "Group \"$DB_ADM_GRP_NAME\" not found on this system."
        print_and_log "Group \"$DB_ADM_GRP_NAME\" is required to create database for $PRODUCT_SHORT."
        quit_installation 8
    else
        print_and_log "Done!"
    fi

    print_and_log ""
}

check_perl()
{
    print_and_log_with_banner "Checking $PERL_NAME..."
    
    LSLPP_PERL_FILESET=`lslpp -l $PERL_FILESET* 2>&1`
    logonly "LSLPP_PERL_FILESET=$LSLPP_PERL_FILESET"
    
    IS_PL_INVALID="1"
    PERL_VRMF=`lslpp -l $PERL_FILESET* 2>&1 | grep $STATE_COMMITTED | head -n 1 | awk '{print $2}'`
    if [ -z "$PERL_VRMF" ]; then
        print_and_log "No $PERL_NAME detected on this system."
    else
        print_and_log "$PERL_NAME version $PERL_VRMF detected on this system."
        compare_vrmfs $PERL_VRMF $PERL_REQ_VRMF
        if [ $? -ne "2" ]; then
            IS_PL_INVALID="0"
        fi
    fi

    if [ "$IS_PL_INVALID" -eq "1" ]; then
        print_and_log "$PRODUCT_NAME requires $PERL_NAME version $PERL_REQ_VRMF or higher."
        quit_installation 9
    else
        print_and_log "Done!"
    fi
    
    print_and_log ""
}

check_prereqs()
{
    check_os_version
    check_tslm_packages_availability
    is_old_release_installed
    check_tape_driver
    if [ $INSTALLATION_SET -eq 2 ] || [ $INSTALLATION_SET -eq 3 ]; then
        check_database_admin
    fi
    if [ $INSTALLATION_SET -eq 1 ] || [ $INSTALLATION_SET -eq 3 ]; then
        check_perl
    fi
}

check_previous_installation()
{
    if [ -f $TSLM_INST_STAT_FILE_NAME ]; then
        print_and_log "Detected that previous $PRODUCT_SHORT installation did not complete successfully."
        print_and_log "Need to cleanup the previous installation before proceeding this process."
        ask_yes_no_answer "Would you like to continue?"
        if [ $YES_NO_ANS == "y" ]; then
            print_and_log "Start cleanup process..."
            print_and_log ""
            TSLM_PREV_INST_STAT=`cat $TSLM_INST_STAT_FILE_NAME`
            if [ $TSLM_PREV_INST_STAT == 1 ]; then
                TSLM_UNINST_SCRIPT_OPT="-p"
            else
                TSLM_UNINST_SCRIPT_OPT="-b"
            fi
            $TSLM_UNINST_ORG_SCRIPT $TSLM_UNINST_SCRIPT_OPT
            TSLM_UNINST_RES=$?
            if [ $TSLM_UNINST_RES != 0 ]; then
                print_and_log "Cleanup of the previous installation failed. RC=$TSLM_UNINST_RES"
                quit_installation 10
            fi
        else
            quit_installation 10
        fi
        rm -rf $TSLM_INST_STAT_FILE_NAME
        print_and_log ""
        print_and_log "Cleanup process done!"
        print_and_log "Going back to the installation process..."
        print_and_log ""
    fi
}

install_bff()
{
    print_and_log "Attempting to install $1"
    installp $INSTALLP_OPTS "$PACKAGE_FILES_DIR/$1" all 1>>$TSLM_INST_LOG_FILE_NAME 2>&1
    INSTALL_BFF_RES=$?
    if [ $INSTALL_BFF_RES -eq 0 ]; then
        print_and_log "Installation of $1 was successful."
    else
        print_and_log "Failed to install $1: RC=$INSTALL_BFF_RES"
        quit_installation 11
    fi
    print_and_log ""
}

install_mandatory()
{
    LSLPP_SYSTEM_VERSION=`lslpp -L 2>&1 | grep $PRODUCT_PKG_FILESET_TSLM.$PACKAGE_SYSTEM_KEY | awk '{print $2}'`
    logonly "LSLPP_SYSTEM_VERSION=$LSLPP_SYSTEM_VERSION"
    if [ -n "$LSLPP_SYSTEM_VERSION" ]; then
        print_and_log "\"$PRODUCT_PKG_FILESET_TSLM.$PACKAGE_SYSTEM_KEY $LSLPP_SYSTEM_VERSION\" has been already installed on this system."
        print_and_log "Skip installing this package..."
        print_and_log ""
    else
        install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_SYSTEM_KEY`
    fi
    
    LSLPP_CLI_VERSION=`lslpp -L 2>&1 | grep $PRODUCT_PKG_FILESET_TSLM.$PACKAGE_CLI_KEY | awk '{print $2}'`
    logonly "LSLPP_CLI_VERSION=$LSLPP_CLI_VERSION"
    if [ -n "$LSLPP_CLI_VERSION" ]; then
        print_and_log "\"$PRODUCT_PKG_FILESET_TSLM.$PACKAGE_CLI_KEY $LSLPP_CLI_VERSION\" has been already installed on this system."
        print_and_log "Skip installing this package..."
        print_and_log ""
    else
        install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_CLI_KEY`
    fi
}

install_server()
{
    install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_MM_KEY`
    install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_LM_KEY`
}

install_client()
{
    install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_ELM_KEY`
    install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_HDM_KEY`
}

install_common()
{
    LSLPP_PWGEN_VERSION=`lslpp -L 2>&1 | grep $PRODUCT_PKG_FILESET_TSLM.$PACKAGE_PWGEN_KEY | awk '{print $2}'`
    logonly "LSLPP_PWGEN_VERSION=$LSLPP_PWGEN_VERSION"
    if [ -n "$LSLPP_PWGEN_VERSION" ]; then
        print_and_log "\"$PRODUCT_PKG_FILESET_TSLM.$PACKAGE_PWGEN_KEY $LSLPP_PWGEN_VERSION\" has been already installed on this system."
        print_and_log "Skip installing this package..."
        print_and_log ""
    else
        install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_PWGEN_KEY`
    fi
}

install_3494()
{
    install_bff `ls $PACKAGE_FILES_DIR | grep $PRODUCT_PKG_FILESET_TSLM..\.$PACKAGE_3494_KEY`
}

do_installations()
{
    print_and_log_with_banner "Start installing $PRODUCT_SHORT packages..."

    install_mandatory
    if [ $INSTALLATION_SET -eq 2 ] || [ $INSTALLATION_SET -eq 3 ]; then
        install_server
    fi
    if [ $INSTALLATION_SET -eq 1 ] || [ $INSTALLATION_SET -eq 3 ]; then
        install_client
    fi
    install_common
    if [ $EMU3494_INSTALLATION -eq 1 ]; then
        install_3494
    fi

    print_and_log "Copying uninstaller."
    copy_tslm_file $TSLM_UNINST_ORG_SCRIPT $INSTALLATION_BASE_DIR/$TSLM_UNINST_SCRIPT
    print_and_log ""

    print_and_log "Done!"
    print_and_log ""
}

su_check()
{
    SU_PATH=`su - $TSLM_USR_NAME -c "env" 2>&1 | grep -e ^PATH=`
    logonly "SU_PATH=$SU_PATH"
    if [ `echo $SU_PATH | grep -c -e $SQLLIB_PATH` -ge "1" ]; then
        TSLM_SU_COMMAND="su - $TSLM_USR_NAME -c"
        logonly "TSLM_SU_COMMAND=$TSLM_SU_COMMAND"
        return
    fi

    SU_PATH=`su $TSLM_USR_NAME -c "env" 2>&1 | grep -e ^PATH=`
    logonly "SU_PATH=$SU_PATH"
    if [ `echo $SU_PATH | grep -c -e $SQLLIB_PATH` -ge "1" ]; then
        TSLM_SU_COMMAND="su $TSLM_USR_NAME -c"
        logonly "TSLM_SU_COMMAND=$TSLM_SU_COMMAND"
        return
    fi

    print_and_log "No directories are specified in the PATH of user $TSLM_USR_NAME to execute database commands."
    quit_installation 7
}

append_db_log()
{
    if [ -f $INSTALLATION_LOG_DIR/$DB2_INSTALL_LOG ]; then
        logonly ""
        logonly "--------------- Start of $INSTALLATION_LOG_DIR/$DB2_INSTALL_LOG ---------------"
        cat $INSTALLATION_LOG_DIR/$DB2_INSTALL_LOG >> $TSLM_INST_LOG_FILE_NAME
        logonly "---------------- End of $INSTALLATION_LOG_DIR/$DB2_INSTALL_LOG ----------------"
        logonly ""
    fi
}

configure_db()
{
    print_and_log_with_banner "Creating database $TSLM_DB_NAME..."

    if [ ! -f $INSTALLATION_INSTALL_DIR/$PRE_INSTALL_DB_SCRIPT ]; then
        print_and_log "Script \"$PRE_INSTALL_DB_SCRIPT\" does not exist in $INSTALLATION_INSTALL_DIR/."
        print_and_log "Package installation seems to be failed."
        quit_installation 12
    fi
    
    if [ ! -f $INSTALLATION_INSTALL_DIR/$INSTALL_DB_SCRIPT ]; then
        print_and_log "Script \"$INSTALL_DB_SCRIPT\" does not exist in $INSTALLATION_INSTALL_DIR/."
        print_and_log "Package installation seems to be failed."
        quit_installation 12
    fi
    
    $INSTALLATION_INSTALL_DIR/$PRE_INSTALL_DB_SCRIPT

    su_check
    
    $TSLM_SU_COMMAND "$INSTALLATION_INSTALL_DIR/$INSTALL_DB_SCRIPT"
    CONFIGURE_DB_RC=$?
    append_db_log
    echo "2" > $TSLM_INST_STAT_FILE_NAME
    if [ $CONFIGURE_DB_RC != 0 ]; then
        if [ $CONFIGURE_DB_RC == 4 ]; then
            ask_yes_no_answer "Would you like to recreate database $TSLM_DB_NAME?"
            if [ $YES_NO_ANS == "y" ]; then
                ask_yes_no_answer "All data in the current database will be lost. Would you really like to continue?"
                if [ $YES_NO_ANS == "y" ]; then
                    $TSLM_SU_COMMAND "db2 connect reset" >> $TSLM_INST_LOG_FILE_NAME 2>&1
                    $TSLM_SU_COMMAND "db2 drop db $TSLM_DB_NAME" >> $TSLM_INST_LOG_FILE_NAME 2>&1
                    CONFIGURE_DB_RC=$?
                    if [ $CONFIGURE_DB_RC != 0 ]; then
                        print_and_log "Failed to drop $TSLM_DB_NAME DB. RC=$CONFIGURE_DB_RC"
                        quit_installation 13
                    fi
                    echo "1" > $TSLM_INST_STAT_FILE_NAME
                    $TSLM_SU_COMMAND "$INSTALLATION_INSTALL_DIR/$INSTALL_DB_SCRIPT"
                    CONFIGURE_DB_RC=$?
                    append_db_log
                    echo "2" > $TSLM_INST_STAT_FILE_NAME
                    if [ $CONFIGURE_DB_RC != 0 ]; then
                        print_and_log "Failed to create $TSLM_DB_NAME DB. RC=$CONFIGURE_DB_RC"
                        quit_installation 14
                    fi
                fi
            fi    
        else
            print_and_log "Failed to create $TSLM_DB_NAME DB. RC=$CONFIGURE_DB_RC"
            quit_installation 14
        fi
    fi

    print_and_log "Done!"
    print_and_log ""
}

copy_tslm_file()
{
    cp $1 $2 >> $TSLM_INST_LOG_FILE_NAME 2>&1
    TSLM_INST_CP_CONFIG_RES=$?
    if [ $TSLM_INST_CP_CONFIG_RES != 0 ]; then
        print_and_log "Failed to copy \"$1\" to \"$2\": RC=$TSLM_INST_CP_CONFIG_RES"
        quit_installation 15
    fi
}

prepare_server_config()
{
    print_and_log_with_banner "Preparing $TSLM_MM config file..."
    if [ ! -f $INSTALLATION_CONFIG_DIR/$MM_CONFIG_FILE_SAMPLE ]; then
        print_and_log "File \"$MM_CONFIG_FILE_SAMPLE\" does not exist in $INSTALLATION_CONFIG_DIR/."
        print_and_log "Package installation seems to be failed."
        quit_installation 12
    else
        if [ -f $INSTALLATION_CONFIG_DIR/$MM_CONFIG_FILE ]; then
            print_and_log "Config file of $TSLM_MM \"$MM_CONFIG_FILE\" already exists in $INSTALLATION_CONFIG_DIR/."
            ask_yes_no_answer "Would you like to use the current config file?"
            if [ $YES_NO_ANS == "n" ]; then
                copy_tslm_file $INSTALLATION_CONFIG_DIR/$MM_CONFIG_FILE_SAMPLE $INSTALLATION_CONFIG_DIR/$MM_CONFIG_FILE
            fi
        else
            copy_tslm_file $INSTALLATION_CONFIG_DIR/$MM_CONFIG_FILE_SAMPLE $INSTALLATION_CONFIG_DIR/$MM_CONFIG_FILE
        fi
    fi

    print_and_log "Done!"
    print_and_log ""
}

prepare_client_config()
{
    print_and_log_with_banner "Preparing $TSLM_HDM config file..."
    if [ ! -f $INSTALLATION_CONFIG_DIR/$HDM_CONFIG_FILE_SAMPLE ]; then
        print_and_log "File \"$HDM_CONFIG_FILE_SAMPLE\" does not exist in $INSTALLATION_CONFIG_DIR/."
        print_and_log "Package installation seems to be failed."
        quit_installation 12
    else
        if [ -f $INSTALLATION_CONFIG_DIR/$HDM_CONFIG_FILE ]; then
            print_and_log "Config file of $TSLM_HDM \"$HDM_CONFIG_FILE\" already exists in $INSTALLATION_CONFIG_DIR/."
            ask_yes_no_answer "Would you like to use the current config file?"
            if [ $YES_NO_ANS == "n" ]; then
                copy_tslm_file $INSTALLATION_CONFIG_DIR/$HDM_CONFIG_FILE_SAMPLE $INSTALLATION_CONFIG_DIR/$HDM_CONFIG_FILE
            fi
        else
            copy_tslm_file $INSTALLATION_CONFIG_DIR/$HDM_CONFIG_FILE_SAMPLE $INSTALLATION_CONFIG_DIR/$HDM_CONFIG_FILE
        fi
    fi
    print_and_log "Done!"
    print_and_log ""
    
    print_and_log_with_banner "Preparing $TSLM_ELM config file..."
    if [ ! -f $INSTALLATION_TSM_DIR/$ELM_CONFIG_FILE_SAMPLE ]; then
        print_and_log "File \"$ELM_CONFIG_FILE_SAMPLE\" does not exist in $INSTALLATION_TSM_DIR/."
        print_and_log "Package installation seems to be failed."
        quit_installation 12
    else
        if [ -f $INSTALLATION_TSM_DIR/$ELM_CONFIG_FILE ]; then
            print_and_log "Config file of $TSLM_ELM \"$ELM_CONFIG_FILE\" already exists in $INSTALLATION_TSM_DIR/."
            ask_yes_no_answer "Would you like to use the current config file?"
            if [ $YES_NO_ANS == "n" ]; then
                copy_tslm_file $INSTALLATION_TSM_DIR/$ELM_CONFIG_FILE_SAMPLE $INSTALLATION_TSM_DIR/$ELM_CONFIG_FILE
            fi
        else
            copy_tslm_file $INSTALLATION_TSM_DIR/$ELM_CONFIG_FILE_SAMPLE $INSTALLATION_TSM_DIR/$ELM_CONFIG_FILE
        fi
    fi
    
    print_and_log "Done!"
    print_and_log ""
}

prepare_3494_config()
{
    print_and_log_with_banner "Preparing $TSLM_EMU3494 config file..."
    if [ ! -f $INSTALLATION_EMU3494_DIR/$EMU3494_CONFIG_FILE_SAMPLE ]; then
        print_and_log "File \"$EMU3494_CONFIG_FILE_SAMPLE\" does not exist in $INSTALLATION_EMU3494_DIR/."
        print_and_log "Package installation seems to be failed."
        quit_installation 12
    else
        if [ -f $INSTALLATION_EMU3494_DIR/$EMU3494_CONFIG_FILE ]; then
            print_and_log "Config file of $TSLM_EMU3494 \"$EMU3494_CONFIG_FILE\" already exists in $INSTALLATION_EMU3494_DIR/."
            ask_yes_no_answer "Would you like to use the current config file?"
            if [ $YES_NO_ANS == "n" ]; then
                copy_tslm_file $INSTALLATION_EMU3494_DIR/$EMU3494_CONFIG_FILE_SAMPLE $INSTALLATION_EMU3494_DIR/$EMU3494_CONFIG_FILE
            fi
        else
            copy_tslm_file $INSTALLATION_EMU3494_DIR/$EMU3494_CONFIG_FILE_SAMPLE $INSTALLATION_EMU3494_DIR/$EMU3494_CONFIG_FILE
        fi
    fi

    print_and_log "Done!"
    print_and_log ""
}

# main
show_copyright
check_user
check_options $@
create_log_file
print_and_log_with_banner "Start of $PRODUCT_SHORT installation process on `date`"
print_and_log ""
logonly "INSTALLATION_SET=$INSTALLATION_SET"
check_previous_installation
check_prereqs
echo "1" > $TSLM_INST_STAT_FILE_NAME
do_installations
if [ $INSTALLATION_SET -eq 2 ] || [ $INSTALLATION_SET -eq 3 ]; then
    configure_db
fi
echo "1" > $TSLM_INST_STAT_FILE_NAME
if [ $INSTALLATION_SET -eq 2 ] || [ $INSTALLATION_SET -eq 3 ]; then
    prepare_server_config
fi
if [ $INSTALLATION_SET -eq 1 ] || [ $INSTALLATION_SET -eq 3 ]; then
    prepare_client_config
fi
if [ $EMU3494_INSTALLATION -eq 1 ]; then
    prepare_3494_config
fi
print_and_log "Installation process of $PRODUCT_SHORT completed successfully."
print_and_log ""
print_and_log_with_banner "End of $PRODUCT_SHORT installation process on `date`"
rm -rf $TSLM_INST_STAT_FILE_NAME
exit 0
