#!/bin/bash
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/08/28 19:57:17
#
# @brief uninstall.sh - Uninstall TSLM from xlinux platforms.
#
#-----------------------------------------------------------------------
export LC_ALL=C

# variable definition
PRODUCT_NAME="Tape System Library Manager"
PRODUCT_SHORT="TSLM"
PRODUCT_PKG_FILESET_IRMM="irmm"
PRODUCT_PKG_FILESET_TSLM="tslm"
TSLM_UNINST_LOG_ROOT="/tmp/tslmlog"
TSLM_UNINST_LOG_FILE_NAME="$TSLM_UNINST_LOG_ROOT/tslm_uninst.log"
RPM_COMMAND="rpm"
QUERY_OPTS="-qa"
ERASE_OPTS="-ev"

TSLM_UNINSTALLATION_MODE=0
NUM_OF_UNINSTALLED_PKG=0

INSTALLATION_BASE_DIR="/opt/IBM/ermm"
INSTALLATION_BIN_DIR="$INSTALLATION_BASE_DIR/bin"

TSLM_MM="Media Manager"
TSLM_LM="Library Manager"
TSLM_HDM="Host Driver Manager"

TSLM_USR_NAME="ermm"
TSLM_DB_NAME="ermm"
TSLM_SU_COMMAND="su - $TSLM_USR_NAME -c"

TSLM_UNINST_PKG_BASE_KEY="base"
TSLM_UNINST_PKG_CLI_KEY="cli"
TSLM_UNINST_PKG_ELM_KEY="elm"
TSLM_UNINST_PKG_HDM_KEY="hdm"
TSLM_UNINST_PKG_LM_KEY="lm"
TSLM_UNINST_PKG_LMIBM_KEY="lmibm"
TSLM_UNINST_PKG_MM_KEY="mm"
TSLM_UNINST_PKG_PWGEN_KEY="pwgen"
TSLM_UNINST_PKG_SYSTEM_KEY="system"
TSLM_UNINST_PKG_3494_KEY="3494"
TSLM_UNINST_PKG_LIBBAL_KEY="libbal"
TSLM_UNINST_PGK_STKUTILS_KEY="stkutils"

TSLM_STOP_SCRIPT="ermmStop"
TSLM_LM_STOP_SCRIPT="ermmLmStop"
TSLM_GEN_HDM_SCRIPT="ermmGenHDM"
TSLM_MM_BIN="MediaManager"
TSLM_LM_BIN="LibraryManager"

SQLLIB_PATH="db2inst1/sqllib/bin"

# function definition
print_and_log()
{
    echo $1 | tee -a $TSLM_UNINST_LOG_FILE_NAME
}

logonly()
{
    echo $1 >> $TSLM_UNINST_LOG_FILE_NAME
}

ask_yes_no_answer()
{
    while true;
    do
        print_and_log "$1 (y/n)"
        read YES_NO_ANS
        if [ $YES_NO_ANS == "y" ] || [ $YES_NO_ANS == "n" ]; then
            break
        fi
    done
    logonly $YES_NO_ANS
}

show_copyright()
{
    echo "IBM Tape System Library Manager"
    echo "Licensed Materials - Property of IBM"
    echo "(C) Copyright IBM Corp. 2004, 2012 All Rights Reserved"
    echo ""
    sleep 1
}

usage()
{
    echo "Uninstall $PRODUCT_NAME and drop database $TSLM_DB_NAME."
    echo "Usage: $(basename $0) [-p] [-d] [-b] [-h]"
    echo "Options:"
    echo "  -p    Uninstall $PRODUCT_SHORT packages only."
    echo "  -d    Drop database $TSLM_DB_NAME only."
    echo "  -b    Uninstall $PRODUCT_SHORT packages and drop database $TSLM_DB_NAME."
    echo "  -h    Display this help and exit."
}

quit_uninstallation()
{
    print_and_log "Uninstallation process of $PRODUCT_SHORT did not complete successfully: RC=$1"
    print_and_log ""
    print_and_log_with_banner "End of $PRODUCT_SHORT uninstallation process on `date`"
    exit $1
}

banner()
{
    BANNER=""
    width=$(tput cols)
    if [ $width -le 80 ]; then
        i=0
        while [[ $i -lt $width ]]; do
            BANNER="$BANNER#"
            let i=$i+1
        done
    else
        BANNER="###############################################################################"
    fi
    print_and_log "$BANNER"
}

print_and_log_with_banner()
{
    banner
    print_and_log "$1"
    banner
}

check_user()
{
    if [ "$USER" != "root" ]; then
        echo "This script can not be run with non-root account."
        exit 1
    fi
}

create_log_file()
{
    if [ ! -d $TSLM_UNINST_LOG_ROOT ]; then
        echo "Create log directory \"$TSLM_UNINST_LOG_ROOT\"."
        mkdir -p $TSLM_UNINST_LOG_ROOT
        if [ $? != 0 ]; then
            echo "Failed to create log directory \"$TSLM_UNINST_LOG_ROOT\"."
            exit 2
        fi
    fi
    
    if [ -f $TSLM_UNINST_LOG_FILE_NAME ]; then
        mv $TSLM_UNINST_LOG_FILE_NAME "$TSLM_UNINST_LOG_FILE_NAME"'.previous'
    fi

    touch $TSLM_UNINST_LOG_FILE_NAME
}

check_options()
{
    while getopts "pdbh" TSLM_UNINST_OPTS
    do
        case $TSLM_UNINST_OPTS in
            p)  TSLM_UNINSTALLATION_MODE=1;;
            d)  TSLM_UNINSTALLATION_MODE=2;;
            b)  TSLM_UNINSTALLATION_MODE=3;;
            h)  usage; exit 0;;
            *) echo "Invalid option was specified."; exit 3;;
        esac
    done

    if [ $TSLM_UNINSTALLATION_MODE -eq 1 ]; then
        echo "Uninstalling $PRODUCT_SHORT packages only..."
    elif [ $TSLM_UNINSTALLATION_MODE -eq 2 ]; then
        echo "Dropping database $TSLM_DB_NAME only..."
    elif [ $TSLM_UNINSTALLATION_MODE -eq 3 ]; then
        echo "Uninstalling $PRODUCT_SHORT packages and dropping database $TSLM_DB_NAME..."
    else
        usage
        exit 0
    fi
}

su_check()
{
    SU_PATH=`su - $TSLM_USR_NAME -c "env" 2>&1 | grep -e ^PATH=`
    logonly "SU_PATH=$SU_PATH"
    if [ `echo $SU_PATH | grep -c -e $SQLLIB_PATH` -ge "1" ]; then
        TSLM_SU_COMMAND="su - $TSLM_USR_NAME -c"
        logonly "TSLM_SU_COMMAND=$TSLM_SU_COMMAND"
        return
    fi

    SU_PATH=`su $TSLM_USR_NAME -c "env" 2>&1 | grep -e ^PATH=`
    logonly "SU_PATH=$SU_PATH"
    if [ `echo $SU_PATH | grep -c -e $SQLLIB_PATH` -ge "1" ]; then
        TSLM_SU_COMMAND="su $TSLM_USR_NAME -c"
        logonly "TSLM_SU_COMMAND=$TSLM_SU_COMMAND"
        return
    fi

    print_and_log "No directories are specified in the PATH of user $TSLM_USR_NAME to execute database commands."
    quit_uninstallation 6
}

stop_mm_by_script()
{
    if [ -a $INSTALLATION_BIN_DIR/$TSLM_STOP_SCRIPT ]; then
        print_and_log "Trying to run $INSTALLATION_BIN_DIR/$TSLM_STOP_SCRIPT..."
        $TSLM_SU_COMMAND "$INSTALLATION_BIN_DIR/$TSLM_STOP_SCRIPT"
    else
        print_and_log "$INSTALLATION_BIN_DIR/$TSLM_STOP_SCRIPT does not exist."
    fi
    
    print_and_log ""
}

stop_lm_by_script()
{
    if [ -a $INSTALLATION_BIN_DIR/$TSLM_LM_STOP_SCRIPT ]; then
        print_and_log "Trying to run $INSTALLATION_BIN_DIR/$TSLM_LM_STOP_SCRIPT..."
        $TSLM_SU_COMMAND "$INSTALLATION_BIN_DIR/$TSLM_LM_STOP_SCRIPT"
    else
        print_and_log "$INSTALLATION_BIN_DIR/$TSLM_LM_STOP_SCRIPT does not exist."
    fi
    
    print_and_log ""
}

kill_mm_process()
{
    PS_MM_PID=`ps aux | grep $INSTALLATION_BIN_DIR/$TSLM_MM_BIN | grep -v grep | awk '{print $2}'`
    logonly "PS_MM_PID=$PS_MM_PID"

    if [ -n "$PS_MM_PID" ]; then
        print_and_log "Killing process of $TSLM_MM (PID: $PS_MM_PID)..."
        KILL_MM_PID=`kill -9 $PS_MM_PID`
        logonly "KILL_MM_PID=$KILL_MM_PID"
    else
        print_and_log "No $TSLM_MM process detected."
    fi
    
    print_and_log ""
}

kill_lm_process()
{
    PS_LM_PID=`ps aux | grep $INSTALLATION_BIN_DIR/$TSLM_LM_BIN | grep -v grep | head -n 1 | awk '{print $2}'`
    logonly "PS_LM_PID=$PS_LM_PID"
    if [ -z "$PS_LM_PID" ]; then
        print_and_log "No $TSLM_LM process detected."
    fi
    
    while [ -n "$PS_LM_PID" ]; do
        print_and_log "Killing process of $TSLM_LM (PID: $PS_LM_PID)..."
        KILL_LM_PID=`kill -9 $PS_LM_PID`
        logonly "KILL_LM_PID=$KILL_LM_PID"
        PS_LM_PID=`ps aux | grep $INSTALLATION_BIN_DIR/$TSLM_LM_BIN | grep -v grep | head -n 1 | awk '{print $2}'`
        logonly "PS_LM_PID=$PS_LM_PID"
    done
    
    print_and_log ""
}

kill_hdm_process()
{
    PS_HDM_PID=`ps aux | grep $INSTALLATION_BIN_DIR/$TSLM_GEN_HDM_SCRIPT | grep -v grep | awk '{print $2}'`
    logonly "PS_HDM_PID=$PS_HDM_PID"

    if [ -n "$PS_HDM_PID" ]; then
        print_and_log "Killing process of $TSLM_HDM (PID: $PS_HDM_PID)..."
        KILL_HDM_PID=`kill -9 $PS_HDM_PID`
        logonly "KILL_HDM_PID=$KILL_HDM_PID"
    else
        print_and_log "No $TSLM_HDM process detected."
    fi
    
    print_and_log ""
}

stop_server_process()
{
    print_and_log_with_banner "Try to stop the server processes of $PRODUCT_SHORT..."
    stop_lm_by_script
    stop_mm_by_script
    kill_lm_process
    kill_mm_process

    print_and_log "Done!"
    print_and_log ""
}

drop_db()
{
    print_and_log_with_banner "Dropping database $TSLM_DB_NAME..."
    
    ask_yes_no_answer "All data in the current database will be lost. Would you really like to continue?"
    if [ $YES_NO_ANS == "y" ]; then
        $TSLM_SU_COMMAND "db2 connect reset" >> $TSLM_UNINST_LOG_FILE_NAME 2>&1
        $TSLM_SU_COMMAND "db2 drop db $TSLM_DB_NAME" >> $TSLM_UNINST_LOG_FILE_NAME 2>&1
        DROP_DB_RC=$?
        if [ $DROP_DB_RC -ne 0 ]; then
            print_and_log "Failed to drop $TSLM_DB_NAME database. RC=$DROP_DB_RC"
            if [ $TSLM_UNINSTALLATION_MODE -eq 3 ]; then
                ask_yes_no_answer "Would you like to continue anyway?"
                if [ $YES_NO_ANS == "n" ]; then
                    quit_uninstallation 4
                fi
            else
                 quit_uninstallation 4
            fi
        else
            print_and_log "Done!"
        fi
    else
        print_and_log "Dropping database was skipped by user's request."
    fi

    print_and_log ""
}

remove_rpm()
{
    RPM_Q_NUM=`$RPM_COMMAND $QUERY_OPTS $1 | grep -c -e $1`
    if [ $RPM_Q_NUM -ne 0 ]; then
        echo "Attempting to remove $1"
        $RPM_COMMAND $ERASE_OPTS $1 1>>$TSLM_UNINST_LOG_FILE_NAME 2>&1
        REMOVE_RPM_RC=$?
        if [ $REMOVE_RPM_RC -eq 0 ]; then
            NUM_OF_UNINSTALLED_PKG=`expr $NUM_OF_UNINSTALLED_PKG + 1`
            print_and_log "Removal of $1 was successful."
        else
            print_and_log "Failed to remove $1: RC=$REMOVE_BFF_RC"
            quit_uninstallation 5
        fi
        print_and_log ""
    fi
}

uninstall_product_packages()
{
    print_and_log_with_banner "Start uninstalling $PRODUCT_SHORT packages..."
    
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_3494_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_LIBBAL_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_PWGEN_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_CLI_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_ELM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_HDM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_LM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_LMIBM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_MM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PGK_STKUTILS_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_SYSTEM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_IRMM-$TSLM_UNINST_PKG_BASE_KEY"

    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_3494_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_LIBBAL_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_PWGEN_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_CLI_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_ELM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_HDM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_LM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_MM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_SYSTEM_KEY"
    remove_rpm "$PRODUCT_PKG_FILESET_TSLM-$TSLM_UNINST_PKG_BASE_KEY"
    
    if [ $NUM_OF_UNINSTALLED_PKG -eq 0 ]; then
        print_and_log "No $PRODUCT_SHORT packages installed."
        print_and_log ""
    else
        print_and_log "Done!"
    fi
}

# main
show_copyright
check_user
check_options $@
create_log_file
print_and_log_with_banner "Start of $PRODUCT_SHORT uninstallation process on `date`"
print_and_log ""
logonly "TSLM_UNINSTALLATION_MODE=$TSLM_UNINSTALLATION_MODE"
stop_server_process
if [ $TSLM_UNINSTALLATION_MODE -eq 2 ] || [ $TSLM_UNINSTALLATION_MODE -eq 3 ]; then
    su_check
    drop_db
fi
if [ $TSLM_UNINSTALLATION_MODE -eq 1 ] || [ $TSLM_UNINSTALLATION_MODE -eq 3 ]; then
    uninstall_product_packages
    print_and_log_with_banner "Try to stop $TSLM_HDM process..."
    kill_hdm_process
fi
print_and_log "Uninstallation process of $PRODUCT_SHORT completed successfully."
print_and_log ""
print_and_log_with_banner "End of $PRODUCT_SHORT uninstallation process on `date`"
exit 0
