-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager 
-- 
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.4 - 12/01/24 02:35:20
--
-- @brief
-- CMVC   DATE         NAME   DESCRIPTIONS
--       (MM/DD/YY) 
-- ------ ---------- -------- ----------------------------------------
-- 63073  2010-12-08  ni      Added CmcGroup, CmcLM             @TMG01
--                            change Library to include ConnectedLibraryList, LibraryAccessPath
-- 66782  2011-12-13  ni      Added SourceLibrary in m_task
--                                  LastAuditTime in m_library
--
----------------------------------------------------------------------

ECHO Start of creating ERMM database tables...;

--
-- M_AI
--
ECHO Creating table M_AI...;
--
CREATE TABLE M_AI (
	AIName VARCHAR ( 192 ) NOT NULL,
	Privilege SMALLINT DEFAULT 1 NOT NULL,
	PrivilegeChangeable CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	DefaultPriority SMALLINT DEFAULT 500 NOT NULL,
	RequestAction VARCHAR ( 255 ),
        AuthenticationMethod VARCHAR ( 192 ) DEFAULT 'none',
        AuthenticationData VARCHAR ( 1024 ) DEFAULT NULL,
	AIID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	AIDisabled VARCHAR ( 16 ),	
 	Connection VARCHAR ( 192 ),	
        CONSTRAINT PK_M_AI90 PRIMARY KEY (AIID)
	) IN DATABASE ERMM;


--
-- M_Application
--
ECHO Creating table M_Application...;
--
CREATE TABLE M_Application (
	ApplicationName VARCHAR ( 192 ) NOT NULL,
	MaxDisconnectTimeout INTEGER DEFAULT 1800 NOT NULL,
	SignatureAlgorithm VARCHAR ( 255 ) DEFAULT 'undefined' NOT NULL,
	AllowRemoteMount CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	BypassVerify CHARACTER ( 1 ) DEFAULT 'Y' NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	ApplicationDisabled  VARCHAR ( 36 ),	
	CONSTRAINT PK_M_Applicatio91 PRIMARY KEY (ApplicationID)
	) IN DATABASE ERMM;


--
-- M_Bay
--
ECHO Creating table M_Bay...;
--
CREATE TABLE M_Bay (
	BayName VARCHAR ( 192 ) NOT NULL,
	BayAccessible CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	BayID CHARACTER ( 36 ) NOT NULL,
	LibraryID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_Bay93 PRIMARY KEY (BayID)
	) IN DATABASE ERMM;


--
-- M_Cartridge
--
ECHO Creating table M_Cartridge...;
--
CREATE TABLE M_Cartridge (
	CartridgeID CHARACTER ( 36 ) NOT NULL,
	CartridgePCL VARCHAR ( 255 ) NOT NULL,
	CartridgeState SMALLINT DEFAULT 1 NOT NULL,
	CartridgeTimeCreated TIMESTAMP NOT NULL,
	CartridgeTimeMountedLast TIMESTAMP DEFAULT NULL,
	CartridgeTimeMountedTotal INTEGER DEFAULT 0 NOT NULL,
	CartridgeNumberMounts INTEGER DEFAULT 0 NOT NULL,
	CartridgeNumberVolumes INTEGER DEFAULT 0 NOT NULL,
	CartridgeTimeDeallocated TIMESTAMP DEFAULT NULL,
	CartridgeTimeMovedLast TIMESTAMP DEFAULT NULL,
	CartridgeNumberAllocated INTEGER DEFAULT 0 NOT NULL,
	CartridgeTypeID CHARACTER ( 36 ) NOT NULL,
	CartridgeGroupID CHARACTER ( 36 ) DEFAULT NULL,
	ApplicationID CHARACTER ( 36 ) DEFAULT NULL,
	LibraryID CHARACTER ( 36 ) DEFAULT NULL,
	UserAttribute1 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute2 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute3 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute4 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute5 VARCHAR ( 36 ) DEFAULT '0',
	CONSTRAINT PK_M_Cartridge96 PRIMARY KEY (CartridgeID)
	) IN DATABASE ERMM;


--
-- M_CartridgeGroup
--
ECHO Creating table M_CartridgeGroup...;
--
CREATE TABLE M_CartridgeGroup (
	CartridgeGroupName VARCHAR ( 192 ) NOT NULL,
	CartridgeGroupPriority INTEGER DEFAULT 1000 NOT NULL,
	CartridgeGroupLowWaterMark INTEGER DEFAULT 0 NOT NULL,
	CartridgeGroupID CHARACTER ( 36 ) NOT NULL,
	IsScratchPool CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	CONSTRAINT PK_M_CartridgeG102 PRIMARY KEY (CartridgeGroupID)
	) IN DATABASE ERMM;


--
-- M_CartridgeGroupAI
--
ECHO Creating table M_CartridgeGroupAI...;
--
CREATE TABLE M_CartridgeGroupAI (
	Priority INTEGER DEFAULT 1000 NOT NULL,
	CartridgeGroupAIID CHARACTER ( 36 ) NOT NULL,
	AIID CHARACTER ( 36 ) NOT NULL,
	CartridgeGroupID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_CartridgeGAI PRIMARY KEY (CartridgeGroupAIID)
	) IN DATABASE ERMM;


--
-- M_CartridgeGroupApplication
--
ECHO Creating table M_CartridgeGroupApplication...;
--
CREATE TABLE M_CartridgeGroupApplication (
	Priority INTEGER DEFAULT 1000 NOT NULL,
	CartridgeGroupApplicationID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	CartridgeGroupID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_CartridgeG125 PRIMARY KEY (CartridgeGroupApplicationID)
	) IN DATABASE ERMM;


--
-- M_CartridgeShape
--
ECHO Creating table M_CartridgeShape...;
--
CREATE TABLE M_CartridgeShape (
	CartridgeShapeName VARCHAR ( 192 ) NOT NULL,
	CartridgeShapeID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_CartridgeS99 PRIMARY KEY (CartridgeShapeID)
	) IN DATABASE ERMM;

--
-- M_CartridgeType
--
ECHO Creating table M_CartridgeType...;
--
CREATE TABLE M_CartridgeType (
	CartridgeTypeName VARCHAR ( 192 ) NOT NULL,
	CartridgeTypeNumberSides INTEGER DEFAULT 1 NOT NULL,
	CartridgeTypeMediaLength INTEGER NOT NULL,
	CartridgeTypeMediaType SMALLINT DEFAULT 0 NOT NULL,
	MaxUseCount INTEGER NOT NULL,
	CartridgeTypeRWChar SMALLINT DEFAULT 3 NOT NULL,
	CartridgeTypeMaxPartitions INTEGER DEFAULT 1 NOT NULL,
	CartridgeTypeID CHARACTER ( 36 ) NOT NULL,
	CartridgeShapeID CHARACTER ( 36 ),
	CONSTRAINT PK_M_CartridgeT97 PRIMARY KEY (CartridgeTypeID)
	) IN DATABASE ERMM;


--
-- M_CartridgeTypeSide
--
ECHO Creating table M_CartridgeTypeSide...;
--
CREATE TABLE M_CartridgeTypeSide (
	CartridgeTypeSideID CHARACTER ( 36 ) NOT NULL,
	SideNumber SMALLINT NOT NULL,
	SideName VARCHAR ( 192 ) NOT NULL,
	CartridgeTypeID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_CartridgeT137 PRIMARY KEY (CartridgeTypeSideID),
	CONSTRAINT TC_M_CartridgeT269 UNIQUE (SideNumber, CartridgeTypeID)
	) IN DATABASE ERMM;


--@TMG01
-- M_CmcGroup
--
ECHO Creating table M_CmcGroup...;
--
CREATE TABLE M_CmcGroup (
	CmcGroupName VARCHAR ( 192 ) NOT NULL,
	CmcGroupID CHARACTER ( 36 ) NOT NULL,
	CmcLMID CHARACTER ( 36 ),
	MediaType CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_CmcGroup PRIMARY KEY (CmcGroupID)
	);

--@TMG01
-- M_CmcLM
--
-- LMHost is not set on object creation according to 1244.
-- Therefore it should be DEFAULT NULL and not NOT NULL.
--
ECHO Creating table M_CmcLM...;
--
CREATE TABLE M_CmcLM (
	CmcLMName VARCHAR ( 192 ) NOT NULL,
	CmcLMHost VARCHAR ( 192 ) NOT NULL,
	CmcLMStateHard SMALLINT DEFAULT 1 NOT NULL,
	CmcLMStateSoft SMALLINT DEFAULT 1 NOT NULL,
	CmcLMID CHARACTER ( 36 ) NOT NULL,
	CmcGroupID CHARACTER ( 36 ),
	CONSTRAINT PK_M_CmcLM PRIMARY KEY (CmcLMID)
	);


--
-- M_Connection
--
ECHO Creating table M_Connection...;
--
CREATE TABLE M_Connection (
	Language VARCHAR ( 192 ) NOT NULL,
	Version VARCHAR ( 192 ) NOT NULL,
	ConnectionClientID CHARACTER ( 36 ) NOT NULL,
	ConnectionClientInstanceID CHARACTER ( 36 ) NOT NULL,
	ConnectionClientType CHARACTER ( 2 ) NOT NULL,
	ConnectionClientHost VARCHAR ( 192 ) NOT NULL,
	ConnectionClientPort INTEGER NOT NULL,
	ConnectionTimeCreated TIMESTAMP NOT NULL,
	ConnectionTimeLastActive TIMESTAMP DEFAULT NULL,
	ConnectionID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_Connection112 PRIMARY KEY (ConnectionID)
	) IN DATABASE ERMM;


--
-- M_DM
--
ECHO Creating table M_DM...;
--
CREATE TABLE M_DM (
	DMName VARCHAR ( 192 ) NOT NULL,
	DMHost VARCHAR ( 192 ) DEFAULT 'false' NOT NULL,
	DMMessageLevel SMALLINT DEFAULT 4 NOT NULL,
	DMStateHard SMALLINT DEFAULT 1 NOT NULL,
	DMStateSoft SMALLINT DEFAULT 1 NOT NULL,
	DMID CHARACTER ( 36 ) NOT NULL,
	DriveID CHARACTER ( 36 ),
	BusId VARCHAR ( 36 ),	
	ClientVersion VARCHAR ( 36 ),	
	Connection VARCHAR ( 192 ),	
	DMQueue VARCHAR ( 192 ),	
	Device VARCHAR ( 192 ),	
	HDMDriveId VARCHAR ( 192 ),	
	Handle VARCHAR ( 192),	
	HostId VARCHAR ( 36 ),	
	LunId VARCHAR ( 36 ),	
	Manufacturer VARCHAR ( 192 ),	
	Model VARCHAR ( 192 ),	
	ScsiId VARCHAR ( 36 ),	
	SerialNumber VARCHAR ( 36 ),	
	isHDM VARCHAR ( 36 ),	
	key VARCHAR ( 192 ),
	CONSTRAINT PK_M_DM100 PRIMARY KEY (DMID)
	) IN DATABASE ERMM;


--
-- M_DMBitFormat
--
ECHO Creating table M_DMBitFormat...;
--
CREATE TABLE M_DMBitFormat (
	DMBitformatName VARCHAR ( 192 ) NOT NULL,
	DMBitFormatID CHARACTER ( 36 ) NOT NULL,
	DMID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DMBitForma118 PRIMARY KEY (DMBitFormatID)
	) IN DATABASE ERMM;


--
-- M_DMBitFormatToken
--
ECHO Creating table M_DMBitFormatToken...;
--
CREATE TABLE M_DMBitFormatToken (
	DMCapabilityToken VARCHAR ( 192 ) NOT NULL,
	DMBitformatTokenID CHARACTER ( 36 ) NOT NULL,
	DMBitFormatID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DMBitForma119 PRIMARY KEY (DMBitformatTokenID)
	) IN DATABASE ERMM;


--
-- M_DMCapability
--
ECHO Creating table M_DMCapability...;
--
CREATE TABLE M_DMCapability (
	DMCapabilityName VARCHAR ( 192 ) NOT NULL,
	DMCapabilityID CHARACTER ( 36 ) NOT NULL,
	DMID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DMCapabili120 PRIMARY KEY (DMCapabilityID)
	) IN DATABASE ERMM;


--
-- M_DMCapabilityGroup
--
ECHO Creating table M_DMCapabilityGroup...;
--
CREATE TABLE M_DMCapabilityGroup (
	DMCapabilityGroupName VARCHAR ( 192 ) NOT NULL,
	DMCapabilityGroupType SMALLINT DEFAULT 2 NOT NULL,
	DMCapabilityGroupID CHARACTER ( 36 ) NOT NULL,
	DMID CHARACTER ( 36 ) NOT NULL,
	DMCapabilityDefaultToken VARCHAR ( 192 ) NOT NULL,
	CONSTRAINT PK_M_DMCapabili122 PRIMARY KEY (DMCapabilityGroupID)
	) IN DATABASE ERMM;


--
-- M_DMCapabilityGroupToken
--
ECHO Creating table M_DMCapabilityGroupToken...;
--
CREATE TABLE M_DMCapabilityGroupToken (
	DMCapabilityToken VARCHAR ( 192 ) NOT NULL,
	DMCapabilityGroupTokenID CHARACTER ( 36 ) NOT NULL,
	DMCapabilityGroupID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DMCapabili123 PRIMARY KEY (DMCapabilityGroupTokenID)
	) IN DATABASE ERMM;


--
-- M_DMCapabilityToken
--
ECHO Creating table M_DMCapabilityToken...;
--
CREATE TABLE M_DMCapabilityToken (
	DMCapabilityToken VARCHAR ( 192 ) NOT NULL,
	DMCapabilityTokenID CHARACTER ( 36 ) NOT NULL,
	DMCapabilityID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DMCapabili121 PRIMARY KEY (DMCapabilityTokenID)
	) IN DATABASE ERMM;


--
-- M_Drive
--
ECHO Creating table M_Drive...;
--
CREATE TABLE M_Drive (
	DriveName VARCHAR ( 192 ) NOT NULL,
	DrivePriority INTEGER DEFAULT 1000 NOT NULL,
	DriveOnline CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	DriveDisabled SMALLINT DEFAULT 2 NOT NULL,
	DriveBroken CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	DriveStateSoft SMALLINT DEFAULT 2 NOT NULL,
	DriveStateHard SMALLINT DEFAULT 4 NOT NULL,
	DriveTimeCreated TIMESTAMP NOT NULL,
	DriveTimeMountedLast TIMESTAMP,
	DriveTimeMountedTotal INTEGER DEFAULT 0 NOT NULL,
	DriveNumberMounts INTEGER DEFAULT 0 NOT NULL,
	DriveNumberMountsSinceCleaning INTEGER DEFAULT 0 NOT NULL,
	DriveLibraryAccessible CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	DriveLibraryOccupied CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	DriveNeedsCleaning SMALLINT DEFAULT 2 NOT NULL,
	MaxMounts INTEGER DEFAULT 0 NOT NULL,
	DriveID CHARACTER ( 36 ) NOT NULL,
	BayID CHARACTER ( 36 ) NOT NULL,
	DMID CHARACTER ( 36 ) DEFAULT NULL,
	DriveGroupID CHARACTER ( 36 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) DEFAULT NULL,
        Manufacturer VARCHAR ( 192 ),
        Model VARCHAR ( 192 ),
        SerialNumber VARCHAR ( 192 ),
	DriveTaskId VARCHAR ( 192 ),
	UserAttribute1 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute2 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute3 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute4 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute5 VARCHAR ( 36 ) DEFAULT '0',
	CONSTRAINT PK_M_Drive98 PRIMARY KEY (DriveID)
	) IN DATABASE ERMM;



--
-- M_DriveCartridgeAccess
--
ECHO Creating table M_DriveCartridgeAccess...;
--
CREATE TABLE M_DriveCartridgeAccess (
	DriveName VARCHAR ( 192 ) NOT NULL,
	DMName VARCHAR ( 192 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) NOT NULL,
	CartridgePCL VARCHAR ( 255 ) NOT NULL,
	SideName VARCHAR ( 192 ) NOT NULL,
	PartitionName VARCHAR ( 192 ) NOT NULL,
	ApplicationName VARCHAR ( 192 ) NOT NULL,
	AIName VARCHAR ( 192 ) NOT NULL,
	TimeMount TIMESTAMP NOT NULL,
	TimeUnmount TIMESTAMP DEFAULT NULL,
	ByteReadCount DECIMAL(19,0) DEFAULT -1 NOT NULL,
	ByteWriteCount DECIMAL(19,0) DEFAULT -1 NOT NULL,
	HardReadErrorCount DECIMAL(19,0) DEFAULT -1 NOT NULL,
	SoftReadErrorCount DECIMAL(19,0) DEFAULT -1 NOT NULL,
	HardWriteErrorCount DECIMAL(19,0) DEFAULT -1 NOT NULL,
	SoftWriteErrorCount DECIMAL(19,0) DEFAULT -1 NOT NULL,
	DriveCartridgeAccessID CHARACTER ( 36 ) NOT NULL,
        MountLogicalID CHARACTER ( 36 ),
	CONSTRAINT PK_M_DriveCartr126 PRIMARY KEY (DriveCartridgeAccessID)
	) IN DATABASE ERMM;

--
-- M_DriveGroup
--
ECHO Creating table M_DriveGroup...;
--
CREATE TABLE M_DriveGroup (
	DriveGroupName VARCHAR ( 192 ) NOT NULL,
	DriveGroupUnloadTime INTEGER DEFAULT 60 NOT NULL,
	DriveGroupID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DriveGroup101 PRIMARY KEY (DriveGroupID)
	) IN DATABASE ERMM;

--
-- M_DriveGroupAI
--
ECHO Creating table M_DriveGroupAI...;
--
CREATE TABLE M_DriveGroupAI (
	Priority INTEGER DEFAULT 1000 NOT NULL,
	UnloadTime INTEGER DEFAULT 60 NOT NULL,
	DriveGroupAIID CHARACTER ( 36 ) NOT NULL,
	AIID CHARACTER ( 36 ) NOT NULL,
	DriveGroupID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DriveGroupAI PRIMARY KEY (DriveGroupAIID)
	) IN DATABASE ERMM;


--
-- M_DriveGroupApplication
--
ECHO Creating table M_DriveGroupApplication...;
--
CREATE TABLE M_DriveGroupApplication (
	Priority INTEGER DEFAULT 1000 NOT NULL,
	UnloadTime INTEGER DEFAULT 60 NOT NULL,
	DriveGroupApplicationID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	DriveGroupID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_DriveGroup117 PRIMARY KEY (DriveGroupApplicationID)
	) IN DATABASE ERMM;


--
-- M_Library
--@TMG01 : Added LibraryIdentifier, ConnectedLibraryList, CmcGroupID
--               LastAuditTime
--
ECHO Creating table M_Library...;
--
CREATE TABLE M_Library (
	LibraryName VARCHAR ( 192 ) NOT NULL,
	LibraryOnline CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	LibraryDisabled SMALLINT DEFAULT 2 NOT NULL,
	LibraryBroken CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	LibraryStateHard SMALLINT DEFAULT 1 NOT NULL,
	LibraryStateSoft SMALLINT DEFAULT 1 NOT NULL,
	LibraryID CHARACTER ( 36 ) NOT NULL,
	LibraryAccessPath VARCHAR ( 192 ),
	ConnectedLibraryList VARCHAR ( 1024 ),	
	LMID CHARACTER ( 36 ),
	CmcGroupID CHARACTER ( 36 ),	
	LastAuditTime  TIMESTAMP DEFAULT NULL,
	UserAttribute1 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute2 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute3 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute4 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute5 VARCHAR ( 36 ) DEFAULT '0',
	CONSTRAINT PK_M_Library89 PRIMARY KEY (LibraryID)
	) IN DATABASE ERMM;

--
-- M_LM
--
-- LMHost is not set on object creation according to 1244.
-- Therefore it should be DEFAULT NULL and not NOT NULL.
--
ECHO Creating table M_LM...;
--
CREATE TABLE M_LM (
	LMName VARCHAR ( 192 ) NOT NULL,
	LMMessageLevel SMALLINT DEFAULT 4 NOT NULL,
	LMHost VARCHAR ( 192 ) NOT NULL,
	LMStateHard SMALLINT DEFAULT 1 NOT NULL,
	LMStateSoft SMALLINT DEFAULT 1 NOT NULL,
	LMID CHARACTER ( 36 ) NOT NULL,
	LibraryID CHARACTER ( 36 ),
	CONSTRAINT PK_M_LM88 PRIMARY KEY (LMID)
	) IN DATABASE ERMM;


--
-- M_Message
--
ECHO Creating table M_Message...;
--
CREATE TABLE M_Message (
	MessageID CHARACTER ( 36 ) NOT NULL,
	MessageSenderType CHARACTER ( 2 ) NOT NULL,
	MessageSenderName VARCHAR ( 192 ) NOT NULL,
	MessageSenderInstance VARCHAR ( 192 ) NOT NULL,
	MessageLevel SMALLINT DEFAULT 0 NOT NULL,
	MessageText VARCHAR ( 1024 ) NOT NULL,
	MessageTimeCreated TIMESTAMP NOT NULL,
	CONSTRAINT PK_M_Message113 PRIMARY KEY (MessageID)
	) IN DATABASE ERMM;

--
-- M_MountLogical
--
ECHO Creating table M_MountLogical...;
--
CREATE TABLE M_MountLogical (
	MountLogicalHandle VARCHAR ( 255 ) NOT NULL,
	MountLogicalTimeWhenMounted TIMESTAMP NOT NULL,
	MountLogicalID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	VolumeID CHARACTER ( 36 ),
	PartitionID CHARACTER ( 36 ),
	DMCapabilityID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_MountLogic130 PRIMARY KEY (MountLogicalID)
	) IN DATABASE ERMM;


--
-- M_MountPhysical
--
ECHO Creating table M_MountPhysical...;
--
CREATE TABLE M_MountPhysical (
	MountPhysicalTimeWhenMounted TIMESTAMP NOT NULL,
	MountPhysicalID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	DriveID CHARACTER ( 36 ) NOT NULL,
	PartitionID CHARACTER ( 36 ) NOT NULL,
	SlotID CHARACTER ( 36 ),
	CONSTRAINT PK_M_MountPhysi128 PRIMARY KEY (MountPhysicalID)
	) IN DATABASE ERMM;


--
-- M_Partition
--
ECHO Creating table M_Partition...;
--
CREATE TABLE M_Partition (
	PartitionName VARCHAR ( 192 ) NOT NULL,
	PartitionSize INTEGER DEFAULT 0 NOT NULL,
	PartitionAllocatable CHARACTER ( 1 ) DEFAULT 'Y' NOT NULL,
	PartitionSignature VARCHAR ( 1024 ) DEFAULT 'undefined' NOT NULL,
	PartitionSignatureState SMALLINT DEFAULT 1 NOT NULL,
	PartitionSignatureAlgorithm VARCHAR ( 255 ) DEFAULT 'undefined' NOT NULL,
	PartitionMediaSerial VARCHAR ( 255 ) DEFAULT 'undefined' NOT NULL,
	PartitionMediaSerialState SMALLINT DEFAULT 1 NOT NULL,
	PartitionNumberMounts INTEGER DEFAULT 0 NOT NULL,
	PartitionTimeCreated TIMESTAMP NOT NULL,
	PartitionTimeMountedTotal INTEGER DEFAULT 0 NOT NULL,
	PartitionTimeMountedLast TIMESTAMP NOT NULL,
	PartitionID CHARACTER ( 36 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) NOT NULL,
	SideName CHARACTER ( 36 ) DEFAULT 'Side 1',
	PartitionBitFormat CHARACTER ( 36 ) DEFAULT 'unknown',
	CONSTRAINT PK_M_Partition131 PRIMARY KEY (PartitionID)
	) IN DATABASE ERMM;



--
-- M_Request
--
ECHO Creating table M_Request...;
--
CREATE TABLE M_Request (
	RequestID CHARACTER ( 36 ) NOT NULL,
	RequestingClientID CHARACTER ( 36 ) NOT NULL,
	RequestingInstanceID CHARACTER ( 36 ) NOT NULL,
	RequestingClientType VARCHAR ( 255 ) NOT NULL,
	RequestPriority INTEGER NOT NULL,
	RequestState SMALLINT DEFAULT 1 NOT NULL,
	RequestText VARCHAR ( 1024 ) NOT NULL,
	AcceptingSessionID CHARACTER ( 36 ) DEFAULT NULL,
	ResponseText VARCHAR ( 1024 ) DEFAULT NULL,
	RequestTimeCreated TIMESTAMP NOT NULL,
	RequestTimeAccepted TIMESTAMP DEFAULT NULL,
	RequestTimeResponded TIMESTAMP DEFAULT NULL,
	TaskID VARCHAR ( 192 ) NOT NULL,
	CONSTRAINT PK_M_Request111 PRIMARY KEY (RequestID)
	) IN DATABASE ERMM;


--
-- M_Session
--
ECHO Creating table M_Session...;
--
CREATE TABLE M_Session (
	SessionID CHARACTER ( 36 ) NOT NULL,
	Language VARCHAR ( 192 ) NOT NULL,
	SessionAttached CHARACTER ( 1 ) DEFAULT 'Y' NOT NULL,
	SessionClientHost VARCHAR ( 192 ) NOT NULL,
	SessionClientPort INTEGER NOT NULL,
	SessionTimeCreated TIMESTAMP NOT NULL,
	SessionTimeLastActive TIMESTAMP NOT NULL,
	AIID CHARACTER ( 36 ) NOT NULL,
        PRIVILEGELEVEL SMALLINT DEFAULT 0 NOT NULL,
	CONSTRAINT PK_M_Session110 PRIMARY KEY (SessionID)
	) IN DATABASE ERMM;


--
-- M_Slot
--
ECHO Creating table M_Slot...;
--
CREATE TABLE M_Slot (
	SlotName VARCHAR ( 192 ) NOT NULL,
	SlotAccessible CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	SlotOccupied CHARACTER ( 1 ) DEFAULT 'N' NOT NULL,
	SlotID CHARACTER ( 36 ) NOT NULL,
	SlotGroupID CHARACTER ( 36 ) NOT NULL,
	SlotTypeID CHARACTER ( 36 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) DEFAULT NULL,
        SlotLastUpdated TIMESTAMP DEFAULT NULL,
	CONSTRAINT PK_M_Slot94 PRIMARY KEY (SlotID)
	) IN DATABASE ERMM;


--
-- M_SlotConfig
--
ECHO Creating table M_SlotConfig...;
--
CREATE TABLE M_SlotConfig (
	SlotConfigNumberFree INTEGER NOT NULL,
	SlotConfigNumberTotal INTEGER NOT NULL,
	SlotConfigID CHARACTER ( 36 ) NOT NULL,
	BayID CHARACTER ( 36 ) NOT NULL,
	SlotTypeID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_SlotConfig115 PRIMARY KEY (SlotConfigID)
	) IN DATABASE ERMM;


--
-- M_SlotGroup
--
ECHO Creating table M_SlotGroup...;
--
CREATE TABLE M_SlotGroup (
	SlotGroupName VARCHAR ( 192 ) NOT NULL,
	Direction SMALLINT DEFAULT 4 NOT NULL,
	Type SMALLINT DEFAULT 3 NOT NULL,
	SlotGroupID CHARACTER ( 36 ) NOT NULL,
	BayID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_SlotGroup92 PRIMARY KEY (SlotGroupID)
	) IN DATABASE ERMM;


--
-- M_SlotType
--
ECHO Creating table M_SlotType...;
--
CREATE TABLE M_SlotType (
        SlotTypeName VARCHAR ( 192 ) NOT NULL,
        SlotTypeID CHARACTER ( 36 ) NOT NULL,
        CONSTRAINT PK_M_SlotType95 PRIMARY KEY (SlotTypeID)
        ) IN DATABASE ERMM;


--
-- M_SlotTypeCartridgeShape
--
ECHO Creating table M_SlotTypeCartridgeShape...;
--
CREATE TABLE M_SlotTypeCartridgeShape (
        SlotTypeID CHARACTER ( 36 ) NOT NULL,
        CartridgeShapeID CHARACTER ( 36 ) NOT NULL,
        CONSTRAINT TC_M_SlotTypeCa271 PRIMARY KEY (CartridgeShapeID, SlotTypeID)
        ) IN DATABASE ERMM;


--
-- M_StaleHandle
--
ECHO Creating table M_StaleHandle...;
--
CREATE TABLE M_StaleHandle (
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	VolumeID CHARACTER ( 36 ) NOT NULL,
	PartitionID CHARACTER ( 36 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) NOT NULL,
	DriveID CHARACTER ( 36 ) NOT NULL,
	DMID CHARACTER ( 36 ) NOT NULL,
	MountLogicalHandleID CHARACTER ( 36 ) NOT NULL,
	MountLogicalTimeWhenMounted TIMESTAMP NOT NULL,
	StaleHandleID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_StaleHandl129 PRIMARY KEY (StaleHandleID)
	) IN DATABASE ERMM;


--
-- M_System
--
ECHO Creating table M_System...;
--
CREATE TABLE M_System (
	ADMINISTRATOR VARCHAR ( 192 ) DEFAULT 'unknown',
	SYSTEMLOGLEVEL SMALLINT,
	SYSTEMACCEPTLEVEL SMALLINT,
	SYSTEMLOGFILE VARCHAR ( 192 ),
	SYSTEMMESSAGELIMIT INTEGER DEFAULT 100 NOT NULL,
	SYSTEMMESSAGECOUNT INTEGER,
	SYSTEMREQUESTLIMIT INTEGER DEFAULT 100 NOT NULL,
	SYSTEMREQUESTCOUNT INTEGER,
	SYSTEMSYNCLIMIT INTEGER DEFAULT 1000 NOT NULL,
	SYSTEMDCALIMIT INTEGER DEFAULT 100 NOT NULL,
	SYSTEMDCACOUNT INTEGER,
	SYSTEMMAXDISCONNECTTIMEOUT INTEGER,
	SYSTEMSTATE VARCHAR ( 36 ) DEFAULT 'unknown',
	SYSTEMEXTERNALSTATE VARCHAR ( 36 ) DEFAULT 'unknown',
        DEFAULTDRIVEGROUP VARCHAR ( 192 ) DEFAULT NULL,
        DEFAULTCARTRIDGEGROUP VARCHAR ( 192 ) DEFAULT NULL,
        DEFAULTSCRATCHPOOL VARCHAR ( 192 ) DEFAULT NULL,
        ERMMDBVERSION CHARACTER ( 10 ) ,
	SYSTEMREPORTINGLEVEL SMALLINT,
	NoAccessCartridgeGroup VARCHAR (192),	
	NoAccessDriveGroup VARCHAR (192),
	NumTraceFiles VARCHAR (32),
	TraceFile VARCHAR (64),
	TraceFileName VARCHAR (64),
	TraceFileSize VARCHAR (32),
	TraceFileVersions VARCHAR (32),
	TraceLevel VARCHAR (32),
	Tracing VARCHAR (32),
	TracingEnabled VARCHAR (32),
	VersionChecking VARCHAR (32),
	SYSTEMID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_SYSTEM PRIMARY KEY (SYSTEMID)
        ) IN DATABASE ERMM;

--
-- M_Task
--
ECHO Creating table M_Task...;
--
CREATE TABLE M_Task (
	TaskID CHARACTER ( 36 ) NOT NULL,
	TaskType VARCHAR ( 120 ) NOT NULL,
	TaskArrivalTime TIMESTAMP NOT NULL,
	TaskPriority INTEGER DEFAULT 1000 NOT NULL,
	TaskStatement VARCHAR ( 1024 ) NOT NULL,
	TaskState SMALLINT DEFAULT 0 NOT NULL,
	ClientTaskID VARCHAR ( 192 ) NOT NULL,
	SessionID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	AIID CHARACTER ( 36 ) NOT NULL,
	DriveSpecificMount VARCHAR ( 36 ),
	TaskConnection VARCHAR ( 192 ),
	TaskDispatchTime VARCHAR ( 36 ),
	TaskHandle VARCHAR ( 192 ),
	UserHelpState VARCHAR ( 36 ),
	theTaskCartridgeId VARCHAR ( 192 ),
	theTaskCartridgePCL VARCHAR ( 192 ),
	theTaskDriveId VARCHAR ( 192 ),
	theTaskDriveName VARCHAR ( 192 ),
	theTaskLibraryId VARCHAR ( 192 ),
	SourceLibrary VARCHAR ( 192 ),
	CONSTRAINT PK_M_Task109 PRIMARY KEY (TaskID)
	) IN DATABASE ERMM;


--
-- M_TaskCartridge
--
ECHO Creating table M_TaskCartridge...;
--
CREATE TABLE M_TaskCartridge (
	TaskCartridgeID CHARACTER ( 36 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) NOT NULL,
	TaskID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_TaskCartri127 PRIMARY KEY (TaskCartridgeID)
	) IN DATABASE ERMM;


--
-- M_TaskDrive
--
ECHO Creating table M_TaskDrive...;
--
CREATE TABLE M_TaskDrive (
	TaskDriveID CHARACTER ( 36 ) NOT NULL,
	DriveID CHARACTER ( 36 ) NOT NULL,
	TaskID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_TaskDrive116 PRIMARY KEY (TaskDriveID)
	) IN DATABASE ERMM;


--
-- M_TaskLibrary
--
ECHO Creating table M_TaskLibrary...;
--
CREATE TABLE M_TaskLibrary (
	TaskLibraryID CHARACTER ( 36 ) NOT NULL,
	LibraryID CHARACTER ( 36 ) NOT NULL,
	TaskID CHARACTER ( 36 ) NOT NULL,
	CONSTRAINT PK_M_TaskLibrar133 PRIMARY KEY (TaskLibraryID)
	) IN DATABASE ERMM;


--
-- M_Volume
--
ECHO Creating table M_Volume...;
--
CREATE TABLE M_Volume (
	VolumeName VARCHAR ( 192 ) NOT NULL,
	VolumeNumberMounts INTEGER DEFAULT 0 NOT NULL,
	VolumeTimeCreated TIMESTAMP NOT NULL,
	VolumeTimeMountedLast TIMESTAMP DEFAULT NULL,
	VolumeTimeMountedTotal INTEGER DEFAULT 0 NOT NULL,
	VolumeExpiration TIMESTAMP DEFAULT NULL,
        NsrPool VARCHAR ( 192 ) DEFAULT '',
        NsrExpire VARCHAR ( 192 ) DEFAULT '',
        NsrLabelTime VARCHAR ( 192 ) DEFAULT '',
        NsrFull VARCHAR ( 192 ) DEFAULT '',
        NsrJukebox VARCHAR ( 192 ) DEFAULT '',
        NsrMode VARCHAR ( 192 ) DEFAULT '',
        NsrRecycle VARCHAR ( 192 ) DEFAULT '',
	VolumeID CHARACTER ( 36 ) NOT NULL,
	PartitionID CHARACTER ( 36 ) NOT NULL,
	ApplicationID CHARACTER ( 36 ) NOT NULL,
	CartridgeID CHARACTER ( 36 ) NOT NULL,
	UserAttribute1 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute2 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute3 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute4 VARCHAR ( 36 ) DEFAULT '0',
	UserAttribute5 VARCHAR ( 36 ) DEFAULT '0',
	CONSTRAINT PK_M_Volume108 PRIMARY KEY (VolumeID)
	) IN DATABASE ERMM;


--
-- M_GCA
--
ECHO Creating table M_GCA...;
--
CREATE TABLE M_GCA (
	GCAID CHARACTER ( 36 ) NOT NULL,
	GCAName VARCHAR ( 192 ) NOT NULL,
	ObjectID CHARACTER ( 36 ) NOT NULL,
	ObjectType VARCHAR ( 128 ) NOT NULL,
	Abstract VARCHAR ( 2048 ) DEFAULT NULL,
	CONSTRAINT PK_M_GlobalClie136 PRIMARY KEY (GCAID),
	CONSTRAINT TC_M_GlobalClie268 UNIQUE (GCAName, ObjectID)
	) IN DATABASE ERMM;


--
-- M_TestDBConnection
--
ECHO Creating table M_TestDBConnection...;
--
CREATE TABLE M_TestDBConnection (
	DummyChar CHARACTER ( 1 )
	) IN DATABASE ERMM;


--
-- Tables needed for collecting statistical information
--

--
-- M_StatsMount
--
ECHO Creating table M_StatsMount...;
--
CREATE TABLE M_StatsMount (
        MountstatID CHARACTER (36) NOT NULL,
        LibraryName CHARACTER (36) NOT NULL,
        CartridgePCL CHARACTER (36) NOT NULL,
        DriveName CHARACTER (192) NOT NULL,
        ApplicationName  VARCHAR(192) NOT NULL,
        AIName VARCHAR (192) NOT NULL,
        TimeMountStart TIMESTAMP NOT NULL,
        TimeMountEnd TIMESTAMP NOT NULL,
        PendingMountRequests INTEGER,
        NumberDrivesMounted INTEGER,
        CONSTRAINT PK_M_StatsMount PRIMARY KEY (MountstatID)
        );

--
-- M_StatsUnmount
--
ECHO Creating table M_StatsUnmount...;
--
CREATE TABLE M_StatsUnmount (
        UnmountstatID CHARACTER(36) NOT NULL,
        LibraryName VARCHAR(192) NOT NULL,
        CartridgePCL VARCHAR(255) NOT NULL,
        ApplicationName VARCHAR(192) NOT NULL,
        AIName VARCHAR(192) NOT NULL,
        TimeUnmountStart TIMESTAMP NOT NULL,
        TimeUnmountEnd TIMESTAMP NOT NULL,
        TimeMounted TIMESTAMP NOT NULL,
        PendingUnmountRequests INTEGER,
        CONSTRAINT PK_M_StatsUnmount PRIMARY KEY (UnmountstatID)
        );

--
-- M_StatsAudit
--
ECHO Creating table M_StatsAudit...;
--
CREATE TABLE M_StatsAudit (
        AuditstatID CHARACTER (36) NOT NULL,
        LibraryID CHARACTER (36) NOT NULL,
        ApplicationName  VARCHAR(192) NOT NULL,
        AIName VARCHAR (192) NOT NULL,
        TimeAuditStart TIMESTAMP NOT NULL,
        TimeAuditEnd TIMESTAMP NOT NULL,
        AuditScope VARCHAR (255) NOT NULL,
        CONSTRAINT PK_M_StatsAudit PRIMARY KEY (AuditstatID)
        );

--
-- M_StatsEjectC06
--
ECHO Creating table M_StatsEjectC06...;
--
CREATE TABLE M_StatsEjectC06 (
        EjectstatID CHARACTER(36) NOT NULL,
        LibraryName VARCHAR(192) NOT NULL,
        CartridgePCL VARCHAR(255) NOT NULL,
        TimeOfEject TIMESTAMP NOT NULL,
        CONSTRAINT PK_M_StatsEjectC06 PRIMARY KEY (EjectstatID)
        );

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating ERMM Tables.;

-----------------------------------------------------------------------
--
-- End of script CreateTables.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.3 - 12/08/24 01:32:53
--
-- @brief
-- 69422  2012-08-24  ni      Added CmcGroup, CmcLM             @TMG01
-----------------------------------------------------------------------

ECHO Start of creating key indexes for ERMM tables...;

--
-- MUI_AI
--
ECHO Creating index MUI_AI;
--
CREATE UNIQUE INDEX MUI_AI
ON M_AI (AIID);


--
-- MUI_Application
--
ECHO Creating index MUI_Application;
--
CREATE UNIQUE INDEX MUI_Application
ON M_Application (ApplicationID);


--
-- MUI_Bay
--
ECHO Creating index MUI_Bay;
--
CREATE UNIQUE INDEX MUI_Bay
ON M_Bay (BayID);


--
-- MUI_Cartridge
--
ECHO Creating index MUI_Cartridge;
--
CREATE UNIQUE INDEX MUI_Cartridge
ON M_Cartridge (CartridgeID);


--
-- MUI_CartridgeGroup
--
ECHO Creating index MUI_CartridgeGroup;
--
CREATE UNIQUE INDEX MUI_CartridgeGroup
ON M_CartridgeGroup (CartridgeGroupID);


--
-- MUI_CartridgeGroupAI
--
ECHO Creating index MUI_CartridgeGroupAI;
--
CREATE UNIQUE INDEX MUI_CGAI
ON M_CartridgeGroupAI (CartridgeGroupAIID);


--
-- MUI_CartridgeGroupApplication
--
ECHO Creating index MUI_CartridgeGroupApplication;
--
CREATE UNIQUE INDEX MUI_CGApp
ON M_CartridgeGroupApplication (CartridgeGroupApplicationID);


--
-- MUI_CartridgeShape
--
ECHO Creating index MUI_CartridgeShape;
--
CREATE UNIQUE INDEX MUI_CartridgeShape
ON M_CartridgeShape (CartridgeShapeID);


--
-- MUI_CartridgeType
--
ECHO Creating index MUI_CartridgeType;
--
CREATE UNIQUE INDEX MUI_CartridgeType
ON M_CartridgeType (CartridgeTypeID);


--
-- MUI_CartridgeTypeSide
--
ECHO Creating index MUI_CartridgeTypeSide;
--
CREATE UNIQUE INDEX MUI_CartTypeSide0
ON M_CartridgeTypeSide (CartridgeTypeSideID);
CREATE UNIQUE INDEX MUI_CartTypeSide1
ON M_CartridgeTypeSide (SideNumber, CartridgeTypeID);



--@TMG01
-- MUI_CmcGroup
--
ECHO Creating index MUI_CmcGroup;
--
CREATE UNIQUE INDEX MUI_CmcGroup
ON M_CmcGroup (CmcGroupID);


--@TMG01
-- MUI_CmcLM
ECHO Creating index MUI_CmcLM;
--
CREATE UNIQUE INDEX MUI_CmcLM
ON M_CmcLM (CmcLMID);


--
-- MUI_Connection
--
ECHO Creating index MUI_Connection;
--
CREATE UNIQUE INDEX MUI_Connection
ON M_Connection (ConnectionID);


--
-- MUI_DM
--
ECHO Creating index MUI_DM;
--
CREATE UNIQUE INDEX MUI_DM
ON M_DM (DMID);


--
-- MUI_DMBitFormat
--
ECHO Creating index MUI_DMBitFormat;
--
CREATE UNIQUE INDEX MUI_DMBitFormat
ON M_DMBitFormat (DMBitFormatID);


--
-- MUI_DMBitFormatToken
--
ECHO Creating index MUI_DMBitFrmTok;
--
CREATE UNIQUE INDEX MUI_DMBitFrmTok
ON M_DMBitFormatToken (DMBitFormatTokenID);


--
-- MUI_DMCapability
--
ECHO Creating index MUI_DMCapability;
--
CREATE UNIQUE INDEX MUI_DMCapability
ON M_DMCapability (DMCapabilityID);


--
-- MUI_DMCapabilityGroup
--
ECHO Creating index MUI_DMCapGrp;
--
CREATE UNIQUE INDEX MUI_DMCapGrp
ON M_DMCapabilityGroup (DMCapabilityGroupID);


--
-- MUI_DMCapabilityGroupToken
--
ECHO Creating index MUI_DMCapGrpTok;
--
CREATE UNIQUE INDEX MUI_DMCapGrpTok
ON M_DMCapabilityGroupToken (DMCapabilityGroupTokenID);


--
-- MUI_DMCapabilityToken
--
ECHO Creating index MUI_DMCapTok;
--
CREATE UNIQUE INDEX MUI_DMCapTok
ON M_DMCapabilityToken (DMCapabilityTokenID);


--
-- MUI_Drive
--
ECHO Creating index MUI_Drive;
--
CREATE UNIQUE INDEX MUI_Drive
ON M_Drive (DriveID);


--
-- MUI_DriveCartridgeAccess
--
ECHO Creating index MUI_DCA;
--
CREATE UNIQUE INDEX MUI_DCA
ON M_DriveCartridgeAccess (DriveCartridgeAccessID);


--
-- MUI_DriveGroup
--
ECHO Creating index MUI_DriveGroup;
--
CREATE UNIQUE INDEX MUI_DriveGroup
ON M_DriveGroup (DriveGroupID);


--
-- MUI_DriveGroupAI
--
ECHO Creating index MUI_DriveGroupAI;
--
CREATE UNIQUE INDEX MUI_DGAI
ON M_DriveGroupAI (DriveGroupAIID);


--
-- MUI_DriveGroupApplication
--
ECHO Creating index MUI_DGApp;
--
CREATE UNIQUE INDEX MUI_DGApp
ON M_DriveGroupApplication (DriveGroupApplicationID);


--
-- MUI_Library
--
ECHO Creating index MUI_Library;
--
CREATE UNIQUE INDEX MUI_Library
ON M_Library (LibraryID);


--
-- MUI_LM
--
ECHO Creating index MUI_LM;
--
CREATE UNIQUE INDEX MUI_LM
ON M_LM (LMID);


--
-- MUI_Message
--
ECHO Creating index MUI_Message;
--
CREATE UNIQUE INDEX MUI_Message
ON M_Message (MessageID);


--
-- MUI_MountLogical
--
ECHO Creating index MUI_MountLogical;
--
CREATE UNIQUE INDEX MUI_MountLogical
ON M_MountLogical (MountLogicalID);


--
-- MUI_MountPhysical
--
ECHO Creating index MUI_MountPhysical;
--
CREATE UNIQUE INDEX MUI_MountPhysical
ON M_MountPhysical (MountPhysicalID);


--
-- MUI_Partition
--
ECHO Creating index MUI_Partition;
--
CREATE UNIQUE INDEX MUI_Partition
ON M_Partition (PartitionID);


--
-- MUI_Request
--
ECHO Creating index MUI_Request;
--
CREATE UNIQUE INDEX MUI_Request
ON M_Request (RequestID);


--
-- MUI_Session
--
ECHO Creating index MUI_Session;
--
CREATE UNIQUE INDEX MUI_Session
ON M_Session (SessionID);


--
-- MUI_Slot
--
ECHO Creating index MUI_Slot;
--
CREATE UNIQUE INDEX MUI_Slot
ON M_Slot (SlotID);


--
-- MUI_SlotConfig
--
ECHO Creating index MUI_SlotConfig;
--
CREATE UNIQUE INDEX MUI_SlotConfig
ON M_SlotConfig (SlotConfigID);


--
-- MUI_SlotGroup
--
ECHO Creating index MUI_SlotGroup;
--
CREATE UNIQUE INDEX MUI_SlotGroup
ON M_SlotGroup (SlotGroupID);


--
-- MUI_SlotType
--
ECHO Creating index MUI_SlotType;
--
CREATE UNIQUE INDEX MUI_SlotType
ON M_SlotType (SlotTypeID);


--
-- MUI_SlotTypeCartridgeShape
--
ECHO Creating index MUI_STCartShape;
--
CREATE UNIQUE INDEX MUI_STCartShape
ON M_SlotTypeCartridgeShape (CartridgeShapeID, SlotTypeID);


--
-- MUI_StaleHandle
--
ECHO Creating index MUI_StaleHandle;
--
CREATE UNIQUE INDEX MUI_StaleHandle
ON M_StaleHandle (StaleHandleID);


--
-- MUI_System
--
ECHO Creating index MUI_System;
--
CREATE UNIQUE INDEX MUI_System
ON M_System (SystemID);


--
-- MUI_Task
--
ECHO Creating index MUI_Task;
--
CREATE UNIQUE INDEX MUI_Task
ON M_Task (TaskID);


--
-- MUI_TaskCartridge
--
ECHO Creating index MUI_TaskCartridge;
--
CREATE UNIQUE INDEX MUI_TaskCartridge
ON M_TaskCartridge (TaskCartridgeID);


--
-- MUI_TaskDrive
--
ECHO Creating index MUI_TaskDrive;
--
CREATE UNIQUE INDEX MUI_TaskDrive
ON M_TaskDrive (TaskDriveID);


--
-- MUI_TaskLibrary
--
ECHO Creating index MUI_TaskLibrary;
--
CREATE UNIQUE INDEX MUI_TaskLibrary
ON M_TaskLibrary (TaskLibraryID);


--
-- MUI_Volume
--
ECHO Creating index MUI_Volume;
--
CREATE UNIQUE INDEX MUI_Volume
ON M_Volume (VolumeID);


--
-- MUI_GCA
--
ECHO Creating index MUI_GCA;
--
CREATE UNIQUE INDEX MUI_GCA0
ON M_GCA (GCAID);
CREATE UNIQUE INDEX MUI_GCA1
ON M_GCA (GCAName, ObjectID);




--@TMG01
-- MUI_StatsMount
--
ECHO Creating index MUI_StatsMount;
--
CREATE UNIQUE INDEX MUI_StatsMount
ON M_StatsMount (MountstatID);

--@TMG01
-- MUI_StatsUnmount
--
ECHO Creating index MUI_StatsUnmount;
--
CREATE UNIQUE INDEX MUI_StatsUnmount
ON M_StatsUnmount (UnmountstatID);

--@TMG01
-- MUI_StatsAudit
--
ECHO Creating index MUI_StatsAudit;
--
CREATE UNIQUE INDEX MUI_StatsAudit
ON M_StatsAudit (AuditstatID);

--@TMG01
-- MUI_StatsEjectC06
--
ECHO Creating index MUI_StatsEjectC06;
--
CREATE UNIQUE INDEX MUI_StatsEjectC06
ON M_StatsEjectC06 (EjectstatID);



-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating key indexes for ERMM tables.;

-----------------------------------------------------------------------
--
-- End of script CreateKeyIndexes.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:30
--
-- @brief

-----------------------------------------------------------------------

ECHO Start of creating indexes for ERMM tables...;

--
-- MI_BAY
--
ECHO Creating indexes MI_BAY...;
--
CREATE INDEX MI_BAY_LIBRARY ON M_BAY (LIBRARYID);


--
-- MI_CARTRIDGE
--
ECHO Creating indexes MI_CARTRIDGE...;
--
CREATE INDEX MI_CARTR_APPL ON M_Cartridge (ApplicationID);
CREATE INDEX MI_CARTR_LIBRARY ON M_Cartridge (LibraryID);
CREATE INDEX MI_CARTR_GROUPID ON M_Cartridge (CartridgeGroupID);


--
-- MI_DRIVE
--
ECHO Creating indexes MI_DRIVE...;
--
CREATE INDEX MI_DRIVE_BAY ON  M_Drive (BayID);
CREATE INDEX MI_DRIVE_DRVGRP ON  M_Drive (DriveGroupID);
CREATE INDEX MI_DRIVE_DM ON  M_Drive (DMID);
CREATE INDEX MI_DRIVE_CARTRIDGE ON  M_DRIVE (CARTRIDGEID);


--
-- MI_LIBRARY
--
ECHO Creating indexes MI_LIBRARY...;
--
CREATE INDEX MI_LIBRARY_LM ON M_LIBRARY (LMID);


--
-- MI_PARTITION
--
ECHO Creating indexes MI_PARTITION...;
--
CREATE INDEX MI_PARTITION_CART ON  M_Partition (CartridgeID);


--
-- MI_SLOT
--
ECHO Creating indexes MI_SLOT...;
--
CREATE INDEX MI_SLOT_CARTRIDGE ON M_SLOT (CARTRIDGEID);
CREATE INDEX MI_SLOT_SLOTGROUP ON M_SLOT (SLOTGROUPID);
CREATE INDEX MI_SLOT_SLOTTYPE ON M_SLOT (SLOTTYPEID);


--
-- MI_SLOTGROUP
--
ECHO Creating indexes MI_SLOTGROUP...;
--
CREATE INDEX MI_SLOTGROUP_BAY ON M_SLOTGROUP (BAYID);

--
-- MI_VOLUME
--
ECHO Creating indexes MI_VOLUME...;
--
CREATE INDEX MI_VOLUME_CARTRIDG ON  M_Volume (CartridgeID);
CREATE INDEX MI_VOLUME_PARTITIO ON  M_Volume (PartitionID);
CREATE INDEX MI_VOLUME_APPLICAT ON  M_Volume (ApplicationID);

--
-- MI_GCA
--
ECHO Creating indexes MI_GCA...;
--
CREATE INDEX MI_GCA_TYPE_ID ON M_GCA (OBJECTTYPE, OBJECTID);

--
-- MI_GCA
--
ECHO Creating indexes MI_GCA...;
--
CREATE INDEX MI_GCA_OBJ_ID ON M_GCA (OBJECTID);

--
-- MI_DM
--
ECHO Creating indexes MI_DM...;
--
CREATE INDEX MI_DM_NAME_ID ON M_DM (DMNAME,DMID);

--
-- MI_DMBitFormat
--
ECHO Creating indexes MI_DMBitFormat...;
--
CREATE INDEX MI_DMBITFOR_DMID ON M_DMBitFormat (DMID);

--
-- MI_DMCapability
--
ECHO Creating indexes MI_DMCapability...;
--
CREATE INDEX MI_DMCAP_DMID ON M_DMCapability (DMID);

--
-- MI_DMCapabilityGroup
--
ECHO Creating indexes MI_DMCapabilityGroup...;
--
CREATE INDEX MI_DMCAPGRP_DMID ON M_DMCapabilityGroup (DMID);

--
-- MI_DMBitFormatToken
--
ECHO Creating indexes MI_DMBitFormatToken...;
--
CREATE INDEX MI_DMBITTOK_BFID ON M_DMBitFormatToken (DMBitFormatID);

--
-- MI_DMCapabilityToken
--
ECHO Creating indexes MI_DMCapabilityToken...;
--
CREATE INDEX MI_DMCAPTOK_CAPID ON M_DMCapabilityToken (DMcapabilityID);

--
-- MI_DMCapabilityGroupToken
--
ECHO Creating indexes MI_DMCapabilityGroupToken...;
--
CREATE INDEX MI_DMCAGPTK_CGID ON M_DMCapabilityGroupToken (DMCapabilityGroupID);

--
-- MI_Message
--
ECHO Creating indexes MI_Message...;
--
CREATE INDEX MI_MSG_CREATETIME ON M_Message (MessageTimeCreated);

--
-- MI_DRIVECARTRIDGEACCESS
--
ECHO Creating indexes MI_DRIVECARTRIDGEACCESS...;
--
CREATE INDEX MI_DCA_TIMEUNMOUNT ON M_DRIVECARTRIDGEACCESS (TimeUnmount);
CREATE INDEX MI_DCA_MLID ON M_DRIVECARTRIDGEACCESS (MountLogicalId);

--
-- MI_STATSMOUNT
--
ECHO Creating index MI_STATSMOUNT...;
--
CREATE INDEX MI_STATSMOUNT ON M_STATSMOUNT (TIMEMOUNTEND);

--
-- MI_STATSUNMOUNT
--
ECHO Creating index MI_STATSUNMOUNT...;
--
CREATE INDEX MI_STATSUNMOUNT ON M_STATSUNMOUNT (TIMEUNMOUNTSTART, TIMEUNMOUNTEND);

--
-- MI_STATSAUDIT
--
ECHO Creating index MI_STATSAUDIT...;
--
CREATE INDEX MI_STATSAUDIT ON M_STATSAUDIT (TIMEAUDITSTART);

--
-- MI_STATSEJECTC06
--
ECHO Creating index MI_STATSEJECTC06...;
--
CREATE INDEX MI_STATSEJECTC06 ON M_STATSEJECTC06 (TIMEOFEJECT);

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating indexes for ERMM tables.;

-----------------------------------------------------------------------
--
-- End of script CreateIndexes.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.3 - 12/08/24 01:32:51
--
-- @brief

-- 69422  2012-08-24  ni      Added CmcGroup, CmcLM             @TMG01


-----------------------------------------------------------------------

ECHO Start of creating constraint indexes for ERMM tables...;

--
-- MCUI_AI
--
ECHO Creating constraint unique index for M_AI...;
--
CREATE UNIQUE INDEX MCUI_AI
ON M_AI (AINAME, APPLICATIONID);


--
-- MCUI_APPLICATION
--
ECHO Creating constraint unique index for M_Application...;
--
CREATE UNIQUE INDEX MCUI_Application
ON M_Application (APPLICATIONNAME);


--
-- MCUI_BAY
--
ECHO Creating constraint unique index for M_Bay...;
--
CREATE UNIQUE INDEX MCUI_Bay
ON M_Bay (BAYNAME, LIBRARYID);


--
-- MCUI_Cartridge
--
ECHO Creating constraint unique index for M_Cartridge...;
--
CREATE UNIQUE INDEX MCUI_Cartridge
ON M_Cartridge (CARTRIDGEPCL);


--
-- MCUI_CartridgeGroup
--
ECHO Creating constraint unique index for M_CartridgeGroup...;
--
CREATE UNIQUE INDEX MCUI_CARTGROUP
ON M_CartridgeGroup (CARTRIDGEGROUPNAME);


--
-- MCUI_CartridgeGroupApplication
--
ECHO Creating constraint unique index for M_CartridgeGroupApplication...;
--
CREATE UNIQUE INDEX MCUI_CGApp
ON M_CartridgeGroupApplication (APPLICATIONID, CARTRIDGEGROUPID);


--
-- MCUI_CartridgeGroupAI
--
ECHO Creating constraint unique index for M_CartridgeGroupAI...;
--
CREATE UNIQUE INDEX MCUI_CGAI
ON M_CartridgeGroupAI (AIID, CARTRIDGEGROUPID);


--
-- MCUI_CartridgeType
--
ECHO Creating constraint unique index for M_CartridgeType...;
--
CREATE UNIQUE INDEX MCUI_CartridgeType
ON M_CartridgeType (CARTRIDGETYPENAME);


--@TMG01
-- MCUI_CmcGroup
--
ECHO Creating constraint unique index for M_CmcGroup...;
--
CREATE UNIQUE INDEX MCUI_CMCGROUP
ON M_CMCGROUP (CMCGROUPNAME);
--
ECHO Creating unique constraint(mediatype) for M_CmcGroup...;
--
CREATE UNIQUE INDEX MCUI_CMCGROUPM
ON M_CMCGROUP (MEDIATYPE);

--@TMG01
-- MCUI_CmcLM
--
ECHO Creating constraint unique index for M_CmcLM...;
--
CREATE UNIQUE INDEX MCUI_CMCLM
ON M_CMCLM (CMCLMNAME);



--
-- MCUI_Connection
--
ECHO Creating constraint unique index for M_Connection...;
--
CREATE UNIQUE INDEX MCUI_Connection
ON M_Connection (LANGUAGE, VERSION, CONNECTIONCLIENTINSTANCEID, CONNECTIONCLIENTTYPE, CONNECTIONCLIENTHOST, CONNECTIONCLIENTPORT);


--
-- MCUI_DM
--
ECHO Creating constraint unique index for M_DM...;
--
CREATE UNIQUE INDEX MCUI_DM
ON M_DM (DMNAME);


--
-- MCUI_DMBitFormat
--
ECHO Creating constraint unique index for M_DMBitFormat...;
--
CREATE UNIQUE INDEX MCUI_DMBitFormat
ON M_DMBitFormat (DMBITFORMATNAME, DMID);


--
-- MCUI_DMBitFormatToken
--
ECHO Creating constraint unique index for M_DMBitFormatToken...;
--
CREATE UNIQUE INDEX MCUI_DMBitFrmTok
ON M_DMBitFormatToken (DMCAPABILITYTOKEN, DMBITFORMATID);


--
-- MCUI_DMCapability
--
ECHO Creating constraint unique index for M_DMCapability...;
--
CREATE UNIQUE INDEX MCUI_DMCapability
ON M_DMCapability (DMCAPABILITYNAME, DMID);


--
-- MCUI_DMCapabilityGroup
--
ECHO Creating constraint index for M_DMCapabilityGroup...;
--
CREATE UNIQUE INDEX MCUI_DMCapGrp
ON M_DMCapabilityGroup (DMCAPABILITYGROUPNAME, DMID);


--
-- MCUI_DMCapabilityGroupToken
--
ECHO Creating constraint unique index for M_DMCapabilityGroupToken...;
--
CREATE UNIQUE INDEX MCUI_DMCapGrpTok
ON M_DMCapabilityGroupToken (DMCAPABILITYTOKEN, DMCAPABILITYGROUPID);


--
-- MCUI_DMCapabilityToken
--
ECHO Creating constraint index for M_DMCapabilityToken...;
--
CREATE UNIQUE INDEX MCUI_DMCapTok
ON M_DMCapabilityToken (DMCAPABILITYTOKEN, DMCAPABILITYID);


--
-- MCUI_Drive
--
ECHO Creating constraint unique index for M_Drive...;
--
CREATE UNIQUE INDEX MCUI_Drive
ON M_Drive (DRIVENAME);


--
-- MCUI_DriveGroup
--
ECHO Creating constraint unique index for M_DriveGroup...;
--
CREATE UNIQUE INDEX MCUI_DriveGroup
ON M_DriveGroup (DRIVEGROUPNAME);


--
-- MCUI_DriveGroupApplication
--
ECHO Creating constraint unique index for M_DriveGroupApplication...;
--
CREATE UNIQUE INDEX MCUI_DGApp
ON M_DriveGroupApplication (APPLICATIONID, DRIVEGROUPID);


--
-- MCUI_DriveGroupAI
--
ECHO Creating constraint unique index for M_DriveGroupAI...;
--
CREATE UNIQUE INDEX MCUI_DGAI
ON M_DriveGroupAI (AIID, DRIVEGROUPID);

--
-- MCUI_Library
--
ECHO Creating constraint unique index for M_Library...;
--
CREATE UNIQUE INDEX MCUI_Library
ON M_Library (LIBRARYNAME);


--
-- MCUI_LM
--
ECHO Creating constraint unique index for M_LM...;
--
CREATE UNIQUE INDEX MCUI_LM
ON M_LM (LMNAME);


--
-- MCUI_MountPhysical
--
ECHO Creating constraint unique index for M_MountPhysical...;
--
CREATE UNIQUE INDEX MCUI_MountPhysical
ON M_MountPhysical (APPLICATIONID, DRIVEID, PARTITIONID);


--
-- MCUI_Partition
--
ECHO Creating constraint unique index for M_Partition...;
--
CREATE UNIQUE INDEX MCUI_Partition
ON M_Partition (PARTITIONNAME, CARTRIDGEID);


--
-- MCUI_Slot
--
ECHO Creating constraint unique index for M_Slot...;
--
CREATE UNIQUE INDEX MCUI_Slot
ON M_Slot (SLOTNAME, SLOTGROUPID);


--
-- MCUI_SlotConfig
--
ECHO Creating constraint unique index for M_SlotConfig...;
--
CREATE UNIQUE INDEX MCUI_SlotConfig
ON M_SlotConfig (BAYID, SLOTTYPEID);


--
-- MCUI_SlotGroup
--
ECHO Creating constraint unique index for M_SlotGroup...;
--
CREATE UNIQUE INDEX MCUI_SlotGroup
ON M_SlotGroup (SLOTGROUPNAME, BAYID);


--
-- MCUI_SlotType
--
ECHO Creating constraint unique index for M_SlotType...;
--
CREATE UNIQUE INDEX MCUI_SlotType
ON M_SlotType (SLOTTYPENAME);


--
-- MCUI_TaskCartridge
--
ECHO Creating constraint unique index for M_TaskCartridge...;
--
CREATE UNIQUE INDEX MCUI_TaskCartridge
ON M_TaskCartridge (CARTRIDGEID, TASKID);


--
-- MCUI_TaskDrive
--
ECHO Creating constraint unique index for M_TaskDrive...;
--
CREATE UNIQUE INDEX MCUI_TaskDrive
ON M_TaskDrive (DRIVEID, TASKID);


--
-- MCUI_TaskLibrary
--
ECHO Creating constraint unique index for M_TaskLibrary...;
--
CREATE UNIQUE INDEX MCUI_TaskLibrary
ON M_TaskLibrary (LIBRARYID, TASKID);


--
-- MCUI_Volume
--
ECHO Creating constraint unique index for M_Volume...;
--
CREATE UNIQUE INDEX MCUI_Volume
ON M_Volume (VOLUMENAME, APPLICATIONID);


-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating indexes for ERMM tables.;

-----------------------------------------------------------------------
--
-- End of script CreateConstraintIndexes.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.3 - 12/01/24 02:34:57
--
-- @brief foreign key constraints
--
-- CMVC   DATE         NAME   DESCRIPTIONS
--       (MM/DD/YY) 
-- ------ ---------- -------- ----------------------------------------
-- 63073  2010-12-09  ni      Added foreign key for CmcGroup, CmcLM  @TMG01
--                            CmcGroupID in Library
--
-----------------------------------------------------------------------

ECHO Start of creating ERMM foreign keys...;


--
-- M_AI
--
ECHO Creating foreign keys for M_AI...;
--
ALTER TABLE M_AI ADD CONSTRAINT FK_M_AI113 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;


--
-- M_Bay
--
ECHO Creating foreign keys for M_Bay...;
--
ALTER TABLE M_Bay ADD CONSTRAINT FK_M_Bay110 FOREIGN KEY (LibraryID) REFERENCES M_Library (LibraryID)  ON DELETE NO ACTION;


--
-- M_Cartridge
--
ECHO Creating foreign keys for M_Cartridge...;
--
ALTER TABLE M_Cartridge ADD CONSTRAINT FK_M_Cartridge177 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;
ALTER TABLE M_Cartridge ADD CONSTRAINT FK_M_Cartridge185 FOREIGN KEY (LibraryID) REFERENCES M_Library (LibraryID)  ON DELETE NO ACTION;
ALTER TABLE M_Cartridge ADD CONSTRAINT FK_M_Cartridge142 FOREIGN KEY (CartridgeGroupID) REFERENCES M_CartridgeGroup (CartridgeGroupID)  ON DELETE NO ACTION;
ALTER TABLE M_Cartridge ADD CONSTRAINT FK_M_Cartridge128 FOREIGN KEY (CartridgeTypeID) REFERENCES M_CartridgeType (CartridgeTypeID)  ON DELETE NO ACTION;


--
-- M_CartridgeGroupAI
--
ECHO Creating foreign keys for M_CartridgeGroupAI...;
--
ALTER TABLE M_CartridgeGroupAI ADD CONSTRAINT FK_M_CartridgeGAI1 FOREIGN KEY (AIID) REFERENCES M_AI (AIID)  ON DELETE NO ACTION;
ALTER TABLE M_CartridgeGroupAI ADD CONSTRAINT FK_M_CartridgeGAI2 FOREIGN KEY (CartridgeGroupID) REFERENCES M_CartridgeGroup (CartridgeGroupID)  ON DELETE NO ACTION;


--
-- M_CartridgeGroupApplication
--
ECHO Creating foreign keys for M_CartridgeGroupApplication...;
--
ALTER TABLE M_CartridgeGroupApplication ADD CONSTRAINT FK_M_CartridgeG114 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;
ALTER TABLE M_CartridgeGroupApplication ADD CONSTRAINT FK_M_CartridgeG141 FOREIGN KEY (CartridgeGroupID) REFERENCES M_CartridgeGroup (CartridgeGroupID)  ON DELETE NO ACTION;


--
-- M_CartridgeType
--
ECHO Creating foreign keys for M_CartridgeType...;
--
ALTER TABLE M_CartridgeType ADD CONSTRAINT FK_M_CartridgeT134 FOREIGN KEY (CartridgeShapeID) REFERENCES M_CartridgeShape (CartridgeShapeID)  ON DELETE NO ACTION;

--
-- M_CartridgeTypeSide
--
ECHO Creating foreign keys for M_CartridgeTypeSide...;
--
ALTER TABLE M_CartridgeTypeSide ADD CONSTRAINT FK_M_CartridgeT189 FOREIGN KEY (CartridgeTypeID) REFERENCES M_CartridgeType (CartridgeTypeID)  ON DELETE NO ACTION;


--@TMG01
-- M_CmcGroup
--
ECHO Creating foreign keys for M_CmcGroup...;
--
ALTER TABLE M_CmcGroup ADD CONSTRAINT FK_M_CmcGroup FOREIGN KEY (CmcLMID) REFERENCES M_CmcLM (CmcLMID)  ON DELETE NO ACTION;


--@TMG01
-- M_CmcLM
--
ECHO Creating foreign keys for M_CmcLM...;
--
ALTER TABLE M_CmcLM ADD CONSTRAINT FK_M_CmcLM FOREIGN KEY (CmcGroupID) REFERENCES M_CmcGroup (CmcGroupID)  ON DELETE NO ACTION;



--
-- M_DM
--
ECHO Creating foreign keys for M_DM...;
--
ALTER TABLE M_DM ADD CONSTRAINT FK_M_DM132 FOREIGN KEY (DriveID) REFERENCES M_Drive (DriveID)  ON DELETE NO ACTION;


--
-- M_DMBitFormat
--
ECHO Creating foreign keys for M_DMBitFormat...;
--
ALTER TABLE M_DMBitFormat ADD CONSTRAINT FK_M_DMBitForma136 FOREIGN KEY (DMID) REFERENCES M_DM (DMID)  ON DELETE CASCADE;


--
-- M_DMBitFormatToken
--
ECHO Creating foreign keys for M_DMBitFormatToken...;
--
ALTER TABLE M_DMBitFormatToken ADD CONSTRAINT FK_M_DMBitForma162 FOREIGN KEY (DMBitFormatID) REFERENCES M_DMBitFormat (DMBitFormatID)  ON DELETE CASCADE;


--
-- M_DMCapability
--
ECHO Creating foreign keys for M_DMCapability...;
--
ALTER TABLE M_DMCapability ADD CONSTRAINT FK_M_DMCapabili178 FOREIGN KEY (DMID) REFERENCES M_DM (DMID)  ON DELETE CASCADE;


--
-- M_DMCapabilityGroup
--
ECHO Creating foreign keys for M_DMCapabilityGroup...;
--
ALTER TABLE M_DMCapabilityGroup ADD CONSTRAINT FK_M_DMCapabili138 FOREIGN KEY (DMID) REFERENCES M_DM (DMID)  ON DELETE CASCADE;


--
-- M_DMCapabilityGroupToken
--
ECHO Creating foreign keys for M_DMCapabilityGroupToken...;

--
ALTER TABLE M_DMCapabilityGroupToken ADD CONSTRAINT FK_M_DMCapabili165 FOREIGN KEY (DMCapabilityGroupID) REFERENCES M_DMCapabilityGroup (DMCapabilityGroupID)  ON DELETE CASCADE;


--
-- M_DMCapabilityToken
--
ECHO Creating foreign keys for M_DMCapabilityToken...;
--
ALTER TABLE M_DMCapabilityToken ADD CONSTRAINT FK_M_DMCapabili163 FOREIGN KEY (DMCapabilityID) REFERENCES M_DMCapability (DMCapabilityID)  ON DELETE CASCADE;


--
-- M_Drive
--
ECHO Creating foreign keys for M_Drive...;
--
ALTER TABLE M_Drive ADD CONSTRAINT FK_M_Drive118 FOREIGN KEY (BayID) REFERENCES M_Bay (BayID)  ON DELETE NO ACTION;
ALTER TABLE M_Drive ADD CONSTRAINT FK_M_Drive139 FOREIGN KEY (DriveGroupID) REFERENCES M_DriveGroup (DriveGroupID)  ON DELETE NO ACTION;
ALTER TABLE M_Drive ADD CONSTRAINT FK_M_Drive135 FOREIGN KEY (DMID) REFERENCES M_DM (DMID)  ON DELETE NO ACTION;
ALTER TABLE M_Drive ADD CONSTRAINT FK_Drive_Cartridge FOREIGN KEY (CartridgeID) REFERENCES M_Cartridge (CartridgeID) ON DELETE NO ACTION;


--
-- M_DriveGroupAI
--
ECHO Creating foreign keys for M_DriveGroupAI...;
--
ALTER TABLE M_DriveGroupAI ADD CONSTRAINT FK_M_DriveGroupAI1 FOREIGN KEY (AIID) REFERENCES M_AI (AIID)  ON DELETE NO ACTION;
ALTER TABLE M_DriveGroupAI ADD CONSTRAINT FK_M_DriveGroupAI2 FOREIGN KEY (DriveGroupID) REFERENCES M_DriveGroup (DriveGroupID)  ON DELETE NO ACTION;


--
-- M_DriveGroupApplication
--
ECHO Creating foreign keys for M_DriveGroupApplication...;
--
ALTER TABLE M_DriveGroupApplication ADD CONSTRAINT FK_M_DriveGroup115 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;
ALTER TABLE M_DriveGroupApplication ADD CONSTRAINT FK_M_DriveGroup140 FOREIGN KEY (DriveGroupID) REFERENCES M_DriveGroup (DriveGroupID)  ON DELETE NO ACTION;


--
-- M_Library
--@TMG01: Add CmcGroupID in M_Cmcgroup as a foreign key
--
ECHO Creating foreign keys for M_Library...;
--
ALTER TABLE M_Library ADD CONSTRAINT FK_M_Library184 FOREIGN KEY (LMID) REFERENCES M_LM (LMID)  ON DELETE NO ACTION;
ALTER TABLE M_Library ADD CONSTRAINT FK_M_Library1184 FOREIGN KEY (CmcGroupID) REFERENCES M_CmcGroup (CmcGroupID)  ON DELETE NO ACTION;


--
-- M_LM
--
ECHO Creating foreign keys for M_LM...;
--
ALTER TABLE M_LM ADD CONSTRAINT FK_M_LM183 FOREIGN KEY (LibraryID) REFERENCES M_Library (LibraryID)  ON DELETE NO ACTION;


--
-- M_MountLogical
--
ECHO Creating foreign keys for M_MountLogical...;
--
ALTER TABLE M_MountLogical ADD CONSTRAINT FK_M_MountLogic164 FOREIGN KEY (DMCapabilityID) REFERENCES M_DMCapability (DMCapabilityID)  ON DELETE NO ACTION;
ALTER TABLE M_MountLogical ADD CONSTRAINT FK_M_MountLogic155 FOREIGN KEY (VolumeID) REFERENCES M_Volume (VolumeID)  ON DELETE NO ACTION;
ALTER TABLE M_MountLogical ADD CONSTRAINT FK_M_MountLogic194 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;
ALTER TABLE M_MountLogical ADD CONSTRAINT FK_M_MountLogic192 FOREIGN KEY (PartitionID) REFERENCES M_Partition (PartitionID)  ON DELETE NO ACTION;

--
-- M_MountPhysical
--
ECHO Creating foreign keys for M_MountPhysical...;
--
ALTER TABLE M_MountPhysical ADD CONSTRAINT FK_M_MountPhysi129 FOREIGN KEY (DriveID) REFERENCES M_Drive (DriveID)  ON DELETE NO ACTION;
ALTER TABLE M_MountPhysical ADD CONSTRAINT FK_M_MountPhysi182 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;
ALTER TABLE M_MountPhysical ADD CONSTRAINT FK_M_MountPhysi181 FOREIGN KEY (SlotID) REFERENCES M_Slot (SlotID)  ON DELETE NO ACTION;
ALTER TABLE M_MountPhysical ADD CONSTRAINT FK_M_MountPhysi180 FOREIGN KEY (PartitionID) REFERENCES M_Partition (PartitionID)  ON DELETE NO ACTION;


--
-- M_Partition
--
ECHO Creating foreign keys for M_Partition...;
--
ALTER TABLE M_Partition ADD CONSTRAINT FK_M_Partition168 FOREIGN KEY (CartridgeID) REFERENCES M_Cartridge (CartridgeID)  ON DELETE CASCADE;


--
-- M_Request
--
ECHO Creating foreign keys for M_Request...;
--
ALTER TABLE M_Request ADD CONSTRAINT FK_M_Request160 FOREIGN KEY (AcceptingSessionID) REFERENCES M_Session (SessionID) ON DELETE NO ACTION;


--
-- M_Session
--
ECHO Creating foreign keys for M_Session...;
--
ALTER TABLE M_Session ADD CONSTRAINT FK_M_Session169 FOREIGN KEY (AIID) REFERENCES M_AI (AIID)  ON DELETE NO ACTION;


--
-- M_Slot
--
ECHO Creating foreign keys for M_Slot...;
--
ALTER TABLE M_Slot ADD CONSTRAINT FK_M_Slot121 FOREIGN KEY (SlotTypeID) REFERENCES M_SlotType (SlotTypeID)  ON DELETE NO ACTION;
ALTER TABLE M_Slot ADD CONSTRAINT FK_M_Slot126 FOREIGN KEY (CartridgeID) REFERENCES M_Cartridge (CartridgeID)  ON DELETE NO ACTION;
ALTER TABLE M_Slot ADD CONSTRAINT FK_M_Slot117 FOREIGN KEY (SlotGroupID) REFERENCES M_SlotGroup (SlotGroupID)  ON DELETE NO ACTION;


--
-- M_SlotConfig
--
ECHO Creating foreign keys for M_SlotConfig...;
--
ALTER TABLE M_SlotConfig ADD CONSTRAINT FK_M_SlotConfig120 FOREIGN KEY (BayID) REFERENCES M_Bay (BayID)  ON DELETE CASCADE;
ALTER TABLE M_SlotConfig ADD CONSTRAINT FK_M_SlotConfig122 FOREIGN KEY (SlotTypeID) REFERENCES M_SlotType (SlotTypeID)  ON DELETE NO ACTION;


--
-- M_SlotGroup
--
ECHO Creating foreign keys for M_SlotGroup...;
--
ALTER TABLE M_SlotGroup ADD CONSTRAINT FK_M_SlotGroup119 FOREIGN KEY (BayID) REFERENCES M_Bay (BayID)  ON DELETE NO ACTION;


--
-- M_SlotTypeCartridgeShape
--
ECHO Creating foreign keys for M_SlotTypeCartridgeShape...;
--
ALTER TABLE M_SlotTypeCartridgeShape ADD CONSTRAINT FK_M_SlotTypeCa196 FOREIGN KEY (CartridgeShapeID) REFERENCES M_CartridgeShape(CartridgeShapeID) ON DELETE NO ACTION;
ALTER TABLE M_SlotTypeCartridgeShape ADD CONSTRAINT FK_M_SlotTypeCa195 FOREIGN KEY (SlotTypeID) REFERENCES M_SlotType (SlotTypeID) ON DELETE NO ACTION;

--
-- M_Task
--
ECHO Creating foreign keys for M_Task...;
--
ALTER TABLE M_Task ADD CONSTRAINT FK_M_Task161 FOREIGN KEY (SessionID) REFERENCES M_Session (SessionID)  ON DELETE NO ACTION;


--
-- M_TaskCartridge
--
ECHO Creating foreign keys for M_TaskCartridge...;
--
ALTER TABLE M_TaskCartridge ADD CONSTRAINT FK_M_TaskCartri124 FOREIGN KEY (CartridgeID) REFERENCES M_Cartridge (CartridgeID)  ON DELETE NO ACTION;
ALTER TABLE M_TaskCartridge ADD CONSTRAINT FK_M_TaskCartri158 FOREIGN KEY (TaskID) REFERENCES M_Task (TaskID)  ON DELETE CASCADE;


--
-- M_TaskDrive
--
ECHO Creating foreign keys for M_TaskDrive...;
--
ALTER TABLE M_TaskDrive ADD CONSTRAINT FK_M_TaskDrive130 FOREIGN KEY (DriveID) REFERENCES M_Drive (DriveID)  ON DELETE NO ACTION;
ALTER TABLE M_TaskDrive ADD CONSTRAINT FK_M_TaskDrive156 FOREIGN KEY (TaskID) REFERENCES M_Task (TaskID)  ON DELETE CASCADE;


--
-- M_TaskLibrary
--
ECHO Creating foreign keys for M_TaskLibrary...;
--
ALTER TABLE M_TaskLibrary ADD CONSTRAINT FK_M_TaskLibrar111 FOREIGN KEY (LibraryID) REFERENCES M_Library (LibraryID)  ON DELETE NO ACTION;
ALTER TABLE M_TaskLibrary ADD CONSTRAINT FK_M_TaskLibrar157 FOREIGN KEY (TaskID) REFERENCES M_Task (TaskID)  ON DELETE CASCADE;


--
-- M_Volume
--
ECHO Creating foreign keys for M_Volume...;
--
ALTER TABLE M_Volume ADD CONSTRAINT FK_M_Volume167 FOREIGN KEY (PartitionID) REFERENCES M_Partition (PartitionID)  ON DELETE NO ACTION;
ALTER TABLE M_Volume ADD CONSTRAINT FK_M_Volume190 FOREIGN KEY (ApplicationID) REFERENCES M_Application (ApplicationID)  ON DELETE NO ACTION;



-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;

ECHO End of creating ERMM foreign keys.;

-----------------------------------------------------------------------
--
-- End of script CreateForeignConstraints.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2005, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:21
--
-- @brief Create attribute view for db2 zOS

-----------------------------------------------------------------------

ECHO Start of creating ERMM attribute view...;

CREATE VIEW MV_ATTR (
        TABNAME,
        COLNAME,
        TYPENAME,
        LENGTH
        )
AS
SELECT
        A.TBNAME AS TABNAME,
        A.NAME AS COLNAME,
        A.TYPENAME AS TYPENAME,
        A.LENGTH AS LENGTH
FROM
        SYSIBM.SYSCOLUMNS A,
        SYSIBM.SYSTABLES B
WHERE
        B.TYPE='V'
        AND B.DBNAME='ERMM'
        AND A.TBNAME=B.NAME
        AND A.TBNAME like 'MV_%'
        AND NOT A.TBNAME='MV_ATTR';

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;

ECHO End of creating ERMM attribute view.;

-----------------------------------------------------------------------
--
-- End of script CreateAttributeView.db2-ulw.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:43
--
-- @brief

-----------------------------------------------------------------------

ECHO Start of creating ERMM Object Connector table...;

CREATE TABLE M_OBJECTCONNECTOR (
        FIRSTOBJECT VARCHAR ( 30 ) NOT NULL,
        SECONDOBJECT VARCHAR ( 30 ) NOT NULL,
        CONDITION VARCHAR ( 1024 ) NOT NULL
	) IN DATABASE ERMM;

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating ERMM Object Connector table.;

--
-- End of script CreateObjectConnectorTable.sql
-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:39
--
-- @brief

-----------------------------------------------------------------------

ECHO Start of creating ERMM Object Connector index...;

--
-- MUI_ObjectConnector
--
ECHO Creating index MUI_ObjectConnector;
--
CREATE UNIQUE INDEX MUI_ObjConnector ON M_ObjectConnector (FIRSTOBJECT, SECONDOBJECT);

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating ERMM Object Connector table.;

-----------------------------------------------------------------------
--
-- End of script CreateObjectConnectorIndex.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:37
--
-- @brief CreateObjectConnectorData

-----------------------------------------------------------------------

ECHO Start of creating ERMM Object Connector table data...;

--
ECHO Creating connections for AI...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'APPLICATION', 'MV_AI.ApplicationName = MV_APPLICATION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'CARTRIDGE', 'MV_AI.ApplicationName = MV_CARTRIDGE.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'CARTRIDGEGROUP', '(MV_AI.ApplicationName = MV_CARTRIDGEGROUPAPPLICATION.ApplicationName) AND (MV_CARTRIDGEGROUP.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'CARTRIDGEGROUPAPPLICATION', 'MV_AI.ApplicationName = CARTRIDGEGROUPMV_APPLICATION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'CARTRIDGETYPE', '(MV_AI.ApplicationName = MV_CARTRIDGE.ApplicationName) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DM', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DM.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMBITFORMAT', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMBITFORMATTOKEN', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMCABILITYTOKEN', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMCAPABILITY', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMCAPABILITYDEFAULTTOKEN', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMCAPABILITYGROUP', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DMCAPABILITYGROUPTOKEN', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DRIVE', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DRIVECARTRIDGEACCESS', 'MV_AI.ApplicationName = MV_DRIVECARTRIDGEACCESS.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DRIVEGROUP', '(MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVEGROUP.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'DRIVEGROUPAPPLICATION', 'MV_AI.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'MOUNTLOGICAL', 'MV_AI.ApplicationName = MV_MOUNTLOGICAL.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'MOUNTPHYSICAL', 'MV_AI.ApplicationName = MV_MOUNTPHYSICAL.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'PARTITION', '(MV_AI.ApplicationName = MV_CARTRIDGE.ApplicationName) AND (MV_CARTRIDGE.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'REQUEST', '(MV_AI.AIName = MV_TASK.AIName) AND (MV_REQUEST.RequestingTaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'SESSION', 'MV_AI.AIName = MV_SESSION.AIName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'STALEHANDLE', 'MV_AI.ApplicationName = MV_STALEHANDLE.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'TASK', 'MV_AI.AIName = MV_TASK.AIName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'TASKCARTRIDGE', '(MV_AI.AIName = MV_TASK.AIName) AND (MV_TASK.TaskID = MV_TASKCARTRIDGE.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'TASKDRIVE', '(MV_AI.AIName = MV_TASK.AIName) AND (MV_TASK.TaskID = MV_TASKDRIVE.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'TASKLIBRARY', '(MV_AI.AIName = MV_TASK.AIName) AND (MV_TASK.TaskID = MV_TASKLIBRARY.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('AI', 'VOLUME', 'MV_AI.ApplicationName = MV_VOLUME.ApplicationName');


--
ECHO Creating connections for Application...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'CARTRIDGE', '(MV_APPLICATION.ApplicationName = MV_CARTRIDGEGROUPAPPLICATION.ApplicationName) AND (MV_CARTRIDGEGROUPAPPLICATION.CARTRIDGEGROUPNAME = MV_CARTRIDGE.CARTRIDGEGROUPNAME)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'CARTRIDGEGROUP', '(MV_APPLICATION.ApplicationName = MV_CARTRIDGEGROUPAPPLICATION.ApplicationName) AND (MV_CARTRIDGEGROUP.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'CARTRIDGEGROUPAPPLICATION', 'MV_APPLICATION.ApplicationName = MV_CARTRIDGEGROUPAPPLICATION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'CARTRIDGETYPE', '(MV_APPLICATION.ApplicationName = MV_CARTRIDGE.ApplicationName) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DM', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DM.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMBITFORMAT', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMBITFORMATTOKEN', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMCABILITYTOKEN', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMCAPABILITY', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMCAPABILITYDEFAULTTOKEN', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMCAPABILITYGROUP', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DMCAPABILITYGROUPTOKEN', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName) AND (MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DRIVE', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DRIVECARTRIDGEACCESS', 'MV_APPLICATION.ApplicationName = MV_DRIVECARTRIDGEACCESS.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DRIVEGROUP', '(MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName) AND (MV_DRIVEGROUP.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'DRIVEGROUPAPPLICATION', 'MV_APPLICATION.ApplicationName = MV_DRIVEGROUPAPPLICATION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'MOUNTLOGICAL', 'MV_APPLICATION.ApplicationName = MV_MOUNTLOGICAL.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'MOUNTPHYSICAL', 'MV_APPLICATION.ApplicationName = MV_MOUNTPHYSICAL.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'PARTITION', '(MV_APPLICATION.ApplicationName = MV_CARTRIDGEGROUPAPPLICATION.ApplicationName) AND (MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName) AND (MV_CARTRIDGE.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'REQUEST', '(MV_APPLICATION.ApplicationName = MV_TASK.ApplicationName) AND (MV_REQUEST.RequestingTaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'SESSION', 'MV_APPLICATION.ApplicationName = MV_SESSION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'STALEHANDLE', 'MV_APPLICATION.ApplicationName = MV_STALEHANDLE.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'TASK', 'MV_APPLICATION.ApplicationName = MV_TASK.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'TASKCARTRIDGE', '(MV_APPLICATION.ApplicationName = MV_TASK.ApplicationName) AND (MV_TASK.TaskID = MV_TASKCARTRIDGE.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'TASKDRIVE', '(MV_APPLICATION.ApplicationName = MV_TASK.ApplicationName) AND (MV_TASK.TaskID = MV_TASKDRIVE.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'TASKLIBRARY', '(MV_APPLICATION.ApplicationName = MV_TASK.ApplicationName) AND (MV_TASK.TaskID = MV_TASKLIBRARY.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('APPLICATION', 'VOLUME', 'MV_APPLICATION.ApplicationName = MV_VOLUME.ApplicationName');

--
ECHO Creating connections for Bay...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'CARTRIDGE', '(MV_CARTRIDGE.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName) OR (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'CARTRIDGEGROUP', '((MV_CARTRIDGEGROUP.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName) AND (MV_CARTRIDGE.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName)AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)) OR ((MV_CARTRIDGEGROUP.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName))');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'CARTRIDGEGROUPAPPLICATION', '((MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName) AND (MV_CARTRIDGE.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)) OR ((MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName))');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'CARTRIDGETYPE', '((MV_CARTRIDGETYPE.CartridgeTypeName = MV_CARTRIDGE.CartridgeTypeName) AND (MV_CARTRIDGE.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)) OR ((MV_CARTRIDGETYPE.CartridgeTypeName = MV_CARTRIDGE.CartridgeTypeName) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName))');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DM', '(MV_DM.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMBITFORMAT', '(MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMBITFORMATTOKEN', '(MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMCABILITYTOKEN', '(MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMCAPABILITY', '(MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMCAPABILITYDEFAULTTOKEN', '(MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMCAPABILITYGROUP', '(MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DMCAPABILITYGROUPTOKEN', '(MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DRIVE', '(MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DRIVECARTRIDGEACCESS', '(MV_DRIVECARTRIDGEACCESS.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'LIBRARY', 'MV_LIBRARY.LibraryName = MV_BAY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'LM', 'MV_LM.LibraryName = MV_BAY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'MOUNTPHYSICAL', '(MV_MOUNTPHYSICAL.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'PARTITION', '((MV_PARTITION.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)) OR ((MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName))');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'SLOT', '(MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_BAY.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_BAY.BayName) AND (MV_SLOTGROUP.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'STALEHANDLE', '(MV_STALEHANDLE.SlotName = MV_SLOT.SlotName) AND (MV_STALEHANDLE.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.BayName = MV_BAY.BayName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'TASKCARTRIDGE', '((MV_TASKCARTRIDGE.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName) AND (MV_SLOT.LibraryName = MV_BAY.LibraryName)) OR ((MV_TASKCARTRIDGE.CartridgeID = MV_SLOT.CartridgeID) AND (MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName))');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND  (MV_DRIVE.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_BAY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('BAY', 'VOLUME', '((MV_VOLUME.CartridgeID = MV_SLOT.CartridgeID) AND (MV_SLOT.BayName = MV_BAY.BayName) AND  (MV_SLOT.LibraryName = MV_BAY.LibraryName)) OR ((MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.BayName = MV_BAY.BayName) AND (MV_DRIVE.LibraryName = MV_BAY.LibraryName))');


--
ECHO Creating connections for Cartridge...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'CARTRIDGEGROUP', 'MV_CARTRIDGEGROUP.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'CARTRIDGEGROUPAPPLICATION', 'MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName = MV_CARTRIDGE.CartridgeGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'CARTRIDGETYPE', 'MV_CARTRIDGETYPE.CartridgeTypeName = MV_CARTRIDGE.CartridgeTypeName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DM', '(MV_DM.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMBITFORMAT', '(MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMBITFORMATTOKEN', '(MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMCAPABILITYTOKEN', '(MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMCAPABILITY', '(MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMCAPABILITYDEFAULTTOKEN', '(MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMCAPABILITYGROUP', '(MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DMCAPABILITYGROUPTOKEN', '(MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DRIVE', 'MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.CartridgeID = MV_CARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'LIBRARY', 'MV_LIBRARY.LibraryName = MV_CARTRIDGE.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'LM', 'MV_LM.LibraryName = MV_CARTRIDGE.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.CartridgeID = MV_CARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'MOUNTPHYSICAL', '(MV_MOUNTPHYSICAL.PartitionID = MV_Partition.PartitionID) AND (MV_Partition.CartridgeID = MV_CARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'PARTITION', 'MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'SLOT', 'MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_SLOT.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'SLOTGROUP', '(MV_SLOTGROUP.SlotGroupName = MV_SLOT.SlotGroupName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'STALEHANDLE', 'MV_STALEHANDLE.CartridgeID = MV_CARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'TASKCARTRIDGE', 'MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'TASKLIBRARY', 'MV_TASKLIBRARY.LibraryName = MV_CARTRIDGE.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGE', 'VOLUME', 'MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID');


--
ECHO Creating connections for CartridgeGroup...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'CARTRIDGEGROUPAPPLICATION', 'MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'CARTRIDGETYPE', '(MV_CARTRIDGETYPE.CartridgeTypeName = MV_CARTRIDGE.CartridgeTypeName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DM', '(MV_DM.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMBITFORMAT', '(MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMBITFORMATTOKEN', '(MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMCAPABILITYTOKEN', '(MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMCAPABILITY', '(MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMCAPABILITYDEFAULTTOKEN', '(MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMCAPABILITYGROUP', '(MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DMCAPABILITYGROUPTOKEN', '(MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DRIVE', '(MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DRIVECARTRIDGEACCESS', '(MV_DRIVECARTRIDGEACCESS.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'LM', '(MV_LM.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'MOUNTPHYSICAL', '(MOUNTPHYSICAL.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'SLOT', '(MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_SLOT.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'SLOTGROUP', '(MV_SLOTGROUP.SlotGroupName = MV_SLOT.SlotGroupName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'STALEHANDLE', '(MV_STALEHANDLE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUP', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUP.CartridgeGroupName)');


--
ECHO Creating connections for CartridgeGroupApplication...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'CARTRIDGETYPE', '(MV_CARTRIDGETYPE.CartridgeTypeName = MV_CARTRIDGE.CartridgeTypeName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DM', '(MV_DM.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMBITFORMAT', '(MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMBITFORMATTOKEN', '(MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMCAPABILITYTOKEN', '(MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMCAPABILITY', '(MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMCAPABILITYDEFAULTTOKEN', '(MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMCAPABILITYGROUP', '(MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DMCAPABILITYGROUPTOKEN', '(MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DRIVE', '(MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DRIVECARTRIDGEACCESS', '(MV_DRIVECARTRIDGEACCESS.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'LM', '(MV_LM.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'MOUNTPHYSICAL', '(MOUNTPHYSICAL.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'SLOT', '(MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_SLOT.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'SLOTGROUP', '(MV_SLOTGROUP.SlotGroupName = MV_SLOT.SlotGroupName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'STALEHANDLE', '(MV_STALEHANDLE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGEGROUPAPPLICATION', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeGroupName = MV_CARTRIDGEGROUPAPPLICATION.CartridgeGroupName)');


--
ECHO Creating connections for CartridgeType...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DM', '(MV_DM.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMBITFORMAT', '(MV_DMBITFORMAT.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMBITFORMATTOKEN', '(MV_DMBITFORMATTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMCAPABILITYTOKEN', '(MV_DMCAPABILITYTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMCAPABILITY', '(MV_DMCAPABILITY.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMCAPABILITYDEFAULTTOKEN', '(MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMCAPABILITYGROUP', '(MV_DMCAPABILITYGROUP.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DMCAPABILITYGROUPTOKEN', '(MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DRIVE', '(MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DRIVECARTRIDGEACCESS', '(MV_DRIVECARTRIDGEACCESS.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveTypeName = MV_DRIVE.DriveTypeName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'LM', '(MV_LM.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'MOUNTPHYSICAL', '(MOUNTPHYSICAL.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'SLOT', '(MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_SLOT.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'SLOTGROUP', '(MV_SLOTGROUP.SlotGroupName = MV_SLOT.SlotSlotGroupName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'STALEHANDLE', '(MV_STALEHANDLE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('CARTRIDGETYPE', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgeTypeName = MV_CARTRIDGETYPE.CartridgeTypeName)');


--
ECHO Creating connections for DM...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMBITFORMAT', 'MV_DMBITFORMAT.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMBITFORMATTOKEN', 'MV_DMBITFORMATTOKEN.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMCABILITYTOKEN', 'MV_DMCAPABILITYTOKEN.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMCAPABILITY', 'MV_DMCAPABILITY.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMCAPABILITYDEFAULTTOKEN', 'MV_DMCAPABILITYDEFAULTTOKEN.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMCAPABILITYGROUP', 'MV_DMCAPABILITYGROUP.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DRIVE', 'MV_DRIVE.DriveName = MV_DM.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DM.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DM.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DM.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DM.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DM', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DM.DriveName)');


--
ECHO Creating connections for DMBitFormat...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DMBITFORMATTOKEN', 'MV_DMBITFORMATTOKEN.DMBitFormatName = MV_DMBITFORMAT.DMBitFormatName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DMCABILITYTOKEN', 'MV_DMCAPABILITYTOKEN.DMName = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DMCAPABILITY', 'MV_DMCAPABILITY.DMName = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DMCAPABILITYDEFAULTTOKEN', 'MV_DMCAPABILITYDEFAULTTOKEN.DMName = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DMCAPABILITYGROUP', 'MV_DMCAPABILITYGROUP.DMName = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DMName = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMBITFORMAT.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMBITFORMAT.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMBITFORMAT.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMBITFORMAT.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DMBITFORMAT.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMAT', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMBITFORMAT.DriveName)');


--
ECHO Creating connections for DMBitFormatToken...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DMCABILITYTOKEN', 'MV_DMCAPABILITYTOKEN.DMName = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DMCAPABILITY', 'MV_DMCAPABILITY.DMName = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DMCAPABILITYDEFAULTTOKEN', 'MV_DMCAPABILITYDEFAULTTOKEN.DMName = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DMName = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMBITFORMATTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMBITFORMATTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMBITFORMATTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMBITFORMATTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMBITFORMATTOKEN', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMBITFORMATTOKEN.DriveName)');


--
ECHO Creating connections for DMCapabilityToken...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DMCAPABILITY', 'MV_DMCAPABILITY.DMCapabilityName = MV_DMCAPABILITYTOKEN.DMCapabilityName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DMCAPABILITYDEFAULTTOKEN', 'MV_DMCAPABILITYDEFAULTTOKEN.DMName = MV_DMCAPABILITYTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DMCAPABILITYGROUP', 'MV_DMCAPABILITYGROUP.DMName = MV_DMCAPABILITYTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DMName = MV_DMCAPABILITYTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMCAPABILITYTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMCAPABILITYTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMCAPABILITYTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMCAPABILITYTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMCAPABILITYTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMCAPABILITYTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYTOKEN', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYTOKEN.DriveName)');


--
ECHO Creating connections for DMCapability...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DMCAPABILITYDEFAULTTOKEN', 'MV_DMCAPABILITYDEFAULTTOKEN.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DMCAPABILITYGROUP', 'MV_DMCAPABILITYGROUP.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMCAPABILITY.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMCAPABILITY.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMCAPABILITY.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DMCAPABILITY.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITY', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');


--
ECHO Creating connections for DMCapabilityDefaultToken...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'DMCAPABILITYGROUP', 'MV_DMCAPABILITYDEFAULTTOKEN.DMCapabilityToken = MV_DMCAPABILITYGROUP.DMCapabilityGroupDefaultName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITY.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMCAPABILITYDEFAULTTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMCAPABILITYDEFAULTTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMCAPABILITYDEFAULTTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'SLOTTYPE', '(MV_SLOTTYPE.SlotType = MV_SLOT.SLotType) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYDEFAULTTOKEN', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYDEFAULTTOKEN.DriveName)');


--
ECHO Creating connections for DMCapabilityGroup...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'DMCAPABILITYGROUPTOKEN', 'MV_DMCAPABILITYGROUPTOKEN.DMCapabilityGroupName = MV_DMCAPABILITYGROUP.DMCapabilityGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMCAPABILITYGROUP.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMCAPABILITYGROUP.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMCAPABILITYGROUP.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMCAPABILITYGROUP.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMCAPABILITYGROUP.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SLotTypeName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMCAPABILITYGROUP.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUP', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUP.DriveName)');


--
ECHO Creating connections for DMCapabilityGroupToken...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'DRIVE', 'MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_DMCAPABILITYGROUPTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DMName = MV_DMCAPABILITYGROUPTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_DMCAPABILITYGROUPTOKEN.DMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'SLOTTYPE', '(MV_SLOTTYPE.SlotType = MV_SLOT.SlotType) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DMCAPABILITYGROUPTOKEN', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveName = MV_DMCAPABILITYGROUPTOKEN.DriveName)');


--
ECHO Creating connections for Drive...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'DRIVECARTRIDGEACCESS', 'MV_DRIVECARTRIDGEACCESS.DriveName = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'DRIVEGROUP', 'MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'DRIVEGROUPAPPLICATION', 'MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'LIBRARY', 'MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'LM', 'MV_LM.LibraryName = MV_DRIVE.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'MESSAGE', 'MV_MESSAGE.MessageSenderName = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'MOUNTLOGICAL', 'MV_MOUNTLOGICAL.DriveName = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'MOUNTPHYSICAL', 'MV_MOUNTPHYSICAL.DriveName = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'REQUEST', 'MV_REQUEST.RequestingClient = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.LibraryName = MV_SLOT.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.LibraryName = MV_SLOTCONFIG.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.LibraryName = MV_SLOT.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.LibraryName = MV_SLOTGROUP.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'STALEHANDLE', 'MV_STALEHANDLE.DriveName = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'TASKLIBRARY', 'MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVE', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL)');


--
ECHO Creating connections for DriveCartridgeAccess...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'DRIVEGROUP', '(MV_DRIVEGROUP.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'DRIVEGROUPAPPLICATION', '(MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVE.DriveGroupName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'MESSAGE', 'MV_MESSAGE.MessageSenderName = MV_DRIVECARTRIDGEACCESS.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID) AND (MV_MOUNTLOGICAL.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'MOUNTPHYSICAL', '(MV_MOUNTPHYSICAL.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID) AND (MV_MOUNTPHYSICAL.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID) AND (MV_PARTITION.SideName = MV_DRIVECARTRIDGEACCESS.SideName) AND (MV_PARTITION.PartitionName = MV_DRIVECARTRIDGEACCESS.PartitionName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'REQUEST', 'MV_REQUEST.RequestingClient = MV_DRIVECARTRIDGEACCESS.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'SIDE', '(MV_SIDE.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID) AND (MV_Partition.SideName = MV_DRIVECARTRIDGEACCESS.SideName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'SLOT', '(MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'SLOTGROUP', '(MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'STALEHANDLE', '(MV_STALEHANDLE.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID) AND (MV_STALEHANDLE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'TASKCARTRIDGE', 'MV_TASKCARTRIDGE.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveName = MV_DRIVECARTRIDGEACCESS.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVECARTRIDGEACCESS', 'VOLUME', 'MV_VOLUME.CartridgeID = MV_DRIVECARTRIDGEACCESS.CartridgeID');


--
ECHO Creating connections for DriveGroup...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'DRIVEGROUPAPPLICATION', 'MV_DRIVEGROUPAPPLICATION.DriveGroupName = MV_DRIVEGROUP.DriveGroupName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'MESSAGE', '(MV_MESSAGE.MessageSenderName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'MOUNTPHYSICAL', '(MV_MOUNTPHYSICAL.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'REQUEST', '(MV_REQUEST.RequestingClient = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'SLOT', '(MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'SLOTCONFIG', '(MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'SLOTTYPE', '(MV_SLOTTYPE.SlotType = MV_SLOT.SLotType) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'SLOTGROUP', '(MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'STALEHANDLE', '(MV_STALEHANDLE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUP', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUP.DriveGroupName)');


--
ECHO Creating connections for DriveGroupApplication...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'LIBRARY', '(MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'LM', '(MV_LM.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'MESSAGE', '(MV_MESSAGE.MessageSenderName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'MOUNTLOGICAL', '(MV_MOUNTLOGICAL.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'MOUNTPHYSICAL', '(MV_MOUNTPHYSICAL.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'PARTITION', '(MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'REQUEST', '(MV_REQUEST.RequestingClient = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'SLOT', '(MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'SLOTCONFIG', '(MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'SLOTTYPE', '(MV_SLOTTYPE.SlotType = MV_SLOT.SlotType) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'SLOTGROUP', '(MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'STALEHANDLE', '(MV_STALEHANDLE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('DRIVEGROUPAPPLICATION', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.CartridgePCL = MV_DRIVE.CartridgePCL) AND (MV_DRIVE.DriveGroupName = MV_DRIVEGROUPAPPLICATION.DriveGroupName)');


--
ECHO Creating connections for Library...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'LM', 'MV_LIBRARY.LibraryName = MV_LM.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'MESSAGE', 'MV_MESSAGE.MessageSenderName = MV_LIBRARY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'MOUNTLOGICAL', '(MOUNTLOGICCAL.DriveName = MV_DRIVE.DriveName) AND (MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'MOUNTPHYSICAL', 'MV_LIBRARY.LibraryName = MV_MOUNTPHYSICAL.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'PARTITION', '(MV_LIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'REQUEST', 'MV_REQUEST.RequestingClient = MV_LIBRARY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'SLOT', 'MV_LIBRARY.LibraryName = MV_SLOT.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'SLOTCONFIG', 'MV_LIBRARY.LibraryName = MV_SLOTCONFIG.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'SLOTGROUP', 'MV_LIBRARY.LibraryName = MV_SLOTGROUP.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'SLOTTYPE', '(MV_LIBRARY.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'STALEHANDLE', '(MV_STALEHANDLE.DriveName = MV_DRIVE.DriveName) AND (MV_LIBRARY.LibraryName = MV_DRIVE.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'TASK', '(MV_LIBRARY.LibraryName = MV_TASKLIBRARY.LibraryName) AND (MV_TASKLIBRARY.TaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.LibraryName = MV_LIBRARY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.LibraryName = MV_LIBRARY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'TASKLIBRARY', 'MV_TASKLIBRARY.LibraryName = MV_LIBRARY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LIBRARY', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.LibraryName = MV_LIBRARY.LibraryName)');


--
ECHO Creating connections for LM...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'MESSAGE', 'MV_MESSAGE.MessageSenderInstance = MV_LM.LMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'MOUNTLOGICAL', '(MOUNTLOGICCAL.DriveName = MV_DRIVE.DriveName) AND (MV_LM.LibraryName = MV_DRIVE.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'MOUNTPHYSICAL', 'MV_LM.LibraryName = MV_MOUNTPHYSICAL.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'PARTITION', '(MV_LM.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_CARTRIDGE.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'REQUEST', 'MV_REQUEST.RequestingInstance = MV_LM.LMName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'SLOT', 'MV_LM.LibraryName = MV_SLOT.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'SLOTCONFIG', 'MV_LM.LibraryName = MV_SLOTCONFIG.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'SLOTGROUP', 'MV_LM.LibraryName = MV_SLOTGROUP.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'SLOTTYPE', '(MV_LM.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'STALEHANDLE', '(MV_STALEHANDLE.DriveName = MV_DRIVE.DriveName) AND (MV_LM.LibraryName = MV_DRIVE.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'TASK', '(MV_LM.LibraryName = MV_TASKLIBRARY.LibraryName) AND (MV_TASKLIBRARY.TaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.LibraryName = MV_LM.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.LibraryName = MV_LM.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'TASKLIBRARY', 'MV_TASKLIBRARY.LibraryName = MV_LM.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('LM', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_CARTRIDGE.CartridgeID) AND (MV_CARTRIDGE.LibraryName = MV_LM.LibraryName)');


--
ECHO Creating connections for Message...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MESSAGE', 'REQUEST', '(MV_REQUEST.RequestingClientType = MV_MESSAGE.MessageSenderType) AND (MV_REQUEST.RequestingInstance = MV_MESSAGE.MessageSenderInstance) AND (MV_REQUEST.RequestingClient = MV_MESSAGE.MessageSenderName)');


--
ECHO Creating connections for MountLogical...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'MOUNTPHYSICAL', '(MV_MOUNTLOGICAL.CartridgeID = MV_MOUNTPHYSICAL.CartridgeID) AND (MV_MOUNTLOGICAL.SideName = MV_MOUNTPHYSICAL.SideName) AND (MV_MOUNTLOGICAL.ApplicationName = MV_MOUNTPHYSICAL.ApplicationName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'PARTITION', '(MV_MOUNTLOGICAL.CartridgeID = MV_PARTITION.CartridgeID) AND (MV_MOUNTLOGICAL.SideName = MV_PARTITION.SideName) AND (MV_MOUNTLOGICAL.PartitionName = MV_PARTITION.PartitionName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'SESSION', 'MV_MOUNTLOGICAL.ApplicationName = MV_SESSION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'SIDE', '(MV_MOUNTLOGICAL.CartridgeID = MV_Partition.CartridgeID) AND (MV_MOUNTLOGICAL.SideName = MV_Partition.SideName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'STALEHANDLE', '(MV_MOUNTLOGICAL.VolumeName = MV_STALEHANDLE.VolumeName) AND (MV_MOUNTLOGICAL.ApplicationName = MV_STALEHANDLE.ApplicationName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'TASKCARTRIDGE', 'MV_MOUNTLOGICAL.CartridgeID = MV_TASKCARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'TASKDRIVE', 'MV_MOUNTLOGICAL.DriveName = MV_TASKDRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTLOGICAL', 'VOLUME', '(MV_MOUNTLOGICAL.VolumeName = MV_VOLUME.VolumeName) AND (MV_MOUNTLOGICAL.ApplicationName = MV_VOLUME.ApplicationName)');


--
ECHO Creating connections for MountPhysical...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'PARTITION', '(MV_MOUNTPHYSICAL.CartridgeID = MV_PARTITION.CartridgeID) AND (MV_MOUNTPHYSICAL.SideName = MV_PARTITION.SideName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'SESSION', 'MV_MOUNTPHYSICAL.ApplicationName = MV_SESSION.ApplicationName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'SIDE', '(MV_MOUNTPHYSICAL.CartridgeID = MV_Partition.CartridgeID) AND (MV_MOUNTPHYSICAL.SideName = MV_Partition.SideName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'SLOT', '(MV_MOUNTPHYSICAL.SlotName = MV_SLOT.SlotName) AND (MV_MOUNTPHYSICAL.LibraryName = MV_SLOT.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'SLOTCONFIG', 'MV_MOUNTPHYSICAL.LibraryName = MV_SLOTCONFIG.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'SLOTGROUP', '(MV_MOUNTPHYSICAL.SlotName = MV_SLOT.SlotName) AND (MV_MOUNTPHYSICAL.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.SlotGroupName = MV_SLOTGROUP.SlotGroupName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'SLOTTYPE', '(MV_MOUNTPHYSICAL.SlotName = MV_SLOT.SlotName) AND (MV_MOUNTPHYSICAL.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.SlotTypeName = MV_SLOTTYPE.SlotTypeName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'STALEHANDLE', '(MV_MOUNTPHYSICAL.ApplicationName = MV_STALEHANDLE.ApplicationName) AND (MV_MOUNTPHYSICAL.CartridgeID = MV_STALEHANDLE.CartridgeID) AND (MV_MOUNTPHYSICAL.SideName = MV_STALEHANDLE.SideName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'TASKCARTRIDGE', 'MV_MOUNTPHYSICAL.CartridgeID = MV_TASKCARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'TASKDRIVE', 'MV_MOUNTPHYSICAL.DriveName = MV_TASKDRIVE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'TASKLIBRARY', 'MV_MOUNTPHYSICAL.LibraryName = MV_TASKLIBRARY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('MOUNTPHYSICAL', 'VOLUME', '(MV_MOUNTPHYSICAL.SideName = MV_VOLUME.SideName) AND (MV_MOUNTPHYSICAL.CartridgeID = MV_VOLUME.CartridgeID) AND (MV_MOUNTPHYSICAL.ApplicationName = MV_VOLUME.ApplicationName)');


--
ECHO Creating connections for Partition...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'SLOT', '(MV_SLOT.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_SLOT.BayName) AND (MV_SLOT.LibraryName = MV_SLOTCONFIG.LibraryName) AND (MV_SLOT.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'SLOTGROUP', '(MV_SLOTGROUP.SlotGroupName = MV_SLOT.SlotGroupName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName) AND (MV_SLOT.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'SLOTTYPE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'STALEHANDLE', '(MV_STALEHANDLE.CartridgeID = MV_PARTITION.CartridgeID) AND (MV_STALEHANDLE.SideName = MV_PARTITION.SideName) AND (MV_STALEHANDLE.PartitionName = MV_PARTITION.PartitionName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'TASKCARTRIDGE', '(MV_TASKCARTRIDGE.CartridgeID = MV_PARTITION.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'TASKDRIVE', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'TASKLIBRARY', '(MV_TASKLIBRARY.LibraryName = MV_CARTRIDGE.LibraryName) AND (MV_PARTITION.CartridgeID = MV_CARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('PARTITION', 'VOLUME', '(MV_VOLUME.CartridgeID = MV_PARTITION.CartridgeID) AND (MV_VOLUME.SideName = MV_PARTITION.SideName) AND (MV_VOLUME.PartitionName = MV_PARTITION.PartitionName)');


--
ECHO Creating connections for Request...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('REQUEST', 'SESSION', 'MV_REQUEST.AcceptionSessionID = MV_SESSION.SessionID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('REQUEST', 'TASK', 'MV_REQUEST.RequestingTaskID = MV_TASK.TaskID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('REQUEST', 'TASKCARTRIDGE', '(MV_REQUEST.RequestingTaskID = MV_TASK.TaskID) AND (MV_TASKCARTRIDGE.TaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('REQUEST', 'TASKDRIVE', '(MV_REQUEST.RequestingTaskID = MV_TASK.TaskID) AND (MV_TASKDRIVE.TaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('REQUEST', 'TASKLIBRARY', '(MV_REQUEST.RequestingTaskID = MV_TASK.TaskID) AND (MV_TASKLIBRARY.TaskID = MV_TASK.TaskID)');


--
ECHO Creating connections for Session...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SESSION', 'TASK', 'MV_SESSION.SessionID = MV_TASK.SessionID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SESSION', 'TASKCARTRIDGE', '(MV_SESSION.SessionID = MV_TASK.SessionID) AND (MV_TASKCARTRIDGE.TaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SESSION', 'TASKDRIVE', '(MV_SESSION.SessionID = MV_TASK.SessionID) AND (MV_TASKDRIVE.TaskID = MV_TASK.TaskID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SESSION', 'TASKLIBRARY', '(MV_SESSION.SessionID = MV_TASK.SessionID) AND (MV_TASKLIBRARY.TaskID = MV_TASK.TaskID)');


--
ECHO Creating connections for Slot...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'SLOTCONFIG', '(MV_SLOTCONFIG.BayName = MV_SLOT.BayName) AND (MV_SLOTCONFIG.LibraryName = MV_SLOT.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'SLOTGROUP', '(MV_SLOT.SlotGroupName = MV_SLOTGROUP.SlotGroupName) AND (MV_SLOTGROUP.BayName = MV_SLOT.BayName) AND (MV_SLOTGROUP.LibraryName = MV_SLOT.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'SLOTTYPE', 'MV_SLOT.SlotTypeName = MV_SLOTTYPE.SlotTypeName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'TASKCARTRIDGE', 'MV_SLOT.CartridgeID = MV_TASKCARTRIDGE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'TASKDRIVE', '(MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'TASKLIBRARY', 'MV_SLOT.LibraryName = MV_TASKLIBRARY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOT', 'VOLUME', 'MV_SLOT.CartridgeID = MV_VOLUME.CartridgeID');


--
ECHO Creating connections for SlotConfig...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTCONFIG', 'SLOTTYPE', 'MV_SLOTCONFIG.SlotTypeName = MV_SLOTTYPE.SlotTypeName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTCONFIG', 'TASKDRIVE', '(MV_SLOTCONFIG.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOTCONFIG.BayName = MV_DRIVE.BayName) AND (MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTCONFIG', 'TASKLIBRARY', 'MV_SLOTCONFIG.LibraryName = MV_TASKLIBRARY.LibraryName');


--
ECHO Creating connections for SlotGroup...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTGROUP', 'TASKCARTRIDGE', '(MV_SLOT.CartridgeID = MV_TASKCARTRIDGE.CartridgeID) AND (MV_SLOT.SlotGroupName = MV_SLOTGROUP.SlotGroupName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTGROUP', 'TASKDRIVE', '(MV_SLOTGROUP.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOTGROUP.BayName = MV_DRIVE.BayName) AND (MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTGROUP', 'TASKLIBRARY', 'MV_SLOTGROUP.LibraryName = MV_TASKLIBRARY.LibraryName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTGROUP', 'VOLUME', '(MV_SLOT.CartridgeID = MV_VOLUME.CartridgeID) AND (MV_SLOT.SlotGroupName = MV_SLOTGROUP.SlotGroupName)');


--
ECHO Creating connections for SlotType...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTTYPE', 'TASKCARTRIDGE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_TASKCARTRIDGE.CartridgeID)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTTYPE', 'TASKDRIVE', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.LibraryName = MV_DRIVE.LibraryName) AND (MV_SLOT.BayName = MV_DRIVE.BayName) AND (MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTTYPE', 'TASKLIBRARY', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.LibraryName = MV_TASKLIBRARY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('SLOTTYPE', 'VOLUME', '(MV_SLOTTYPE.SlotTypeName = MV_SLOT.SlotTypeName) AND (MV_SLOT.CartridgeID = MV_VOLUME.CartridgeID)');


--
ECHO Creating connections for StaleHandle...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('STALEHANDLE', 'TASKCARTRIDGE', 'MV_TASKCARTRIDGE.CartridgeID = MV_STALEHANDLE.CartridgeID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('STALEHANDLE', 'TASKDRIVE', 'MV_TASKDRIVE.DriveName = MV_STALEHANDLE.DriveName');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('STALEHANDLE', 'TASKLIBRARY', '(MV_STALEHANDLE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.LibraryName = MV_TASKLIBRARY.LibraryName)');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('STALEHANDLE', 'VOLUME', '(MV_STALEHANDLE.VolumeName = MV_VOLUME.VolumeName) AND (MV_STALEHANDLE.ApplicationName = MV_VOLUME.ApplicationName)');


--
ECHO Creating connections for Task...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASK', 'TASKCARTRIDGE', 'MV_TASKCARTRIDGE.TaskID = MV_TASK.TaskID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASK', 'TASKDRIVE', 'MV_TASKDRIVE.TaskID = MV_TASK.TaskID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASK', 'TASKLIBRARY', 'MV_TASKLIBRARY.TaskID = MV_TASK.TaskID');


--
ECHO Creating connections for TaskCartridge...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASKCARTRIDGE', 'TASKDRIVE', 'MV_TASKCARTRIDGE.TaskID = MV_TASKDRIVE.TaskID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASKCARTRIDGE', 'TASKLIBRARY', 'MV_TASKCARTRIDGE.TaskID = MV_TASKLIBRARY.TaskID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASKCARTRIDGE', 'VOLUME', 'MV_TASKCARTRIDGE.CartridgeID = MV_VOLUME.CartridgeID');


--
ECHO Creating connections for TaskDrive...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASKDRIVE', 'TASKLIBRARY', 'MV_TASKLIBRARY.TaskID = MV_TASKDRIVE.TaskID');
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASKDRIVE', 'VOLUME', '(MV_TASKDRIVE.DriveName = MV_DRIVE.DriveName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeID = MV_VOLUME.CartridgeID)');


--
ECHO Creating connections for TaskLibrary...;
--
INSERT INTO M_OBJECTCONNECTOR (FIRSTOBJECT, SECONDOBJECT, CONDITION) VALUES
('TASKLIBRARY', 'VOLUME', '((MV_TASKLIBRARY.LibraryName = MV_DRIVE.LibraryName) AND (MV_DRIVE.CartridgePCL = MV_CARTRIDGE.CartridgePCL) AND (MV_CARTRIDGE.CartridgeID = MV_VOLUME.CartridgeID)) OR ((MV_TASKLIBRARY.LibraryName = MV_SLOT.LibraryName) AND (MV_SLOT.CartridgeID = MV_VOLUME.CartridgeID))');

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;

ECHO End of creating ERMM Object Connector table data.;

-----------------------------------------------------------------------
--
-- End of script CreateObjectConnectorData.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager 
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.4 - 12/01/24 02:35:32
--
-- @brief
-- CMVC   DATE         NAME   DESCRIPTIONS
--       (MM/DD/YY) 
-- ------ ---------- -------- ----------------------------------------
-- 63073  2010-12-09  ni      Added View table for CmcGroup, CmcLM   @TMG01
--                            Added CmcGroupName, LibraryAccessPath, ConnectedLibraryList
--                            in MV_Library
-- 66782  2011-12-13   ni      Added SourceLibrary to mv_task
--                                  LastAuditTime
--

-----------------------------------------------------------------------

ECHO Start of creating ERMM views...;

--
-- MV_AI
--
ECHO Creating view MV_AI...;
--
CREATE VIEW MV_AI (
    AINAME,
    APPLICATIONNAME,
    PRIVILEGE,
    PRIVILEGECHANGEABLE,
    DEFAULTPRIORITY,
    REQUESTACTION,
    AUTHENTICATIONMETHOD,
    AUTHENTICATIONDATA,
    AIDISABLED,
    CONNECTION,
    AIID
) AS
SELECT
    AINAME,
    APPLICATIONNAME,
    CASE PRIVILEGE
        WHEN 0 THEN 'standard'
        ELSE 'administrator'
    END AS PRIVILEGELEVEL,
    CASE PRIVILEGECHANGEABLE
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS PRIVILEGECHANGEABLE,
    DEFAULTPRIORITY,
    REQUESTACTION,
    AUTHENTICATIONMETHOD,
    AUTHENTICATIONDATA,
    AI.AIDISABLED,
    AI.CONNECTION,	
    AIID
FROM
    M_AI AS AI,
    M_APPLICATION AS A
WHERE
    AI.APPLICATIONID = A.APPLICATIONID
;

--
-- MV_APPLICATION
--
ECHO Creating view MV_APPLICATION...;
--
CREATE VIEW MV_APPLICATION (
    APPLICATIONNAME,
    MAXDISCONNECTTIMEOUT,
    SIGNATUREALGORITHM,
    ALLOWREMOTEMOUNT,
    BYPASSVERIFY,
    APPLICATIONID,
    APPLICATIONDISABLED
) AS
SELECT
    APPLICATIONNAME,
    MAXDISCONNECTTIMEOUT,
    SIGNATUREALGORITHM,
    CASE ALLOWREMOTEMOUNT
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS ALLOWREMOTEMOUNT,
    CASE BYPASSVERIFY
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS BYPASSVERIFY,
    APPLICATIONID,
    APPLICATIONDISABLED
FROM
    M_APPLICATION
;

--
-- MV_BAY
--
ECHO Creating view MV_BAY...;
--
CREATE VIEW MV_BAY (
    BAYNAME,
    LIBRARYNAME,
    LMNAME,
    BAYACCESSIBLE,
    BAYID
) AS
SELECT
    BAYNAME,
    LIBRARYNAME,
    LMNAME,
    CASE BAYACCESSIBLE
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS BAYACCESSIBLE,
    BAYID
FROM
    M_BAY AS B,
    M_LIBRARY AS L
    LEFT JOIN M_LM AS LM ON (L.LMID = LM.LMID)
WHERE
    B.LIBRARYID = L.LIBRARYID
;

--
-- MV_CARTRIDGE
--
ECHO Creating view MV_CARTRIDGE...;
--
CREATE VIEW MV_CARTRIDGE (
    CARTRIDGEID,
    CARTRIDGEPCL,
    CARTRIDGESTATE,
    CARTRIDGETYPENAME,
    CARTRIDGETYPEID,
    CARTRIDGEGROUPNAME,
    CARTRIDGEGROUPID,
    CARTRIDGETIMECREATED,
    CARTRIDGETIMEMOUNTEDLAST,
    CARTRIDGETIMEMOUNTEDTOTAL,
    CARTRIDGENUMBERMOUNTS,
    CARTRIDGENUMBERVOLUMES,
    APPLICATIONNAME,
    APPLICATIONID,
    LIBRARYNAME,
    LIBRARYID,
    UserAttribute1,	
    UserAttribute2,	
    UserAttribute3,	
    UserAttribute4,	
    UserAttribute5,
    CARTRIDGETIMEDEALLOCATED,
    CARTRIDGETIMEMOVEDLAST,
    EJECTPENDING
) AS
SELECT
    CARTRIDGEID,
    CARTRIDGEPCL,
    CASE CARTRIDGESTATE
        WHEN 0 THEN 'defined'
        WHEN 1 THEN 'identified'
        WHEN 2 THEN 'allocatable'
        WHEN 3 THEN 'allocated'
        WHEN 4 THEN 'error'
        WHEN 5 THEN 'deallocated'
        ELSE 'recycled'
    END AS CARTRIDGESTATE,
    CARTRIDGETYPENAME,
    C.CARTRIDGETYPEID,
    CARTRIDGEGROUPNAME,
    C.CARTRIDGEGROUPID,
    CARTRIDGETIMECREATED,
    CARTRIDGETIMEMOUNTEDLAST,
    CARTRIDGETIMEMOUNTEDTOTAL,
    CARTRIDGENUMBERMOUNTS,
    CARTRIDGENUMBERVOLUMES,
    APPLICATIONNAME,
    C.APPLICATIONID,
    L.LIBRARYNAME,
    C.LIBRARYID,
    C.UserAttribute1,		
    C.UserAttribute2,	
    C.UserAttribute3,	
    C.UserAttribute4,	
    C.UserAttribute5,
    CARTRIDGETIMEDEALLOCATED,
    CARTRIDGETIMEMOVEDLAST,
    CASE CARTRIDGENUMBERALLOCATED
        WHEN 0 THEN 'false'
        ELSE 'true'
    END AS EJECTPENDING
FROM
    M_CARTRIDGE AS C
    LEFT JOIN M_CARTRIDGEGROUP AS CG ON
        (C.CARTRIDGEGROUPID = CG.CARTRIDGEGROUPID)
    LEFT JOIN M_APPLICATION AS A ON
        (C.APPLICATIONID = A.APPLICATIONID)
    LEFT JOIN M_LIBRARY AS L ON
        (C.LIBRARYID = L.LIBRARYID)
    LEFT JOIN M_CARTRIDGETYPE AS CT ON
        (C.CARTRIDGETYPEID = CT.CARTRIDGETYPEID)
;

--
-- MV_CARTRIDGEGROUP
--
ECHO Creating view MV_CARTRIDGEGROUP...;
--
CREATE VIEW MV_CARTRIDGEGROUP (
    CARTRIDGEGROUPNAME,
    CARTRIDGEGROUPPRIORITY,
    CARTRIDGEGROUPLOWWATERMARK,
    ISSCRATCHPOOL,
    CARTRIDGEGROUPID
) AS
SELECT
    CARTRIDGEGROUPNAME,
    CARTRIDGEGROUPPRIORITY,
    CARTRIDGEGROUPLOWWATERMARK,
    CASE ISSCRATCHPOOL
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS ISSCRATCHPOOL,
    CG.CARTRIDGEGROUPID
FROM
    M_CARTRIDGEGROUP AS CG
;

--
-- MV_CARTRIDGEGROUPAPPLICATION
--
ECHO Creating view MV_CARTRIDGEGROUPAPPLICATION...;
--
CREATE VIEW MV_CARTRIDGEGROUPAPPLICATION (
    APPLICATIONNAME,
    CARTRIDGEGROUPNAME,
    PRIORITY,
    CARTRIDGEGROUPAPPLICATIONID
) AS
SELECT
    APPLICATIONNAME,
    CARTRIDGEGROUPNAME,
    PRIORITY,
    CGA.CARTRIDGEGROUPAPPLICATIONID
FROM
    M_CARTRIDGEGROUPAPPLICATION AS CGA,
    M_CARTRIDGEGROUP AS CG,
    M_APPLICATION AS A
WHERE
    CGA.CARTRIDGEGROUPID = CG.CARTRIDGEGROUPID
    AND CGA.APPLICATIONID = A.APPLICATIONID
;

--
-- MV_CARTRIDGEGROUPAI
--
ECHO Creating view MV_CARTRIDGEGROUPAI...;
--
CREATE VIEW MV_CARTRIDGEGROUPAI (
    AINAME,
    CARTRIDGEGROUPNAME,
    PRIORITY,
    CARTRIDGEGROUPAIID
) AS
SELECT
    AINAME,
    CARTRIDGEGROUPNAME,
    PRIORITY,
    CGAI.CARTRIDGEGROUPAIID
FROM
    M_CARTRIDGEGROUPAI AS CGAI,
    M_CARTRIDGEGROUP AS CG,
    M_AI AS A
WHERE
    CGAI.CARTRIDGEGROUPID = CG.CARTRIDGEGROUPID
    AND CGAI.AIID = A.AIID
;

--
-- MV_CARTRIDGETYPE
--
ECHO Creating view MV_CARTRIDGETYPE...;
--
CREATE VIEW MV_CARTRIDGETYPE (
    CARTRIDGETYPENAME,
    CARTRIDGETYPENUMBERSIDES,
    CARTRIDGETYPEMEDIALENGTH,
    CARTRIDGETYPEMEDIATYPE,
    MAXUSECOUNT,
    CARTRIDGESHAPENAME,
    CARTRIDGETYPERWCHAR,
    CARTRIDGETYPEMAXPARTITIONS,
    CARTRIDGETYPEID
) AS
SELECT
    CARTRIDGETYPENAME,
    CARTRIDGETYPENUMBERSIDES,
    CARTRIDGETYPEMEDIALENGTH,
    CASE CARTRIDGETYPEMEDIATYPE
        WHEN 0 THEN 'undefined'
        WHEN 1 THEN 'data'
        WHEN 2 THEN 'cleaning'
        WHEN 3 THEN 'diagnostic'
        WHEN 4 THEN 'microcode'
        ELSE 'alignment'
    END AS CARTRIDGETYPEMEDIATYPE,
    MAXUSECOUNT,
    CARTRIDGESHAPENAME,
    CASE CARTRIDGETYPERWCHAR
        WHEN 0 THEN 'undefined'
        WHEN 1 THEN 'readonly'
        WHEN 2 THEN 'writeonly'
        ELSE 'readwrite'
    END AS CARTRIDGETYPERWCHAR,
    CARTRIDGETYPEMAXPARTITIONS,
    CARTRIDGETYPEID
FROM
    M_CARTRIDGETYPE AS CT
    LEFT JOIN M_CARTRIDGESHAPE AS CS ON
        (CT.CARTRIDGESHAPEID = CS.CARTRIDGESHAPEID)
;


--@TMG01
-- MV_CMCGROUP
--
ECHO Creating view MV_CMCGROUP...;
--
CREATE VIEW MV_CMCGROUP (
    CMCLMNAME,
    CMCGROUPNAME,
    CMCGROUPID,
    MEDIATYPE
) AS
SELECT
    CMCLMNAME,
    CMCGROUPNAME,
    CG.CMCGROUPID,
    MEDIATYPE
FROM
    M_CMCGROUP AS CG
    LEFT JOIN M_CMCLM AS CL ON
        (CG.CMCLMID = CL.CMCLMID)
;

--@TMG01
-- MV_CMCLM
--
ECHO Creating view MV_CMCLM...;
--
CREATE VIEW MV_CMCLM (
    CMCGROUPNAME,
    CMCLMNAME,
    CMCLMHOST,
    CMCLMSTATEHARD,
    CMCLMSTATESOFT,
    CMCLMID
) AS
SELECT
    CMCGROUPNAME,
    CMCLMNAME,
    CMCLMHOST,
    CASE CMCLMSTATEHARD
        WHEN 0 THEN 'ready'
        ELSE 'broken'
    END AS CMCLMSTATEHARD,
    CASE CMCLMSTATESOFT
        WHEN 0 THEN 'absent'
        WHEN 1 THEN 'present'
        WHEN 2 THEN 'notready'
        WHEN 3 THEN 'disconnected'
        ELSE 'ready'
    END AS CMCLMSTATESOFT,
    CL.CMCLMID
FROM
    M_CMCLM AS CL
    LEFT JOIN M_CMCGROUP AS CG ON
        (CL.CMCGROUPID = CG.CMCGROUPID)
;



--
-- MV_CONNECTION
--
ECHO Creating view MV_CONNECTION...;
--
CREATE VIEW MV_CONNECTION (
    LANGUAGE,
    VERSION,
    CONNECTIONCLIENTNAME,
    CONNECTIONCLIENTINSTANCE,
    CONNECTIONCLIENTHOST,
    CONNECTIONCLIENTPORT,
    CONNECTIONTIMECREATED,
    CONNECTIONTIMELASTACTIVE,
    CONNECTIONID,
    CONNECTIONCLIENTTYPE
) AS
SELECT
    LANGUAGE,
    VERSION,
    APPLICATIONNAME AS CONNECTIONCLIENTNAME,
    AINAME AS CONNECTIONCLIENTINSTANCE,
    CONNECTIONCLIENTHOST,
    CONNECTIONCLIENTPORT,
    CONNECTIONTIMECREATED,
    CONNECTIONTIMELASTACTIVE,
    CONNECTIONID,
    CONNECTIONCLIENTTYPE
FROM
    M_CONNECTION AS C,
    M_AI AS AI,
    M_APPLICATION AS A
WHERE
    UCASE(C.CONNECTIONCLIENTTYPE) = 'AI'
    AND C.CONNECTIONCLIENTINSTANCEID = AI.AIID
    AND C.CONNECTIONCLIENTID = A.APPLICATIONID
UNION ALL
SELECT
    LANGUAGE,
    VERSION,
    LIBRARYNAME AS CONNECTIONCLIENTNAME,
    LMNAME AS CONNECTIONCLIENTINSTANCE,
    CONNECTIONCLIENTHOST,
    CONNECTIONCLIENTPORT,
    CONNECTIONTIMECREATED,
    CONNECTIONTIMELASTACTIVE,
    CONNECTIONID,
    CONNECTIONCLIENTTYPE
FROM
    M_CONNECTION AS C,
    M_LM AS LM,
    M_LIBRARY AS L
WHERE
    UCASE(C.CONNECTIONCLIENTTYPE) = 'LM'
    AND C.CONNECTIONCLIENTID = L.LIBRARYID
    AND C.CONNECTIONCLIENTINSTANCEID = LM.LMID
UNION ALL
SELECT
    LANGUAGE,
    VERSION,
    DRIVENAME AS CONNECTIONCLIENTNAME,
    DMNAME AS CONNECTIONCLIENTINSTANCE,
    CONNECTIONCLIENTHOST,
    CONNECTIONCLIENTPORT,
    CONNECTIONTIMECREATED,
    CONNECTIONTIMELASTACTIVE,
    CONNECTIONID,
    CONNECTIONCLIENTTYPE
FROM
    M_CONNECTION AS C,
    M_DM AS DM,
    M_DRIVE AS D
WHERE
    UCASE(C.CONNECTIONCLIENTTYPE) = 'DM'
    AND C.CONNECTIONCLIENTID = D.DRIVEID
    AND C.CONNECTIONCLIENTINSTANCEID = DM.DMID
;

--
-- MV_DM
--
ECHO Creating view MV_DM...;
--
CREATE VIEW MV_DM (
    DMNAME,
    DRIVENAME,
    DMHOST,
    DMMESSAGELEVEL,
    DMSTATEHARD,
    DMSTATESOFT,
    BusId,	
    ClientVersion,	
    Connection,	
    DMQueue,	
    Device,	
    HDMDriveId,	
    Handle,	
    HostId,	
    LunId,	
    Manufacturer,	
    Model,	
    ScsiId,	
    SerialNumber,	
    isHDM,	
    key,	
    DMID
) AS
SELECT
    DMNAME,
    DRIVENAME,
    DMHOST,
    CASE DMMESSAGELEVEL
        WHEN 0 THEN 'emergency'
        WHEN 1 THEN 'alert'
        WHEN 2 THEN 'critical'
        WHEN 3 THEN 'error'
        WHEN 4 THEN 'warning'
        WHEN 5 THEN 'notice'
        WHEN 6 THEN 'information'
        WHEN 7 THEN 'debug'
        ELSE 'developer'
    END AS DMMESSAGELEVEL,
    CASE DMSTATEHARD
        WHEN 0 THEN 'ready'
        ELSE 'broken'
    END AS DMSTATEHARD,
    CASE DMSTATESOFT
        WHEN 0 THEN 'absent'
        WHEN 1 THEN 'present'
        WHEN 2 THEN 'notready'
        WHEN 3 THEN 'disconnected'
        WHEN 4 THEN 'ready'
        ELSE 'reserved'
    END AS DMSTATESOFT,
    DM.BusId,	
    DM.ClientVersion,	
    DM.Connection,	
    DM.DMQueue,	
    DM.Device,	
    DM.HDMDriveId,	
    DM.Handle,	
    DM.HostId,	
    DM.LunId,	
    DM.Manufacturer,	
    DM.Model,	
    DM.ScsiId,	
    DM.SerialNumber,	
    DM.isHDM,	
    DM.key, 
    DM.DMID
FROM
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
;

--
-- MV_DMBITFORMAT
--
ECHO Creating view MV_DMBITFORMAT...;
--
CREATE VIEW MV_DMBITFORMAT (
    DRIVENAME,
    DMNAME,
    DMBITFORMATNAME,
    DMBITFORMATID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMBITFORMATNAME,
    DMBITFORMATID
FROM
    M_DMBITFORMAT AS DF,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DF.DMID = DM.DMID
;

--
-- MV_DMBITFORMATTOKEN
--
ECHO Creating view MV_DMBITFORMATTOKEN...;
--
CREATE VIEW MV_DMBITFORMATTOKEN (
    DRIVENAME,
    DMNAME,
    DMBITFORMATNAME,
    DMCAPABILITYTOKEN,
    DMBITFORMATTOKENID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMBITFORMATNAME,
    DMCAPABILITYTOKEN,
    DMBITFORMATTOKENID
FROM
    M_DMBITFORMATTOKEN AS DFT,
    M_DMBITFORMAT AS DF,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DFT.DMBITFORMATID = DF.DMBITFORMATID
    AND DF.DMID = DM.DMID
;

--
-- MV_DMCAPABILITY
--
ECHO Creating view MV_DMCAPABILITY...;
--
CREATE VIEW MV_DMCAPABILITY (
    DRIVENAME,
    DMNAME,
    DMCAPABILITYNAME,
    DMCAPABILITYID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMCAPABILITYNAME,
    DMCAPABILITYID
FROM
    M_DMCAPABILITY AS DC,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DC.DMID = DM.DMID
;

--
-- MV_DMCAPABILITYDEFAULTTOKEN
-- This view is emulated from M_DMCAPABILITYGROUP table
--
ECHO Creating view MV_DMCAPABILITYDEFAULTTOKEN...;
--
CREATE VIEW MV_DMCAPABILITYDEFAULTTOKEN (
    DRIVENAME,
    DMNAME,
    DMCAPABILITYTOKEN,
    DMCAPABILITYDEFAULTTOKENID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMCAPABILITYDEFAULTTOKEN,
    'DMCAPABILITYDEFAULTTOKEN'||DMCAPABILITYGROUPID
FROM
    M_DMCAPABILITYGROUP AS DCG,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DCG.DMID = DM.DMID
;


--
-- MV_DMCAPABILITYGROUP
--
ECHO Creating view MV_DMCAPABILITYGROUP...;
--
CREATE VIEW MV_DMCAPABILITYGROUP (
    DRIVENAME,
    DMNAME,
    DMCAPABILITYGROUPNAME,
    DMCAPABILITYGROUPDEFAULTNAME,
    DMCAPABILITYGROUPTYPE,
    DMCAPABILITYGROUPID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMCAPABILITYGROUPNAME,
    DMCAPABILITYDEFAULTTOKEN,
    CASE DMCAPABILITYGROUPTYPE
        WHEN 0 THEN 'access'
        WHEN 1 THEN 'interchange'
        ELSE 'unknown'
    END AS DMCAPABILITYGROUPTYPE,
    DMCAPABILITYGROUPID
FROM
    M_DMCAPABILITYGROUP AS DCG,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DCG.DMID = DM.DMID
;

--
-- MV_DMCAPABILITYGROUPTOKEN
--
ECHO Creating view MV_DMCAPABILITYGROUPTOKEN...;
--
CREATE VIEW MV_DMCAPABILITYGROUPTOKEN (
    DRIVENAME,
    DMNAME,
    DMCAPABILITYGROUPNAME,
    DMCAPABILITYTOKEN,
    DMCAPABILITYGROUPTOKENID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMCAPABILITYGROUPNAME,
    DMCAPABILITYTOKEN,
    DMCAPABILITYGROUPTOKENID
FROM
    M_DMCAPABILITYGROUPTOKEN AS DCGT,
    M_DMCAPABILITYGROUP AS DCG,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DCGT.DMCAPABILITYGROUPID = DCG.DMCAPABILITYGROUPID
    AND DCG.DMID = DM.DMID
;

--
-- MV_DMCAPABILITYTOKEN
--
ECHO Creating view MV_DMCAPABILITYTOKEN...;
--
CREATE VIEW MV_DMCAPABILITYTOKEN (
    DRIVENAME,
    DMNAME,
    DMCAPABILITYNAME,
    DMCAPABILITYTOKEN,
    DMCAPABILITYTOKENID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    DMCAPABILITYNAME,
    DMCAPABILITYTOKEN,
    DMCAPABILITYTOKENID
FROM
    M_DMCAPABILITYTOKEN AS DCT,
    M_DMCAPABILITY AS DC,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    DCT.DMCAPABILITYID = DC.DMCAPABILITYID
    AND DC.DMID = DM.DMID
;

--
-- MV_DRIVE
--
ECHO Creating view MV_DRIVE...;
--
CREATE VIEW MV_DRIVE (
    DRIVENAME,
    DRIVEGROUPNAME,
    DRIVEPRIORITY,
    DMNAME,
    DRIVEDISABLED,
    DRIVEBROKEN,
    DRIVEONLINE,
    DRIVESTATESOFT,
    DRIVESTATEHARD,
    DRIVETIMECREATED,
    DRIVETIMEMOUNTEDLAST,
    DRIVETIMEMOUNTEDTOTAL,
    DRIVENUMBERMOUNTS,
    DRIVENUMBERMOUNTSSINCECLEANING,
    LIBRARYNAME,
    BAYNAME,
    DRIVELIBRARYACCESSIBLE,
    DRIVELIBRARYOCCUPIED,
    CARTRIDGEPCL,
    DRIVENEEDSCLEANING,
    MAXMOUNTS,
    MANUFACTURER,
    MODEL,
    SERIALNUMBER,
    DRIVEID,
    DriveTaskId,
    UserAttribute1,	
    UserAttribute2,	
    UserAttribute3,	
    UserAttribute4,	
    UserAttribute5  
) AS
SELECT
    DRIVENAME,
    DRIVEGROUPNAME,
    DRIVEPRIORITY,
    DMNAME,
    CASE DRIVEDISABLED
        WHEN 0 THEN 'true'
        WHEN 1 THEN 'false'
        ELSE 'temporary'
    END AS DRIVEDISABLED,
    CASE DRIVEBROKEN
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS DRIVEBROKEN,
    CASE DRIVEONLINE
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS DRIVEONLINE,
    CASE DRIVESTATESOFT
        WHEN 0 THEN 'ready'
        ELSE 'inuse'
    END AS DRIVESTATESOFT,
    CASE DRIVESTATEHARD
        WHEN 0 THEN 'loaded'
        WHEN 1 THEN 'loading'
        WHEN 2 THEN 'unloading'
        ELSE 'unloaded'
    END AS DRIVESTATEHARD,
    DRIVETIMECREATED,
    DRIVETIMEMOUNTEDLAST,
    DRIVETIMEMOUNTEDTOTAL,
    DRIVENUMBERMOUNTS,
    DRIVENUMBERMOUNTSSINCECLEANING,
    LIBRARYNAME,
    BAYNAME,
    CASE DRIVELIBRARYACCESSIBLE
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS DRIVELIBRARYACCESSIBLE,
    CASE DRIVELIBRARYOCCUPIED
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS DRIVELIBRARYOCCUPIED,
    CARTRIDGEPCL,
    CASE DRIVENEEDSCLEANING
        WHEN 0 THEN 'false'
        WHEN 1 THEN 'true'
        WHEN 2 THEN 'advisory'
        ELSE 'mandatory'
    END AS DRIVENEEDSCLEANING,
    D.MAXMOUNTS,
    D.MANUFACTURER,
    D.MODEL,
    D.SERIALNUMBER,
    D.DRIVEID,
    D.DriveTaskId, 
    D.UserAttribute1,	
    D.UserAttribute2,	
    D.UserAttribute3,	
    D.UserAttribute4,	
    D.UserAttribute5  
FROM
    M_DRIVE AS D
    LEFT JOIN M_DM AS DM ON
        (D.DMID = DM.DMID)
    LEFT JOIN M_CARTRIDGE AS C ON
        (D.CARTRIDGEID = C.CARTRIDGEID),
    M_BAY AS B,
    M_LIBRARY AS L,
    M_DRIVEGROUP AS DG
WHERE
    D.BAYID = B.BAYID
    AND B.LIBRARYID = L.LIBRARYID
    AND D.DRIVEGROUPID = DG.DRIVEGROUPID
;

--
-- MV_DRIVECARTRIDGEACCESS
--
ECHO Creating view MV_DRIVECARTRIDGEACCESS...;
--
CREATE VIEW MV_DRIVECARTRIDGEACCESS (
    DRIVENAME,
    DMNAME,
    CARTRIDGEID,
    CARTRIDGEPCL,
    SIDENAME,
    PARTITIONNAME,
    APPLICATIONNAME,
    AINAME,
    TIMEMOUNT,
    TIMEUNMOUNT,
    BYTEREADCOUNT,
    BYTEWRITECOUNT,
    HARDREADERRORCOUNT,
    SOFTREADERRORCOUNT,
    HARDWRITEERRORCOUNT,
    SOFTWRITEERRORCOUNT,
    DRIVECARTRIDGEACCESSID,
    MOUNTLOGICALID
) AS
SELECT
    DRIVENAME,
    DMNAME,
    CARTRIDGEID,
    CARTRIDGEPCL,
    SIDENAME,
    PARTITIONNAME,
    APPLICATIONNAME,
    AINAME,
    TIMEMOUNT,
    TIMEUNMOUNT,
    BYTEREADCOUNT,
    BYTEWRITECOUNT,
    HARDREADERRORCOUNT,
    SOFTREADERRORCOUNT,
    HARDWRITEERRORCOUNT,
    SOFTWRITEERRORCOUNT,
    DRIVECARTRIDGEACCESSID,
    MOUNTLOGICALID
FROM
    M_DRIVECARTRIDGEACCESS
;

--
-- MV_DRIVEGROUP
--
ECHO Creating view MV_DRIVEGROUP...;
--
CREATE VIEW MV_DRIVEGROUP (
    DRIVEGROUPNAME,
    DRIVEGROUPUNLOADTIME,
    DRIVEGROUPID
) AS
SELECT
    DRIVEGROUPNAME,
    DRIVEGROUPUNLOADTIME,
    DRIVEGROUPID
FROM
    M_DRIVEGROUP
;

--
-- MV_DRIVEGROUPAPPLICATION
--
ECHO Creating view MV_DRIVEGROUPAPPLICATION...;
--
CREATE VIEW MV_DRIVEGROUPAPPLICATION (
    DRIVEGROUPNAME,
    APPLICATIONNAME,
    DRIVEGROUPAPPLICATIONPRIORITY,
    UNLOADTIME,
    DRIVEGROUPAPPLICATIONID
) AS
SELECT
    DRIVEGROUPNAME,
    APPLICATIONNAME,
    PRIORITY,
    UNLOADTIME,
    DRIVEGROUPAPPLICATIONID
FROM
    M_DRIVEGROUPAPPLICATION AS DGA,
    M_DRIVEGROUP AS DG,
    M_APPLICATION AS A
WHERE
    DGA.DRIVEGROUPID = DG.DRIVEGROUPID
    AND DGA.APPLICATIONID = A.APPLICATIONID
;

--
-- MV_DRIVEGROUPAI
--
ECHO Creating view MV_DRIVEGROUPAI...;
--
CREATE VIEW MV_DRIVEGROUPAI (
    DRIVEGROUPNAME,
    AINAME,
    DRIVEGROUPAIPRIORITY,
    UNLOADTIME,
    DRIVEGROUPAIID
) AS
SELECT
    DRIVEGROUPNAME,
    AINAME,
    PRIORITY,
    UNLOADTIME,
    DRIVEGROUPAIID
FROM
    M_DRIVEGROUPAI AS DGAI,
    M_DRIVEGROUP AS DG,
    M_AI AS A
WHERE
    DGAI.DRIVEGROUPID = DG.DRIVEGROUPID
    AND DGAI.AIID = A.AIID
;

--
-- MV_LIBRARY
-- TMG01: Added CmcGroupName 
--
ECHO Creating view MV_LIBRARY...;
--
CREATE VIEW MV_LIBRARY (
    LIBRARYNAME,
    LIBRARYONLINE,
    LIBRARYDISABLED,
    LIBRARYBROKEN,
    LMNAME,
    LIBRARYSTATEHARD,
    LIBRARYSTATESOFT,
    LIBRARYACCESSPATH,
    CONNECTEDLIBRARYLIST,    
    LIBRARYID,
    CMCGROUPNAME,    
    LASTAUDITTIME,
    UserAttribute1,	
    UserAttribute2,	
    UserAttribute3,	
    UserAttribute4,	
    UserAttribute5  
) AS
SELECT
    LIBRARYNAME,
    CASE LIBRARYONLINE
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS LIBRARYONLINE,
    CASE LIBRARYDISABLED
        WHEN 0 THEN 'true'
        WHEN 1 THEN 'false'
        ELSE 'temporary'
    END AS LIBRARYDISABLED,
    CASE LIBRARYBROKEN
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS LIBRARYBROKEN,
    LMNAME,
    CASE LIBRARYSTATEHARD
        WHEN 0 THEN 'unknown'
        ELSE '--error--'
    END AS LIBRARYSTATEHARD,
    CASE LIBRARYSTATESOFT
        WHEN 0 THEN 'ready'
        WHEN 1 THEN 'auditing'
        ELSE '--error--'
    END AS LIBRARYSTATESOFT,
    LIBRARYACCESSPATH,
    CONNECTEDLIBRARYLIST, 
    L.LIBRARYID,
    CMCGROUPNAME,
    L.LASTAUDITTIME,
    L.UserAttribute1,	
    L.UserAttribute2,	
    L.UserAttribute3,	
    L.UserAttribute4,	
    L.UserAttribute5  
FROM
    M_LIBRARY AS L
    LEFT JOIN M_LM AS LM ON
        (L.LMID = LM.LMID)
    LEFT JOIN M_CMCGROUP AS CG ON
        (L.CMCGROUPID = CG.CMCGROUPID)
;

--
-- MV_LM
--
ECHO Creating view MV_LM...;
--
CREATE VIEW MV_LM (
    LIBRARYNAME,
    LMNAME,
    LMMESSAGELEVEL,
    LMHOST,
    LMSTATEHARD,
    LMSTATESOFT,
    LMID
) AS
SELECT
    LIBRARYNAME,
    LMNAME,
    CASE LMMESSAGELEVEL
        WHEN 0 THEN 'emergency'
        WHEN 1 THEN 'alert'
        WHEN 2 THEN 'critical'
        WHEN 3 THEN 'error'
        WHEN 4 THEN 'warning'
        WHEN 5 THEN 'notice'
        WHEN 6 THEN 'information'
        WHEN 7 THEN 'debug'
        ELSE 'developer'
    END AS LMMESSAGELEVEL,
    LMHOST,
    CASE LMSTATEHARD
        WHEN 0 THEN 'ready'
        ELSE 'broken'
    END AS LMSTATEHARD,
    CASE LMSTATESOFT
        WHEN 0 THEN 'absent'
        WHEN 1 THEN 'present'
        WHEN 2 THEN 'notready'
        WHEN 3 THEN 'disconnected'
        ELSE 'ready'
    END AS LMSTATESOFT,
    LM.LMID
FROM
    M_LM AS LM
    LEFT JOIN M_LIBRARY AS L ON
        (LM.LIBRARYID = L.LIBRARYID)
;

--
-- MV_MESSAGE
--
ECHO Creating view MV_MESSAGE...;
--
CREATE VIEW MV_MESSAGE (
    MESSAGEID,
    MESSAGESENDERTYPE,
    MESSAGESENDERNAME,
    MESSAGESENDERINSTANCE,
    MESSAGELEVEL,
    MESSAGETEXT,
    MESSAGETIMECREATED
) AS
SELECT
    MESSAGEID,
    MESSAGESENDERTYPE,
    MESSAGESENDERNAME,
    MESSAGESENDERINSTANCE,
    CASE MESSAGELEVEL
        WHEN 0 THEN 'emergency'
        WHEN 1 THEN 'alert'
        WHEN 2 THEN 'critical'
        WHEN 3 THEN 'error'
        WHEN 4 THEN 'warning'
        WHEN 5 THEN 'notice'
        WHEN 6 THEN 'information'
        WHEN 7 THEN 'debug'
        ELSE 'developer'
    END AS MESSAGELEVEL,
    MESSAGETEXT,
    MESSAGETIMECREATED
FROM
    M_MESSAGE
;

--
-- MV_MOUNTLOGICAL
--
ECHO Creating view MV_MOUNTLOGICAL...;
--
CREATE VIEW MV_MOUNTLOGICAL (
    APPLICATIONNAME,
    VOLUMENAME,
    PARTITIONNAME,
    SIDENAME,
    CARTRIDGEID,
    DRIVENAME,
    DMNAME,
    DMCAPABILITYNAME,
    MOUNTLOGICALHANDLE,
    MOUNTLOGICALTIMEWHENMOUNTED,
    MOUNTLOGICALID
) AS
SELECT
    APPLICATIONNAME,
    VOLUMENAME,
    PARTITIONNAME,
    P.SIDENAME,
    P.CARTRIDGEID,
    DRIVENAME,
    DMNAME,
    DMCAPABILITYNAME,
    MOUNTLOGICALHANDLE,
    MOUNTLOGICALTIMEWHENMOUNTED,
    MOUNTLOGICALID
FROM
    M_MOUNTLOGICAL AS ML
    LEFT JOIN M_VOLUME AS V ON
        (ML.VOLUMEID = V.VOLUMEID)
    LEFT JOIN M_PARTITION AS P ON
        (ML.PARTITIONID = P.PARTITIONID),
    M_APPLICATION AS A,
    M_DMCAPABILITY AS DC,
    M_DM AS DM
    LEFT JOIN M_DRIVE AS D ON
        (DM.DRIVEID = D.DRIVEID)
WHERE
    ML.APPLICATIONID = A.APPLICATIONID
    AND ML.DMCAPABILITYID = DC.DMCAPABILITYID
    AND DC.DMID = DM.DMID
;

--
-- MV_MOUNTPHYSICAL
--
ECHO Creating view MV_MOUNTPHYSICAL...;
--
CREATE VIEW MV_MOUNTPHYSICAL (
    APPLICATIONNAME,
    DRIVENAME,
    LIBRARYNAME,
    CARTRIDGEID,
    CARTRIDGEPCL,
    SIDENAME,
    SLOTNAME,
    MOUNTPHYSICALTIMEWHENMOUNTED,
    MOUNTPHYSICALID
) AS
SELECT
    APPLICATIONNAME,
    DRIVENAME,
    LIBRARYNAME,
    C.CARTRIDGEID,
    C.CARTRIDGEPCL,
    P.SIDENAME,
    SLOTNAME,
    MOUNTPHYSICALTIMEWHENMOUNTED,
    MOUNTPHYSICALID
FROM
    M_MOUNTPHYSICAL AS MP LEFT JOIN M_SLOT AS SL ON
        (MP.SLOTID = SL.SLOTID),
    M_APPLICATION AS A,
    M_DRIVE AS D,
    M_BAY AS B,
    M_LIBRARY AS L,
    M_PARTITION AS P,
    M_CARTRIDGE AS C
WHERE
    MP.APPLICATIONID = A.APPLICATIONID
    AND MP.DRIVEID = D.DRIVEID
    AND D.BAYID = B.BAYID
    AND B.LIBRARYID = L.LIBRARYID
    AND MP.PARTITIONID = P.PARTITIONID
    AND P.CARTRIDGEID = C.CARTRIDGEID
;

--
-- MV_PARTITION
--
ECHO Creating view MV_PARTITION...;
--
CREATE VIEW MV_PARTITION (
    CARTRIDGEID,
    SIDENAME,
    PARTITIONNAME,
    PARTITIONSIZE,
    PARTITIONBITFORMAT,
    PARTITIONALLOCATABLE,
    PARTITIONSIGNATURE,
    PARTITIONSIGNATURESTATE,
    PARTITIONSIGNATUREALGORITHM,
    PARTITIONMEDIASERIAL,
    PARTITIONMEDIASERIALSTATE,
    PARTITIONNUMBERMOUNTS,
    PARTITIONTIMECREATED,
    PARTITIONTIMEMOUNTEDTOTAL,
    PARTITIONTIMEMOUNTEDLAST,
    PARTITIONID
) AS
SELECT
    CARTRIDGEID,
    SIDENAME,
    PARTITIONNAME,
    PARTITIONSIZE,
    PARTITIONBITFORMAT,
    CASE PARTITIONALLOCATABLE
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS PARTITIONALLOCATABLE,
    PARTITIONSIGNATURE,
    CASE PARTITIONSIGNATURESTATE
        WHEN 0 THEN 'undefined'
        WHEN 1 THEN 'unimplemented'
        WHEN 2 THEN 'unknown'
        WHEN 3 THEN 'uninitialized'
        WHEN 4 THEN 'system'
        WHEN 5 THEN 'application'
        WHEN 6 THEN 'sysactive'
        ELSE 'appactive'
    END AS PARTITIONSIGNATURESTATE,
    PARTITIONSIGNATUREALGORITHM,
    PARTITIONMEDIASERIAL,
    CASE PARTITIONMEDIASERIALSTATE
        WHEN 0 THEN 'unknown'
        WHEN 1 THEN 'unitialized'
        WHEN 2 THEN 'known'
        ELSE 'unimplemented'
    END AS PARTITIONMEDIASERIALSTATE,
    PARTITIONNUMBERMOUNTS,
    PARTITIONTIMECREATED,
    PARTITIONTIMEMOUNTEDTOTAL,
    PARTITIONTIMEMOUNTEDLAST,
    PARTITIONID
FROM
    M_PARTITION
;

--
-- MV_REQUEST
-- Correct join conditions.
--
ECHO Creating view MV_REQUEST...;
--
CREATE VIEW MV_REQUEST (
    REQUESTID,
    REQUESTINGTASKID,
    REQUESTINGCLIENT,
    REQUESTINGINSTANCE,
    REQUESTINGCLIENTTYPE,
    REQUESTPRIORITY,
    REQUESTSTATE,
    REQUESTTEXT,
    ACCEPTINGSESSIONID,
    RESPONSETEXT,
    REQUESTTIMECREATED,
    REQUESTTIMEACCEPTED,
    REQUESTTIMERESPONDED
) AS
SELECT
    REQUESTID,
    TASKID,
    L.LIBRARYNAME,
    LM.LMNAME,
    REQUESTINGCLIENTTYPE,
    REQUESTPRIORITY,
    CASE REQUESTSTATE
        WHEN 0 THEN 'pending'
        WHEN 1 THEN 'accepted'
        ELSE 'responded'
    END AS REQUESTSTATE,
    REQUESTTEXT,
    ACCEPTINGSESSIONID,
    RESPONSETEXT,
    REQUESTTIMECREATED,
    REQUESTTIMEACCEPTED,
    REQUESTTIMERESPONDED
FROM
    M_REQUEST AS R,
    M_LM AS LM,
    M_LIBRARY AS L
WHERE
    R.REQUESTINGCLIENTID = L.LIBRARYID
    AND R.REQUESTINGINSTANCEID = LM.LMID
UNION ALL
SELECT
    REQUESTID,
    TASKID,
    D.DRIVENAME,
    DM.DMNAME,
    REQUESTINGCLIENTTYPE,
    REQUESTPRIORITY,
    CASE REQUESTSTATE
        WHEN 0 THEN 'pending'
        WHEN 1 THEN 'accepted'
        ELSE 'responded'
    END AS REQUESTSTATE,
    REQUESTTEXT,
    ACCEPTINGSESSIONID,
    RESPONSETEXT,
    REQUESTTIMECREATED,
    REQUESTTIMEACCEPTED,
    REQUESTTIMERESPONDED
FROM
    M_REQUEST AS R,
    M_DM AS DM,
    M_DRIVE AS D
WHERE
    R.REQUESTINGCLIENTID = D.DRIVEID
    AND R.REQUESTINGINSTANCEID = DM.DMID
;

--
-- MV_SESSION
--
ECHO Creating view MV_SESSION...;
--
CREATE VIEW MV_SESSION (
    SESSIONID,
    APPLICATIONNAME,
    AINAME,
    LANGUAGE,
    SESSIONATTACHED,
    SESSIONCLIENTHOST,
    SESSIONCLIENTPORT,
    SESSIONTIMECREATED,
    SESSIONTIMELASTACTIVE,
    PRIVILEGE
) AS
SELECT
    SESSIONID,
    APPLICATIONNAME,
    AINAME,
    LANGUAGE,
    CASE SESSIONATTACHED
        WHEN 'Y' THEN 'true'
        ELSE 'false'
    END AS SESSIONATTACHED,
    SESSIONCLIENTHOST,
    SESSIONCLIENTPORT,
    SESSIONTIMECREATED,
    SESSIONTIMELASTACTIVE,
    CASE PRIVILEGELEVEL
        WHEN 0 THEN 'standard'
        ELSE 'administrator'
    END AS PRIVILEGE
FROM
    M_SESSION AS S,
    M_AI AS AI,
    M_APPLICATION AS A
WHERE
    S.AIID = AI.AIID
    AND AI.APPLICATIONID = A.APPLICATIONID
;

--
-- MV_SLOT
--
ECHO Creating view MV_SLOT...;
--
CREATE VIEW MV_SLOT (
    SLOTNAME,
    LIBRARYNAME,
    LMNAME,
    BAYNAME,
    SLOTGROUPNAME,
    SLOTTYPENAME,
    CARTRIDGEID,
    CARTRIDGEPCL,
    SLOTACCESSIBLE,
    SLOTOCCUPIED,
    SLOTID
) AS
SELECT
    SLOTNAME,
    LIBRARYNAME,
    LMNAME,
    BAYNAME,
    SLOTGROUPNAME,
    SLOTTYPENAME,
    S.CARTRIDGEID,
    CARTRIDGEPCL,
    SLOTACCESSIBLE,
    SLOTOCCUPIED,
    SLOTID
FROM
    M_SLOT AS S
    LEFT JOIN M_CARTRIDGE AS C ON
        (S.CARTRIDGEID = C.CARTRIDGEID),
    M_SLOTGROUP AS SG,
    M_BAY AS B,
    M_LIBRARY AS L
    LEFT JOIN M_LM AS LM ON
        (L.LMID = LM.LMID),
    M_SLOTTYPE AS ST
WHERE
    S.SLOTGROUPID = SG.SLOTGROUPID
    AND SG.BAYID = B.BAYID
    AND B.LIBRARYID = L.LIBRARYID
    AND S.SLOTTYPEID = ST.SLOTTYPEID
;

--
-- MV_SLOTCONFIG
--
ECHO Creating view MV_SLOTCONFIG...;
--
CREATE VIEW MV_SLOTCONFIG (
    LIBRARYNAME,
    LMNAME,
    BAYNAME,
    SLOTTYPENAME,
    SLOTCONFIGNUMBERFREE,
    SLOTCONFIGNUMBERTOTAL,
    SLOTCONFIGID
) AS
SELECT
    LIBRARYNAME,
    LMNAME,
    BAYNAME,
    SLOTTYPENAME,
    SLOTCONFIGNUMBERFREE,
    SLOTCONFIGNUMBERTOTAL,
    SLOTCONFIGID
FROM
    M_SLOTCONFIG AS SC,
    M_SLOTTYPE AS ST,
    M_BAY AS B,
    M_LIBRARY AS L LEFT JOIN M_LM AS LM ON
        (L.LMID = LM.LMID)
WHERE
    SC.SLOTTYPEID = ST.SLOTTYPEID
    AND SC.BAYID = B.BAYID
    AND B.LIBRARYID = L.LIBRARYID
;

--
-- MV_SLOTGROUP
--
ECHO Creating view MV_SLOTGROUP...;
--
CREATE VIEW MV_SLOTGROUP (
    SLOTGROUPNAME,
    DIRECTION,
    TYPE,
    LIBRARYNAME,
    LMNAME,
    SLOTGROUPID,
    BAYNAME
) AS
SELECT
    SLOTGROUPNAME,
    CASE DIRECTION
        WHEN 0 THEN 'none'
        WHEN 1 THEN 'in'
        WHEN 2 THEN 'out'
        ELSE 'both'
    END AS DIRECTION,
    CASE TYPE
        WHEN 0 THEN 'ordinary'
        WHEN 1 THEN 'port'
        ELSE 'magazine'
    END AS TYPE,
    LIBRARYNAME,
    LMNAME,
    SLOTGROUPID,
    BAYNAME
FROM
    M_SLOTGROUP AS SG,
    M_BAY AS B,
    M_LIBRARY AS L LEFT JOIN M_LM AS LM ON
        (L.LMID = LM.LMID)
WHERE
    SG.BAYID = B.BAYID
    AND B.LIBRARYID = L.LIBRARYID
;

--
-- MV_SLOTTYPE
--
ECHO Creating view MV_SLOTTYPE...;
--
CREATE VIEW MV_SLOTTYPE (
    SLOTTYPENAME,
    CARTRIDGESHAPENAME,
    SLOTTYPEID
) AS
SELECT
    ST.SLOTTYPENAME,
    CS.CARTRIDGESHAPENAME,
    ST.SLOTTYPEID
FROM
    M_SlotType AS ST,
    M_SLOTTYPECARTRIDGESHAPE AS STCS,
    M_CARTRIDGESHAPE AS CS
WHERE
    ST.SLOTTYPEID = STCS.SLOTTYPEID
    AND CS.CARTRIDGESHAPEID = STCS.CARTRIDGESHAPEID
;

--
-- MV_STALEHANDLE
--
ECHO Creating view MV_STALEHANDLE...;
--
CREATE VIEW MV_STALEHANDLE (
    APPLICATIONNAME,
    VOLUMENAME,
    PARTITIONNAME,
    SIDENAME,
    CARTRIDGEID,
    DRIVENAME,
    DMNAME,
    MOUNTLOGICALHANDLE,
    MOUNTLOGICALTIMEWHENMOUNTED,
    STALEHANDLEID
) AS
SELECT
    A.APPLICATIONNAME,
    V.VOLUMENAME,
    P.PARTITIONNAME,
    P.SIDENAME,
    SH.CARTRIDGEID,
    D.DRIVENAME,
    DM.DMNAME,
    ML.MOUNTLOGICALHANDLE,
    SH.MOUNTLOGICALTIMEWHENMOUNTED,
    SH.STALEHANDLEID
FROM
    M_STALEHANDLE AS SH,
    M_APPLICATION AS A,
    M_VOLUME AS V,
    M_PARTITION AS P,
    M_DRIVE AS D,
    M_DM AS DM,
    M_MOUNTLOGICAL AS ML
WHERE
    SH.APPLICATIONID = A.APPLICATIONID
    AND SH.VOLUMEID = V.VOLUMEID
    AND SH.PARTITIONID = P.PARTITIONID
    AND SH.DRIVEID = D.DRIVEID
    AND SH.DMID = DM.DMID
    AND SH.MOUNTLOGICALHANDLEID = ML.MOUNTLOGICALID
;

--
-- MV_SYSTEM
--
ECHO Creating view MV_SYSTEM...;
--
CREATE VIEW MV_SYSTEM (
    ADMINISTRATOR,
    SYSTEMLOGLEVEL,
    SYSTEMACCEPTLEVEL,
    SYSTEMLOGFILE,
    SYSTEMMESSAGELIMIT,
    SYSTEMMESSAGECOUNT,
    SYSTEMREQUESTLIMIT,
    SYSTEMREQUESTCOUNT,
    SYSTEMSYNCLIMIT,
    SYSTEMDCALIMIT,
    SYSTEMDCACOUNT,
    SYSTEMMAXDISCONNECTTIMEOUT,
    SYSTEMSTATE,
    SYSTEMEXTERNALSTATE,
    DEFAULTDRIVEGROUP,
    DEFAULTCARTRIDGEGROUP,
    DEFAULTSCRATCHPOOL,
    ERMMDBVERSION,
    SYSTEMREPORTINGLEVEL,
    NoAccessCartridgeGroup,	
    NoAccessDriveGroup,
    NumTraceFiles,
    TraceFile,
    TraceFileName,
    TraceFileSize,
    TraceFileVersions,
    TraceLevel,
    Tracing,
    TracingEnabled,
    VersionChecking,
    SYSTEMID
) AS
SELECT
    ADMINISTRATOR,
    CASE SYSTEMLOGLEVEL
        WHEN 0 THEN 'emergency'
        WHEN 1 THEN 'alert'
        WHEN 2 THEN 'critical'
        WHEN 3 THEN 'error'
        WHEN 4 THEN 'warning'
        WHEN 5 THEN 'notice'
        WHEN 6 THEN 'information'
        WHEN 7 THEN 'debug'
        ELSE 'developer'
    END AS SYSTEMLOGLEVEL,
    CASE SYSTEMACCEPTLEVEL
        WHEN 0 THEN 'emergency'
        WHEN 1 THEN 'alert'
        WHEN 2 THEN 'critical'
        WHEN 3 THEN 'error'
        WHEN 4 THEN 'warning'
        WHEN 5 THEN 'notice'
        WHEN 6 THEN 'information'
        WHEN 7 THEN 'debug'
        ELSE 'developer'
    END AS SYSTEMACCEPTLEVEL,
    SYSTEMLOGFILE,
    SYSTEMMESSAGELIMIT,
    SYSTEMMESSAGECOUNT,
    SYSTEMREQUESTLIMIT,
    SYSTEMREQUESTCOUNT,
    SYSTEMSYNCLIMIT,
    SYSTEMDCALIMIT,
    SYSTEMDCACOUNT,
    SYSTEMMAXDISCONNECTTIMEOUT,
    SYSTEMSTATE,
    SYSTEMEXTERNALSTATE,
    DEFAULTDRIVEGROUP,
    DEFAULTCARTRIDGEGROUP,
    DEFAULTSCRATCHPOOL,
    ERMMDBVERSION,
    CASE SYSTEMREPORTINGLEVEL
        WHEN 0 THEN 'disabled'
        WHEN 1 THEN 'enabled'
        ELSE 'disabled'
    END AS SYSTEMREPORTINGLEVEL,
    NoAccessCartridgeGroup,	
    NoAccessDriveGroup,
    NumTraceFiles,
    TraceFile,
    TraceFileName,
    TraceFileSize,
    TraceFileVersions,
    TraceLevel,
    Tracing,
    TracingEnabled,
    VersionChecking,
    SYSTEMID
FROM
    M_SYSTEM
;

--
-- MV_TASK
--
ECHO Creating view MV_TASK...;
--
CREATE VIEW MV_TASK (
    TASKID,
    TASKTYPE,
    TASKARRIVALTIME,
    TASKPRIORITY,
    APPLICATIONNAME,
    APPLICATIONID,
    AINAME,
    AIID,
    TASKSTATEMENT,
    TASKSTATE,
    CLIENTTASKID,
    SESSIONID,
    DriveSpecificMount,
    TaskConnection,
    TaskDispatchTime,
    TaskHandle,
    UserHelpState,
    theTaskCartridgeId,
    theTaskCartridgePCL,
    theTaskDriveId,
    theTaskDriveName,
    theTaskLibraryId,
    SourceLibrary
) AS
SELECT
    TASKID,
    TASKTYPE,
    TASKARRIVALTIME,
    TASKPRIORITY,
    APPLICATIONNAME,
    T.APPLICATIONID,
    AINAME,
    T.AIID,
    TASKSTATEMENT,
    CASE TASKSTATE
        WHEN 0 THEN 'undefined'
        WHEN 1 THEN 'blocked'
        ELSE 'dispatched'
    END AS TASKSTATE,
    CLIENTTASKID,
    T.SESSIONID,
    T.DriveSpecificMount,
    T.TaskConnection,
    T.TaskDispatchTime,
    T.TaskHandle,
    T.UserHelpState,
    T.theTaskCartridgeId,
    T.theTaskCartridgePCL,
    T.theTaskDriveId,
    T.theTaskDriveName,
    T.theTaskLibraryId,
    T.SourceLibrary
FROM
    M_TASK AS T
    LEFT JOIN M_SESSION AS S ON (T.SESSIONID = S.SESSIONID)
    LEFT JOIN M_AI AS AI ON (T.AIID = AI.AIID)
    LEFT JOIN M_APPLICATION AS A ON (T.APPLICATIONID = A.APPLICATIONID)
;

--
-- MV_TASKCARTRIDGE
--
ECHO Creating view MV_TASKCARTRIDGE...;
--
CREATE VIEW MV_TASKCARTRIDGE (
    TASKID,
    CARTRIDGEID,
    TASKCARTRIDGEID
) AS
SELECT
    TASKID,
    CARTRIDGEID,
    TASKCARTRIDGEID
FROM
    M_TASKCARTRIDGE
;

--
-- MV_TASKDRIVE
--
ECHO Creating view MV_TASKDRIVE...;
--
CREATE VIEW MV_TASKDRIVE (
    TASKID,
    DRIVENAME,
    TASKDRIVEID
) AS
SELECT
    TASKID,
    DRIVENAME,
    TASKDRIVEID
FROM
    M_TASKDRIVE AS TD,
    M_DRIVE AS D
WHERE
    TD.DRIVEID = D.DRIVEID
;

--
-- MV_TASKLIBRARY
--
ECHO Creating view MV_TASKLIBRARY...;
--
CREATE VIEW MV_TASKLIBRARY (
    TASKID,
    LIBRARYNAME,
    TASKLIBRARYID
) AS
SELECT
    TASKID,
    LIBRARYNAME,
    TASKLIBRARYID
FROM
    M_TASKLIBRARY AS TL,
    M_LIBRARY AS L
WHERE
    TL.LIBRARYID = L.LIBRARYID
;

--
-- MV_VOLUME
--
ECHO Creating view MV_VOLUME...;
--
CREATE VIEW MV_VOLUME (
    APPLICATIONNAME,
    VOLUMENAME,
    CARTRIDGEID,
    SIDENAME,
    PARTITIONNAME,
    VOLUMENUMBERMOUNTS,
    VOLUMETIMECREATED,
    VOLUMETIMEMOUNTEDLAST,
    VOLUMETIMEMOUNTEDTOTAL,
    VOLUMEEXPIRATION,
    NSRPOOL,
    NSREXPIRE,
    NSRLABELTIME,
    NSRFULL,
    NSRJUKEBOX,
    NSRMODE,
    NSRRECYCLE,
    VOLUMEID,
    UserAttribute1,	
    UserAttribute2,	
    UserAttribute3,	
    UserAttribute4,	
    UserAttribute5  
) AS
SELECT
    APPLICATIONNAME,
    VOLUMENAME,
    V.CARTRIDGEID,
    P.SIDENAME,
    PARTITIONNAME,
    VOLUMENUMBERMOUNTS,
    VOLUMETIMECREATED,
    VOLUMETIMEMOUNTEDLAST,
    VOLUMETIMEMOUNTEDTOTAL,
    VOLUMEEXPIRATION,
    NSRPOOL,
    NSREXPIRE,
    NSRLABELTIME,
    NSRFULL,
    NSRJUKEBOX,
    NSRMODE,
    NSRRECYCLE,
    VOLUMEID,
    V.UserAttribute1,	
    V.UserAttribute2,	
    V.UserAttribute3,	
    V.UserAttribute4,	
    V.UserAttribute5 
FROM
    M_VOLUME AS V,
    M_PARTITION AS P,
    M_APPLICATION AS A
WHERE
    V.APPLICATIONID = A.APPLICATIONID
   AND V.PARTITIONID = P.PARTITIONID
;       

--
-- View definitions for statistical information
--

--
-- MV_STATSMOUNT
--
ECHO Creating view MV_STATSMOUNT...;
--
CREATE VIEW MV_STATSMOUNT (
    MOUNTSTATID,
    LIBRARYNAME,
    CARTRIDGEPCL,
    DRIVENAME,
    APPLICATIONNAME,
    AINAME,
    TIMEMOUNTSTART,
    TIMEMOUNTEND,
    TIMEOFMOUNT,
    PENDINGMOUNTREQUESTS,
    NUMBERDRIVESMOUNTED
) AS
SELECT
    MOUNTSTATID,
    LIBRARYNAME,
    CARTRIDGEPCL,
    DRIVENAME,
    APPLICATIONNAME,
    AINAME,
    TIMEMOUNTSTART,
    TIMEMOUNTEND,
    TIMESTAMPDIFF(2, CHAR(TIMEMOUNTEND-TIMEMOUNTSTART)),
    PENDINGMOUNTREQUESTS,
    NUMBERDRIVESMOUNTED
FROM
    M_STATSMOUNT
;

--
-- MV_UNMOUNT
--
ECHO Creating view MV_STATSUNMOUNT...;
--
CREATE VIEW MV_STATSUNMOUNT (
    UNMOUNTSTATID,
    LIBRARYNAME,
    CARTRIDGEPCL,
    APPLICATIONNAME,
    AINAME,
    TIMEUNMOUNTSTART,
    TIMEUNMOUNTEND,
    TIMEOFUNMOUNT,
    TIMEMOUNTEDTOTAL,
    PENDINGUNMOUNTREQUESTS
) AS
SELECT
    UNMOUNTSTATID,
    LIBRARYNAME,
    CARTRIDGEPCL,
    APPLICATIONNAME,
    AINAME,
    TIMEUNMOUNTSTART,
    TIMEUNMOUNTEND,
    TIMESTAMPDIFF(2, CHAR(TIMEUNMOUNTEND-TIMEUNMOUNTSTART)),
    TIMESTAMPDIFF(2, CHAR(TIMEUNMOUNTEND-TIMEMOUNTED)),
    PENDINGUNMOUNTREQUESTS
FROM
    M_STATSUNMOUNT
;

--
-- MV_STATSAUDIT
--
ECHO Creating view MV_STATSAUDIT...;
--
CREATE VIEW MV_STATSAUDIT (
    AUDITSTATID,
    LIBRARYNAME,
    APPLICATIONNAME,
    AINAME,
    TIMEAUDITSTART,
    TIMEAUDITEND,
    TIMEOFAUDIT,
    AUDITSCOPE
) AS
SELECT
    AUDITSTATID,
    B.LIBRARYNAME,
    APPLICATIONNAME,
    AINAME,
    TIMEAUDITSTART,
    TIMEAUDITEND,
    TIMESTAMPDIFF(2, CHAR(A.TIMEAUDITEND-A.TIMEAUDITSTART)),
    AUDITSCOPE
FROM
    M_STATSAUDIT AS A,
    M_LIBRARY AS B
WHERE
   A.LIBRARYID = B.LIBRARYID
;

--
-- MV_STATSEJECTC06
--
ECHO Creating view MV_STATSEJECTC06...;
--
CREATE VIEW MV_STATSEJECTC06 (
    EJECTSTATID,
    LIBRARYNAME,
    CARTRIDGEPCL,
    TIMEOFEJECT
) AS
SELECT
    EJECTSTATID,
    LIBRARYNAME,
    CARTRIDGEPCL,
    TIMEOFEJECT
FROM
    M_STATSEJECTC06
;

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;


ECHO End of creating ERMM views.;

-----------------------------------------------------------------------
--
-- End of script CreateViews.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:28
--
-- @brief CreateFunctions for DB2 zOS

-----------------------------------------------------------------------

ECHO Start of creating DB Functions...;

--
-- MV_OBJECTATTRIBUTE
-- Special view. It is necessary for correct work of ISATTR/NOATTR DB functions
--
ECHO Creating view MV_OBJECTATTRIBUTE (necessary for ISATTR/NOATTR)...;
--
CREATE VIEW MV_OBJECTATTRIBUTE (OBJECTATTRIBUTE) AS
SELECT
    CASE SUBSTR(TABNAME, 4) || '.' || COLNAME
        WHEN 'APPLICATION.MAXDISCONNECTTIMEOUT'
            THEN 'APPLICATION.APPLICATIONMAXDISCONNECTTIMEOUT'
        WHEN 'CARTRIDGEGROUPAPPLICATION.PRIORITY'
            THEN 'CARTRIDGEGROUPAPPLICATION.CARTRIDGEGROUPAPPLICATIONPRIORITY'
        WHEN 'DRIVECARTRIDGEACCESS.TIMEMOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSTIMEMOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.TIMEUNMOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSTIMEUNMOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.BYTEREADCOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSBYTEREADCOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.BYTEWRITECOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSBYTEWRITECOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.HARDREADERRORCOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSHARDREADERRORCOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.SOFTREADERRORCOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSSOFTREADERRORCOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.HARDWRITEERRORCOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSHARDWRITEERRORCOUNT'
        WHEN 'DRIVECARTRIDGEACCESS.SOFTWRITEERRORCOUNT'
            THEN 'DRIVECARTRIDGEACCESS.DRIVECARTRIDGEACCESSSOFTWRITEERRORCOUNT'
        WHEN 'DRIVEGROUPAPPLICATION.UNLOADTIME'
            THEN 'DRIVEGROUPAPPLICATION.DRIVEGROUPAPPLICATIONUNLOADTIME'
        ELSE SUBSTR(TABNAME, 4) || '.' || COLNAME
    END
FROM
    MV_ATTR
WHERE
    SUBSTR(TABNAME,1,3) = 'MV_'
UNION ALL
SELECT
    OBJECTTYPE || '.' || GCANAME
FROM
    M_GCA
UNION ALL
SELECT
    'CARTRIDGETYPE.SIDE' || RTRIM(CHAR(SIDENUMBER)) || 'NAME'
FROM
    M_CARTRIDGETYPESIDE
;

--
-- ISATTR function
-- Checks if specified object attribue exists
-- This function required view MV_OBJECTATTRIBUTE
--in form "object.attribute",
--            where object - name of object,
--                  attribute - name of attribute for object;
--            or "object.application.attribute" for local
--            client attributes,
--            where application - name of application for which
--                                this local client attribute was
--                                defined
-- returns 'Y' if specified attribute exists within specified object,
--         'N' otherwise.
--
-- Currently this function is not supported on zOS DB2
--
ECHO Creating function ISATTR...;
--
CREATE FUNCTION ISATTR (ATTR VARCHAR(256))
RETURNS CHAR(1)
LANGUAGE SQL
CONTAINS SQL
NO EXTERNAL ACTION
DETERMINISTIC
RETURN 'Y';

--BEGIN ATOMIC FOR NUMFUNC AS SELECT COUNT(OBJECTATTRIBUTE) COA FROM MV_OBJECTATTRIBUTE WHERE UPPER(OBJECTATTRIBUTE) = UPPER(ATTR) DO IF NUMFUNC.COA = 0 THEN RETURN 'N'; ELSE RETURN 'Y'; END IF; END FOR; END;

--
-- NOATTR function
-- Checks if specified object attribue not exists
-- This function required DB function ISATTR
--
-- first parameter: name of attribute in form "object.attribute",
--                  where object - name of object,
--                        attribute - name of attribute for object;
-- second parameter: locale in form
--
-- returns 'Y' if specified attribute not exist within specified object,
--         'N' otherwise.
--
--
-- Currently this function is not supported on zOS DB2
--
ECHO Creating function NOATTR...;
--
CREATE FUNCTION NOATTR (ATTR VARCHAR(256))
RETURNS CHAR(1)
LANGUAGE SQL
CONTAINS SQL
NO EXTERNAL ACTION
DETERMINISTIC
RETURN 'N';

--RETURN VALUE((SELECT COUNT(OBJECTATTRIBUTE) FROM MV_OBJECTATTRIBUTE WHERE UPPER(OBJECTATTRIBUTE) = UPPER(ATTR)), 0);

--BEGIN ATOMIC FOR NUMFUNC AS SELECT COUNT(OBJECTATTRIBUTE) COA FROM MV_OBJECTATTRIBUTE WHERE UPPER(OBJECTATTRIBUTE) = UPPER(ATTR) DO IF NUMFUNC.COA = 0 THEN RETURN 'Y'; ELSE RETURN 'N'; END IF; END FOR; END;

-- commit changes to database
ECHO Commiting changes to database ...;
--
commit;

ECHO End of creating DB Functions;

-----------------------------------------------------------------------
--
-- End of script CreateFunctions.db2-zOS.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.2 - 12/01/24 02:37:48
--
-- @brief CreateTriggers for DB2 zOS

-----------------------------------------------------------------------

ECHO Start of creating triggers...;


--
-- M_System
--
ECHO Creating unique trigger for System...;
--
CREATE TRIGGER M_SYSTEM_INSERT NO CASCADE BEFORE INSERT ON M_SYSTEM FOR EACH ROW MODE DB2SQL
VALUES CASE WHEN (SELECT COUNT(*) AS NUM FROM M_SYSTEM) > 1 THEN 1/0 ELSE 1 END;
--BEGIN ATOMIC FOR ROW AS SELECT COUNT(*) AS NUM FROM M_SYSTEM DO IF ROW.NUM > 1 THEN SIGNAL SQLSTATE '23I05' ('Unique constraint violation'); END IF; END FOR; END;


--
ECHO Creating triggers for M_DRIVE table...;
--
CREATE TRIGGER M_DRIVE_UPDATE NO CASCADE BEFORE UPDATE OF DMID ON M_DRIVE REFERENCING NEW AS NEWDRV FOR EACH ROW MODE DB2SQL
VALUES CASE WHEN (SELECT DRIVEID from M_DM where DMID = NEWDRV.DMID) <> NEWDRV.DRIVEID THEN 1/0 ELSE 1 END;
--BEGIN ATOMIC FOR DMREF AS (SELECT DRIVEID from M_DM where DMID = NEWDRV.DMID) DO IF (DMREF.DRIVEID <> NEWDRV.DRIVEID)
--THEN SIGNAL SQLSTATE '23I99' ('Unique constraint violation'); END IF; END FOR; END;


--
ECHO Creating triggers for M_LIBRARY table...;
--
CREATE TRIGGER M_LIBRARY_UPDATE NO CASCADE BEFORE UPDATE OF LMID ON M_LIBRARY REFERENCING NEW AS NEWLIB FOR EACH ROW MODE DB2SQL
VALUES CASE WHEN (SELECT LIBRARYID FROM M_LM WHERE LMID = NEWLIB.LMID) <> NEWLIB.LIBRARYID THEN 1/0 ELSE 1 END;
--BEGIN ATOMIC FOR LMREF AS (SELECT LIBRARYID from M_LM where LMID = NEWLIB.LMID) DO IF (LMREF.LIBRARYID <> NEWLIB.LIBRARYID)
--THEN SIGNAL SQLSTATE '23I98' ('Unique constraint violation'); END IF; END FOR; END;


--
ECHO Creating triggers for SYSTEM Message Limits...;
--
CREATE TRIGGER SYSTEM_MSGLIM_UPD AFTER UPDATE OF SYSTEMMESSAGELIMIT ON M_SYSTEM
FOR EACH STATEMENT MODE DB2SQL
DELETE FROM M_MESSAGE WHERE
        (SELECT COUNT(*) FROM M_MESSAGE AS REFMSG
                WHERE REFMSG.MESSAGETIMECREATED > M_MESSAGE.MESSAGETIMECREATED)
        > (SELECT MAX(SYSTEMMESSAGELIMIT) FROM M_SYSTEM WHERE SYSTEMID <> 'INIT');
--REFERENCING OLD AS PREV NEW AS NEXT FOR EACH ROW MODE DB2SQL
--WHEN (NEXT.SYSTEMMESSAGELIMIT < PREV.SYSTEMMESSAGELIMIT)
--BEGIN ATOMIC WHILE (SELECT COUNT(*) FROM M_MESSAGE) > NEXT.SYSTEMMESSAGELIMIT DO DELETE FROM M_MESSAGE WHERE MESSAGETIMECREATED = (SELECT MIN(MESSAGETIMECREATED) FROM M_MESSAGE); END WHILE; END;


--
ECHO Creating triggers for SYSTEM Cartridge access limits...;
--
CREATE TRIGGER SYSTEM_DCALIM_UPD AFTER UPDATE OF SYSTEMDCALIMIT ON M_SYSTEM
FOR EACH STATEMENT MODE DB2SQL
DELETE FROM M_DRIVECARTRIDGEACCESS WHERE 
        NOT TIMEUNMOUNT IS NULL
        AND NOT TIMEUNMOUNT='1900-01-01 00:00:00.000'
        AND     (SELECT MAX(SYSTEMDCALIMIT) FROM M_SYSTEM WHERE SYSTEMID <> 'INIT') <=
                (SELECT COUNT(*) FROM M_DRIVECARTRIDGEACCESS AS REFMSG
                WHERE REFMSG.TIMEUNMOUNT > M_DRIVECARTRIDGEACCESS.TIMEUNMOUNT);
--REFERENCING OLD AS PREV NEW AS NEXT FOR EACH ROW MODE DB2SQL
--WHEN (NEXT.SYSTEMDCALIMIT < PREV.SYSTEMDCALIMIT)
--BEGIN ATOMIC WHILE (SELECT COUNT(*) FROM M_DRIVECARTRIDGEACCESS) > NEXT.SYSTEMDCALIMIT DO DELETE FROM M_DRIVECARTRIDGEACCESS WHERE TIMEUNMOUNT = (SELECT MIN(TIMEUNMOUNT) FROM M_DRIVECARTRIDGEACCESS WHERE NOT TIMEUNMOUNT IS NULL AND NOT TIMEUNMOUNT='1900-01-01 00:00:00.000'); END WHILE; END;


--
ECHO Creating triggers for MESSAGE table...;
--
CREATE TRIGGER MESSAGE_INSERT AFTER INSERT ON M_MESSAGE FOR EACH ROW MODE DB2SQL
DELETE FROM M_MESSAGE WHERE
        (MESSAGETIMECREATED = (SELECT MIN(MESSAGETIMECREATED) FROM M_MESSAGE))
        AND ((SELECT COUNT(*) FROM M_MESSAGE) > (SELECT MAX(SYSTEMMESSAGELIMIT) FROM M_SYSTEM WHERE SYSTEMID <> 'INIT'));
--WHERE (MESSAGETIMECREATED = (SELECT MIN(MESSAGETIMECREATED) FROM M_MESSAGE)) AND ((SELECT COUNT(*) FROM M_MESSAGE) > (SELECT MAX(SYSTEMMESSAGELIMIT) FROM M_SYSTEM WHERE SYSTEMID <> 'INIT'));
--BEGIN ATOMIC FOR ROW AS SELECT MAX(SYSTEMMESSAGELIMIT) AS MAXMSG FROM M_SYSTEM DO WHILE (SELECT COUNT(*)FROM M_MESSAGE) > ROW.MAXMSG DO WHILE (SELECT COUNT(*)FROM M_MESSAGE) > CAST((ROW.MAXMSG) AS INT)*0.9 DO DELETE FROM M_MESSAGE WHERE MESSAGETIMECREATED = (SELECT MIN(MESSAGETIMECREATED) FROM M_MESSAGE WHERE NOT MESSAGETIMECREATED IS NULL); END WHILE; END WHILE; END FOR; END;



--
ECHO Creating triggers for DRIVECARTRIDGEACCESS table...;
--
CREATE TRIGGER DCA_INSERT AFTER INSERT ON M_DRIVECARTRIDGEACCESS FOR EACH ROW MODE DB2SQL
DELETE FROM M_DRIVECARTRIDGEACCESS WHERE
        (TIMEUNMOUNT = (SELECT MIN(TIMEUNMOUNT) FROM M_DRIVECARTRIDGEACCESS
                WHERE NOT TIMEUNMOUNT IS NULL AND NOT TIMEUNMOUNT='1900-01-01 00:00:00.000'))
        AND ((SELECT COUNT(*) FROM M_DRIVECARTRIDGEACCESS) > (SELECT MAX(SYSTEMDCALIMIT) FROM M_SYSTEM WHERE SYSTEMID <> 'INIT'));
--BEGIN ATOMIC FOR ROW AS SELECT MAX(SYSTEMDCALIMIT) AS MAXDCA FROM M_SYSTEM DO WHILE ( SELECT COUNT(*) FROM M_DRIVECARTRIDGEACCESS) > ROW.MAXDCA DO WHILE ( SELECT COUNT(*) FROM M_DRIVECARTRIDGEACCESS) > CAST((ROW.MAXDCA) AS INT)*0.9 DO DELETE FROM M_DRIVECARTRIDGEACCESS WHERE TIMEUNMOUNT = (SELECT MIN(TIMEUNMOUNT) FROM M_DRIVECARTRIDGEACCESS WHERE NOT TIMEUNMOUNT IS NULL AND NOT TIMEUNMOUNT='1900-01-01 00:00:00.000'); END WHILE; END WHILE; END FOR; END;


--
ECHO Creating triggers for GCA table...;
--
CREATE TRIGGER DCA_DELETE AFTER DELETE ON M_DRIVECARTRIDGEACCESS REFERENCING OLD AS Record FOR EACH ROW MODE DB2SQL
DELETE FROM M_GCA WHERE Record.DRIVECARTRIDGEACCESSID = M_GCA.OBJECTID;

-- 
-- Creating the maintenance triggers for the statistics table.
--
-- Currently statistics are only used for C06 which requires obtainung
-- the information for at most 2 hours.
-- We will make the retention limit configurable later by introducing a
-- StatsRetentionTime parameter (currently using 1 day).
--
ECHO Creating triggers for MV_STATSMOUNT table...;
--
CREATE TRIGGER STATSMOUNT_INS AFTER INSERT ON M_STATSMOUNT FOR EACH ROW MODE DB2SQL
DELETE FROM M_STATSMOUNT WHERE
        (TIMEMOUNTEND = (SELECT MIN(TIMEMOUNTEND) FROM M_STATSMOUNT
                WHERE NOT TIMEMOUNTEND IS NULL)
        AND (TIMEMOUNTEND < ( (CURRENT_TIMESTAMP - CURRENT_TIMEZONE) - 1 DAYS) ));

--
ECHO Creating triggers for MV_STATSUNMOUNT table...;
--
CREATE TRIGGER STATSUNMOUNT_INS AFTER INSERT ON M_STATSUNMOUNT FOR EACH ROW MODE DB2SQL
DELETE FROM M_STATSUNMOUNT WHERE
        (TIMEUNMOUNTEND = (SELECT MIN(TIMEUNMOUNTEND) FROM M_STATSUNMOUNT
                WHERE NOT TIMEUNMOUNTEND IS NULL)
        AND (TIMEUNMOUNTEND < ( (CURRENT_TIMESTAMP - CURRENT_TIMEZONE) - 1 DAY) ));

--
ECHO Creating triggers for MV_STATSAUDIT table...;
--
CREATE TRIGGER STATSAUDIT_INS AFTER INSERT ON M_STATSAUDIT FOR EACH ROW MODE DB2SQL
DELETE FROM M_STATSAUDIT WHERE
        (TIMEAUDITEND = (SELECT MIN(TIMEAUDITEND) FROM M_STATSAUDIT
                WHERE NOT TIMEAUDITEND IS NULL)
        AND (TIMEAUDITEND < ( (CURRENT_TIMESTAMP - CURRENT_TIMEZONE) - 1 DAY) ));

--
ECHO Creating triggers for MV_STATSEJECTC06 table...;
--
CREATE TRIGGER STATSEJECTC06_INS AFTER INSERT ON M_STATSEJECTC06 FOR EACH ROW MODE DB2SQL
DELETE FROM M_STATSEJECTC06 WHERE
        (TIMEOFEJECT = (SELECT MIN(TIMEOFEJECT) FROM M_STATSEJECTC06
                WHERE NOT TIMEOFEJECT IS NULL)
        AND (TIMEOFEJECT < ( (CURRENT_TIMESTAMP - CURRENT_TIMEZONE) - 1 DAY) ));

-- Commit changes
ECHO Commiting changes to database...;
--
COMMIT;

ECHO End of creating triggers.;

-----------------------------------------------------------------------
--
-- End of script CreateTriggers.sql
--
-----------------------------------------------------------------------

-----------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- IBM Tape System Library Manager
--
-- (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
-----------------------------------------------------------------------

-- @version 1.3 - 12/01/24 02:35:17
--
-- @brief CreateSystemRecord
-- CMVC   DATE         NAME   DESCRIPTIONS
--       (MM/DD/YY) 
-- ------ ---------- -------- ----------------------------------------
-- 63073  2010-12-10  ni      Added contents of CmcGroup, CmcLM   @TMG01
--

-----------------------------------------------------------------------

--@TMG01
ECHO Start of creating Cmc records...;

INSERT INTO M_CMCGROUP (CMCGROUPNAME, CMCGROUPID, MEDIATYPE) values ('CMCLTOGROUP', 'CMCLTOGROUPID', 'LTO');
INSERT INTO M_CMCGROUP (CMCGROUPNAME, CMCGROUPID, MEDIATYPE) values ('CMC3592GROUP', 'CMC3592GROUPID', '3592' );
INSERT INTO M_CMCLM (CMCLMNAME, CMCLMHOST, CMCLMID, CMCGROUPID) values ('CMCLTOLM', '127.0.0.1', 'CMCLTOLMID', 'CMCLTOGROUPID');
INSERT INTO M_CMCLM (CMCLMNAME, CMCLMHOST, CMCLMID, CMCGROUPID) values ('CMC3592LM', '127.0.0.1', 'CMC3592LMID', 'CMC3592GROUPID');
UPDATE M_CMCGROUP SET CmcLMID = 'CMCLTOLMID' where CmcGroupID = 'CMCLTOGROUPID';
UPDATE M_CMCGROUP SET CmcLMID = 'CMC3592LMID' where CmcGroupID = 'CMC3592GROUPID';

ECHO End of creating Cmc records...;


ECHO Start of creating the system init record...;

INSERT INTO M_SYSTEM (SYSTEMID, ERMMDBVERSION) VALUES ('INIT', '1.5.14');

ECHO End of creating the system init record ...;

-----------------------------------------------------------------------
--
-- End of script CreateSystemRecord.sql
--
-----------------------------------------------------------------------

